# Autogenerated by get_module_idx.py

d = { 'settings': {'lib_path': 'nbdev_scipy'},
  'syms': { 'builtins': { 'builtins.SuperLU': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.SuperLU.html#scipy.sparse.linalg.SuperLU'},
            'scipy': { 'scipy.LowLevelCallable': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.LowLevelCallable.html#scipy.LowLevelCallable',
                       'scipy.LowLevelCallable.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.LowLevelCallable.__getitem__.html#scipy.LowLevelCallable.__getitem__',
                       'scipy.LowLevelCallable.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.LowLevelCallable.__len__.html#scipy.LowLevelCallable.__len__',
                       'scipy.LowLevelCallable.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.LowLevelCallable.__mul__.html#scipy.LowLevelCallable.__mul__',
                       'scipy.LowLevelCallable.count': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.LowLevelCallable.count.html#scipy.LowLevelCallable.count',
                       'scipy.LowLevelCallable.from_cython': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.LowLevelCallable.from_cython.html#scipy.LowLevelCallable.from_cython',
                       'scipy.LowLevelCallable.index': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.LowLevelCallable.index.html#scipy.LowLevelCallable.index',
                       'scipy.cluster': 'https://docs.scipy.org/doc/scipy/reference/reference/cluster.html#module-scipy.cluster',
                       'scipy.constants': 'https://docs.scipy.org/doc/scipy/reference/reference/constants.html#module-scipy.constants',
                       'scipy.fft': 'https://docs.scipy.org/doc/scipy/reference/reference/fft.html#module-scipy.fft',
                       'scipy.fftpack': 'https://docs.scipy.org/doc/scipy/reference/reference/fftpack.html#module-scipy.fftpack',
                       'scipy.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/integrate.html#module-scipy.integrate',
                       'scipy.interpolate': 'https://docs.scipy.org/doc/scipy/reference/reference/interpolate.html#module-scipy.interpolate',
                       'scipy.io': 'https://docs.scipy.org/doc/scipy/reference/reference/io.html#module-scipy.io',
                       'scipy.linalg': 'https://docs.scipy.org/doc/scipy/reference/reference/linalg.html#module-scipy.linalg',
                       'scipy.misc': 'https://docs.scipy.org/doc/scipy/reference/reference/misc.html#module-scipy.misc',
                       'scipy.ndimage': 'https://docs.scipy.org/doc/scipy/reference/reference/ndimage.html#module-scipy.ndimage',
                       'scipy.odr': 'https://docs.scipy.org/doc/scipy/reference/reference/odr.html#module-scipy.odr',
                       'scipy.optimize': 'https://docs.scipy.org/doc/scipy/reference/reference/optimize.html#module-scipy.optimize',
                       'scipy.signal': 'https://docs.scipy.org/doc/scipy/reference/reference/signal.html#module-scipy.signal',
                       'scipy.sparse': 'https://docs.scipy.org/doc/scipy/reference/reference/sparse.html#module-scipy.sparse',
                       'scipy.spatial': 'https://docs.scipy.org/doc/scipy/reference/reference/spatial.html#module-scipy.spatial',
                       'scipy.special': 'https://docs.scipy.org/doc/scipy/reference/reference/special.html#module-scipy.special',
                       'scipy.stats': 'https://docs.scipy.org/doc/scipy/reference/reference/stats.html#module-scipy.stats'},
            'scipy._lib._ccallback': { 'scipy._lib._ccallback.LowLevelCallable': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.LowLevelCallable.html#scipy.LowLevelCallable'},
            'scipy._lib._disjoint_set': { 'scipy._lib._disjoint_set.DisjointSet': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.DisjointSet.html#scipy.cluster.hierarchy.DisjointSet'},
            'scipy.cluster': { 'scipy.cluster.hierarchy': 'https://docs.scipy.org/doc/scipy/reference/reference/cluster.hierarchy.html#module-scipy.cluster.hierarchy',
                               'scipy.cluster.vq': 'https://docs.scipy.org/doc/scipy/reference/reference/cluster.vq.html#module-scipy.cluster.vq'},
            'scipy.cluster.hierarchy': { 'scipy.cluster.hierarchy.ClusterNode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.ClusterNode.html#scipy.cluster.hierarchy.ClusterNode',
                                         'scipy.cluster.hierarchy.ClusterNode.get_count': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.ClusterNode.get_count.html#scipy.cluster.hierarchy.ClusterNode.get_count',
                                         'scipy.cluster.hierarchy.ClusterNode.get_id': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.ClusterNode.get_id.html#scipy.cluster.hierarchy.ClusterNode.get_id',
                                         'scipy.cluster.hierarchy.ClusterNode.get_left': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.ClusterNode.get_left.html#scipy.cluster.hierarchy.ClusterNode.get_left',
                                         'scipy.cluster.hierarchy.ClusterNode.get_right': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.ClusterNode.get_right.html#scipy.cluster.hierarchy.ClusterNode.get_right',
                                         'scipy.cluster.hierarchy.ClusterNode.is_leaf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.ClusterNode.is_leaf.html#scipy.cluster.hierarchy.ClusterNode.is_leaf',
                                         'scipy.cluster.hierarchy.ClusterNode.pre_order': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.ClusterNode.pre_order.html#scipy.cluster.hierarchy.ClusterNode.pre_order',
                                         'scipy.cluster.hierarchy.DisjointSet': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.DisjointSet.html#scipy.cluster.hierarchy.DisjointSet',
                                         'scipy.cluster.hierarchy.DisjointSet.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.DisjointSet.__getitem__.html#scipy.cluster.hierarchy.DisjointSet.__getitem__',
                                         'scipy.cluster.hierarchy.DisjointSet.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.DisjointSet.__len__.html#scipy.cluster.hierarchy.DisjointSet.__len__',
                                         'scipy.cluster.hierarchy.DisjointSet.add': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.DisjointSet.add.html#scipy.cluster.hierarchy.DisjointSet.add',
                                         'scipy.cluster.hierarchy.DisjointSet.connected': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.DisjointSet.connected.html#scipy.cluster.hierarchy.DisjointSet.connected',
                                         'scipy.cluster.hierarchy.DisjointSet.merge': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.DisjointSet.merge.html#scipy.cluster.hierarchy.DisjointSet.merge',
                                         'scipy.cluster.hierarchy.DisjointSet.subset': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.DisjointSet.subset.html#scipy.cluster.hierarchy.DisjointSet.subset',
                                         'scipy.cluster.hierarchy.DisjointSet.subsets': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.DisjointSet.subsets.html#scipy.cluster.hierarchy.DisjointSet.subsets',
                                         'scipy.cluster.hierarchy.average': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.average.html#scipy.cluster.hierarchy.average',
                                         'scipy.cluster.hierarchy.centroid': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.centroid.html#scipy.cluster.hierarchy.centroid',
                                         'scipy.cluster.hierarchy.complete': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.complete.html#scipy.cluster.hierarchy.complete',
                                         'scipy.cluster.hierarchy.cophenet': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.cophenet.html#scipy.cluster.hierarchy.cophenet',
                                         'scipy.cluster.hierarchy.correspond': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.correspond.html#scipy.cluster.hierarchy.correspond',
                                         'scipy.cluster.hierarchy.cut_tree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.cut_tree.html#scipy.cluster.hierarchy.cut_tree',
                                         'scipy.cluster.hierarchy.dendrogram': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.dendrogram.html#scipy.cluster.hierarchy.dendrogram',
                                         'scipy.cluster.hierarchy.fcluster': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.fcluster.html#scipy.cluster.hierarchy.fcluster',
                                         'scipy.cluster.hierarchy.fclusterdata': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.fclusterdata.html#scipy.cluster.hierarchy.fclusterdata',
                                         'scipy.cluster.hierarchy.from_mlab_linkage': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.from_mlab_linkage.html#scipy.cluster.hierarchy.from_mlab_linkage',
                                         'scipy.cluster.hierarchy.inconsistent': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.inconsistent.html#scipy.cluster.hierarchy.inconsistent',
                                         'scipy.cluster.hierarchy.is_isomorphic': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.is_isomorphic.html#scipy.cluster.hierarchy.is_isomorphic',
                                         'scipy.cluster.hierarchy.is_monotonic': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.is_monotonic.html#scipy.cluster.hierarchy.is_monotonic',
                                         'scipy.cluster.hierarchy.is_valid_im': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.is_valid_im.html#scipy.cluster.hierarchy.is_valid_im',
                                         'scipy.cluster.hierarchy.is_valid_linkage': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.is_valid_linkage.html#scipy.cluster.hierarchy.is_valid_linkage',
                                         'scipy.cluster.hierarchy.leaders': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.leaders.html#scipy.cluster.hierarchy.leaders',
                                         'scipy.cluster.hierarchy.leaves_list': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.leaves_list.html#scipy.cluster.hierarchy.leaves_list',
                                         'scipy.cluster.hierarchy.linkage': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.linkage.html#scipy.cluster.hierarchy.linkage',
                                         'scipy.cluster.hierarchy.maxRstat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.maxRstat.html#scipy.cluster.hierarchy.maxRstat',
                                         'scipy.cluster.hierarchy.maxdists': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.maxdists.html#scipy.cluster.hierarchy.maxdists',
                                         'scipy.cluster.hierarchy.maxinconsts': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.maxinconsts.html#scipy.cluster.hierarchy.maxinconsts',
                                         'scipy.cluster.hierarchy.median': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.median.html#scipy.cluster.hierarchy.median',
                                         'scipy.cluster.hierarchy.num_obs_linkage': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.num_obs_linkage.html#scipy.cluster.hierarchy.num_obs_linkage',
                                         'scipy.cluster.hierarchy.optimal_leaf_ordering': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.optimal_leaf_ordering.html#scipy.cluster.hierarchy.optimal_leaf_ordering',
                                         'scipy.cluster.hierarchy.set_link_color_palette': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.set_link_color_palette.html#scipy.cluster.hierarchy.set_link_color_palette',
                                         'scipy.cluster.hierarchy.single': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.single.html#scipy.cluster.hierarchy.single',
                                         'scipy.cluster.hierarchy.to_mlab_linkage': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.to_mlab_linkage.html#scipy.cluster.hierarchy.to_mlab_linkage',
                                         'scipy.cluster.hierarchy.to_tree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.to_tree.html#scipy.cluster.hierarchy.to_tree',
                                         'scipy.cluster.hierarchy.ward': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.ward.html#scipy.cluster.hierarchy.ward',
                                         'scipy.cluster.hierarchy.weighted': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.hierarchy.weighted.html#scipy.cluster.hierarchy.weighted'},
            'scipy.cluster.vq': { 'scipy.cluster.vq.kmeans': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.vq.kmeans.html#scipy.cluster.vq.kmeans',
                                  'scipy.cluster.vq.kmeans2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.vq.kmeans2.html#scipy.cluster.vq.kmeans2',
                                  'scipy.cluster.vq.vq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.vq.vq.html#scipy.cluster.vq.vq',
                                  'scipy.cluster.vq.whiten': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.cluster.vq.whiten.html#scipy.cluster.vq.whiten'},
            'scipy.constants': { 'scipy.constants.ConstantWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.constants.ConstantWarning.html#scipy.constants.ConstantWarning.with_traceback',
                                 'scipy.constants.convert_temperature': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.constants.convert_temperature.html#scipy.constants.convert_temperature',
                                 'scipy.constants.find': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.constants.find.html#scipy.constants.find',
                                 'scipy.constants.lambda2nu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.constants.lambda2nu.html#scipy.constants.lambda2nu',
                                 'scipy.constants.nu2lambda': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.constants.nu2lambda.html#scipy.constants.nu2lambda',
                                 'scipy.constants.precision': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.constants.precision.html#scipy.constants.precision',
                                 'scipy.constants.unit': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.constants.unit.html#scipy.constants.unit',
                                 'scipy.constants.value': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.constants.value.html#scipy.constants.value'},
            'scipy.fft': { 'scipy.fft.dct': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.dct.html#scipy.fft.dct',
                           'scipy.fft.dctn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.dctn.html#scipy.fft.dctn',
                           'scipy.fft.dst': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.dst.html#scipy.fft.dst',
                           'scipy.fft.dstn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.dstn.html#scipy.fft.dstn',
                           'scipy.fft.fft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.fft.html#scipy.fft.fft',
                           'scipy.fft.fft2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.fft2.html#scipy.fft.fft2',
                           'scipy.fft.fftfreq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.fftfreq.html#scipy.fft.fftfreq',
                           'scipy.fft.fftn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.fftn.html#scipy.fft.fftn',
                           'scipy.fft.fftshift': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.fftshift.html#scipy.fft.fftshift',
                           'scipy.fft.fht': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.fht.html#scipy.fft.fht',
                           'scipy.fft.fhtoffset': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.fhtoffset.html#scipy.fft.fhtoffset',
                           'scipy.fft.get_workers': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.get_workers.html#scipy.fft.get_workers',
                           'scipy.fft.hfft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.hfft.html#scipy.fft.hfft',
                           'scipy.fft.hfft2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.hfft2.html#scipy.fft.hfft2',
                           'scipy.fft.hfftn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.hfftn.html#scipy.fft.hfftn',
                           'scipy.fft.idct': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.idct.html#scipy.fft.idct',
                           'scipy.fft.idctn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.idctn.html#scipy.fft.idctn',
                           'scipy.fft.idst': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.idst.html#scipy.fft.idst',
                           'scipy.fft.idstn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.idstn.html#scipy.fft.idstn',
                           'scipy.fft.ifft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.ifft.html#scipy.fft.ifft',
                           'scipy.fft.ifft2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.ifft2.html#scipy.fft.ifft2',
                           'scipy.fft.ifftn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.ifftn.html#scipy.fft.ifftn',
                           'scipy.fft.ifftshift': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.ifftshift.html#scipy.fft.ifftshift',
                           'scipy.fft.ifht': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.ifht.html#scipy.fft.ifht',
                           'scipy.fft.ihfft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.ihfft.html#scipy.fft.ihfft',
                           'scipy.fft.ihfft2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.ihfft2.html#scipy.fft.ihfft2',
                           'scipy.fft.ihfftn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.ihfftn.html#scipy.fft.ihfftn',
                           'scipy.fft.irfft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.irfft.html#scipy.fft.irfft',
                           'scipy.fft.irfft2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.irfft2.html#scipy.fft.irfft2',
                           'scipy.fft.irfftn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.irfftn.html#scipy.fft.irfftn',
                           'scipy.fft.next_fast_len': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.next_fast_len.html#scipy.fft.next_fast_len',
                           'scipy.fft.register_backend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.register_backend.html#scipy.fft.register_backend',
                           'scipy.fft.rfft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.rfft.html#scipy.fft.rfft',
                           'scipy.fft.rfft2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.rfft2.html#scipy.fft.rfft2',
                           'scipy.fft.rfftfreq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.rfftfreq.html#scipy.fft.rfftfreq',
                           'scipy.fft.rfftn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.rfftn.html#scipy.fft.rfftn',
                           'scipy.fft.set_backend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.set_backend.html#scipy.fft.set_backend',
                           'scipy.fft.set_global_backend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.set_global_backend.html#scipy.fft.set_global_backend',
                           'scipy.fft.set_workers': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.set_workers.html#scipy.fft.set_workers',
                           'scipy.fft.skip_backend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fft.skip_backend.html#scipy.fft.skip_backend'},
            'scipy.fftpack': { 'scipy.fftpack.cc_diff': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.cc_diff.html#scipy.fftpack.cc_diff',
                               'scipy.fftpack.convolve': 'https://docs.scipy.org/doc/scipy/reference/reference/fftpack.html#module-scipy.fftpack.convolve',
                               'scipy.fftpack.cs_diff': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.cs_diff.html#scipy.fftpack.cs_diff',
                               'scipy.fftpack.dct': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.dct.html#scipy.fftpack.dct',
                               'scipy.fftpack.dctn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.dctn.html#scipy.fftpack.dctn',
                               'scipy.fftpack.diff': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.diff.html#scipy.fftpack.diff',
                               'scipy.fftpack.dst': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.dst.html#scipy.fftpack.dst',
                               'scipy.fftpack.dstn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.dstn.html#scipy.fftpack.dstn',
                               'scipy.fftpack.fft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.fft.html#scipy.fftpack.fft',
                               'scipy.fftpack.fft2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.fft2.html#scipy.fftpack.fft2',
                               'scipy.fftpack.fftfreq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.fftfreq.html#scipy.fftpack.fftfreq',
                               'scipy.fftpack.fftn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.fftn.html#scipy.fftpack.fftn',
                               'scipy.fftpack.fftshift': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.fftshift.html#scipy.fftpack.fftshift',
                               'scipy.fftpack.hilbert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.hilbert.html#scipy.fftpack.hilbert',
                               'scipy.fftpack.idct': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.idct.html#scipy.fftpack.idct',
                               'scipy.fftpack.idctn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.idctn.html#scipy.fftpack.idctn',
                               'scipy.fftpack.idst': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.idst.html#scipy.fftpack.idst',
                               'scipy.fftpack.idstn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.idstn.html#scipy.fftpack.idstn',
                               'scipy.fftpack.ifft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.ifft.html#scipy.fftpack.ifft',
                               'scipy.fftpack.ifft2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.ifft2.html#scipy.fftpack.ifft2',
                               'scipy.fftpack.ifftn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.ifftn.html#scipy.fftpack.ifftn',
                               'scipy.fftpack.ifftshift': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.ifftshift.html#scipy.fftpack.ifftshift',
                               'scipy.fftpack.ihilbert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.ihilbert.html#scipy.fftpack.ihilbert',
                               'scipy.fftpack.irfft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.irfft.html#scipy.fftpack.irfft',
                               'scipy.fftpack.itilbert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.itilbert.html#scipy.fftpack.itilbert',
                               'scipy.fftpack.next_fast_len': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.next_fast_len.html#scipy.fftpack.next_fast_len',
                               'scipy.fftpack.rfft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.rfft.html#scipy.fftpack.rfft',
                               'scipy.fftpack.rfftfreq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.rfftfreq.html#scipy.fftpack.rfftfreq',
                               'scipy.fftpack.sc_diff': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.sc_diff.html#scipy.fftpack.sc_diff',
                               'scipy.fftpack.shift': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.shift.html#scipy.fftpack.shift',
                               'scipy.fftpack.ss_diff': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.ss_diff.html#scipy.fftpack.ss_diff',
                               'scipy.fftpack.tilbert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.tilbert.html#scipy.fftpack.tilbert'},
            'scipy.fftpack.convolve': { 'scipy.fftpack.convolve.convolve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.convolve.convolve.html#scipy.fftpack.convolve.convolve',
                                        'scipy.fftpack.convolve.convolve_z': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.convolve.convolve_z.html#scipy.fftpack.convolve.convolve_z',
                                        'scipy.fftpack.convolve.destroy_convolve_cache': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.convolve.destroy_convolve_cache.html#scipy.fftpack.convolve.destroy_convolve_cache',
                                        'scipy.fftpack.convolve.init_convolution_kernel': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.fftpack.convolve.init_convolution_kernel.html#scipy.fftpack.convolve.init_convolution_kernel'},
            'scipy.integrate': { 'scipy.integrate.AccuracyWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.AccuracyWarning.html#scipy.integrate.AccuracyWarning.with_traceback',
                                 'scipy.integrate.BDF': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.BDF.html#scipy.integrate.BDF',
                                 'scipy.integrate.BDF.dense_output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.BDF.dense_output.html#scipy.integrate.BDF.dense_output',
                                 'scipy.integrate.BDF.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.BDF.step.html#scipy.integrate.BDF.step',
                                 'scipy.integrate.DOP853': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.DOP853.html#scipy.integrate.DOP853',
                                 'scipy.integrate.DOP853.dense_output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.DOP853.dense_output.html#scipy.integrate.DOP853.dense_output',
                                 'scipy.integrate.DOP853.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.DOP853.step.html#scipy.integrate.DOP853.step',
                                 'scipy.integrate.DenseOutput': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.DenseOutput.html#scipy.integrate.DenseOutput',
                                 'scipy.integrate.DenseOutput.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.DenseOutput.__call__.html#scipy.integrate.DenseOutput.__call__',
                                 'scipy.integrate.IntegrationWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.IntegrationWarning.html#scipy.integrate.IntegrationWarning.with_traceback',
                                 'scipy.integrate.LSODA': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.LSODA.html#scipy.integrate.LSODA',
                                 'scipy.integrate.LSODA.dense_output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.LSODA.dense_output.html#scipy.integrate.LSODA.dense_output',
                                 'scipy.integrate.LSODA.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.LSODA.step.html#scipy.integrate.LSODA.step',
                                 'scipy.integrate.OdeSolution': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.OdeSolution.html#scipy.integrate.OdeSolution',
                                 'scipy.integrate.OdeSolution.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.OdeSolution.__call__.html#scipy.integrate.OdeSolution.__call__',
                                 'scipy.integrate.OdeSolver': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.OdeSolver.html#scipy.integrate.OdeSolver',
                                 'scipy.integrate.OdeSolver.dense_output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.OdeSolver.dense_output.html#scipy.integrate.OdeSolver.dense_output',
                                 'scipy.integrate.OdeSolver.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.OdeSolver.step.html#scipy.integrate.OdeSolver.step',
                                 'scipy.integrate.RK23': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.RK23.html#scipy.integrate.RK23',
                                 'scipy.integrate.RK23.dense_output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.RK23.dense_output.html#scipy.integrate.RK23.dense_output',
                                 'scipy.integrate.RK23.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.RK23.step.html#scipy.integrate.RK23.step',
                                 'scipy.integrate.RK45': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.RK45.html#scipy.integrate.RK45',
                                 'scipy.integrate.RK45.dense_output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.RK45.dense_output.html#scipy.integrate.RK45.dense_output',
                                 'scipy.integrate.RK45.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.RK45.step.html#scipy.integrate.RK45.step',
                                 'scipy.integrate.Radau': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.Radau.html#scipy.integrate.Radau',
                                 'scipy.integrate.Radau.dense_output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.Radau.dense_output.html#scipy.integrate.Radau.dense_output',
                                 'scipy.integrate.Radau.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.Radau.step.html#scipy.integrate.Radau.step',
                                 'scipy.integrate.complex_ode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.html#scipy.integrate.complex_ode',
                                 'scipy.integrate.complex_ode.get_return_code': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.get_return_code.html#scipy.integrate.complex_ode.get_return_code',
                                 'scipy.integrate.complex_ode.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.integrate.html#scipy.integrate.complex_ode.integrate',
                                 'scipy.integrate.complex_ode.set_f_params': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.set_f_params.html#scipy.integrate.complex_ode.set_f_params',
                                 'scipy.integrate.complex_ode.set_initial_value': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.set_initial_value.html#scipy.integrate.complex_ode.set_initial_value',
                                 'scipy.integrate.complex_ode.set_integrator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.set_integrator.html#scipy.integrate.complex_ode.set_integrator',
                                 'scipy.integrate.complex_ode.set_jac_params': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.set_jac_params.html#scipy.integrate.complex_ode.set_jac_params',
                                 'scipy.integrate.complex_ode.set_solout': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.set_solout.html#scipy.integrate.complex_ode.set_solout',
                                 'scipy.integrate.complex_ode.successful': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.successful.html#scipy.integrate.complex_ode.successful',
                                 'scipy.integrate.cumulative_trapezoid': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.cumulative_trapezoid.html#scipy.integrate.cumulative_trapezoid',
                                 'scipy.integrate.dblquad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.dblquad.html#scipy.integrate.dblquad',
                                 'scipy.integrate.fixed_quad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.fixed_quad.html#scipy.integrate.fixed_quad',
                                 'scipy.integrate.newton_cotes': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.newton_cotes.html#scipy.integrate.newton_cotes',
                                 'scipy.integrate.nquad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.nquad.html#scipy.integrate.nquad',
                                 'scipy.integrate.ode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.html#scipy.integrate.ode',
                                 'scipy.integrate.ode.get_return_code': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.get_return_code.html#scipy.integrate.ode.get_return_code',
                                 'scipy.integrate.ode.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.integrate.html#scipy.integrate.ode.integrate',
                                 'scipy.integrate.ode.set_f_params': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.set_f_params.html#scipy.integrate.ode.set_f_params',
                                 'scipy.integrate.ode.set_initial_value': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.set_initial_value.html#scipy.integrate.ode.set_initial_value',
                                 'scipy.integrate.ode.set_integrator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.set_integrator.html#scipy.integrate.ode.set_integrator',
                                 'scipy.integrate.ode.set_jac_params': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.set_jac_params.html#scipy.integrate.ode.set_jac_params',
                                 'scipy.integrate.ode.set_solout': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.set_solout.html#scipy.integrate.ode.set_solout',
                                 'scipy.integrate.ode.successful': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.successful.html#scipy.integrate.ode.successful',
                                 'scipy.integrate.odeint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.odeint.html#scipy.integrate.odeint',
                                 'scipy.integrate.quad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.quad.html#scipy.integrate.quad',
                                 'scipy.integrate.quad_vec': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.quad_vec.html#scipy.integrate.quad_vec',
                                 'scipy.integrate.quadrature': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.quadrature.html#scipy.integrate.quadrature',
                                 'scipy.integrate.romb': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.romb.html#scipy.integrate.romb',
                                 'scipy.integrate.romberg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.romberg.html#scipy.integrate.romberg',
                                 'scipy.integrate.simpson': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.simpson.html#scipy.integrate.simpson',
                                 'scipy.integrate.solve_bvp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.solve_bvp.html#scipy.integrate.solve_bvp',
                                 'scipy.integrate.solve_ivp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.solve_ivp.html#scipy.integrate.solve_ivp',
                                 'scipy.integrate.tplquad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.tplquad.html#scipy.integrate.tplquad',
                                 'scipy.integrate.trapezoid': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.trapezoid.html#scipy.integrate.trapezoid'},
            'scipy.integrate._ivp.base': { 'scipy.integrate._ivp.base.DenseOutput': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.DenseOutput.html#scipy.integrate.DenseOutput',
                                           'scipy.integrate._ivp.base.OdeSolver': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.OdeSolver.html#scipy.integrate.OdeSolver'},
            'scipy.integrate._ivp.bdf': { 'scipy.integrate._ivp.bdf.BDF': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.BDF.html#scipy.integrate.BDF'},
            'scipy.integrate._ivp.common': { 'scipy.integrate._ivp.common.OdeSolution': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.OdeSolution.html#scipy.integrate.OdeSolution'},
            'scipy.integrate._ivp.lsoda': { 'scipy.integrate._ivp.lsoda.LSODA': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.LSODA.html#scipy.integrate.LSODA'},
            'scipy.integrate._ivp.radau': { 'scipy.integrate._ivp.radau.Radau': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.Radau.html#scipy.integrate.Radau'},
            'scipy.integrate._ivp.rk': { 'scipy.integrate._ivp.rk.DOP853': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.DOP853.html#scipy.integrate.DOP853',
                                         'scipy.integrate._ivp.rk.RK23': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.RK23.html#scipy.integrate.RK23',
                                         'scipy.integrate._ivp.rk.RK45': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.RK45.html#scipy.integrate.RK45'},
            'scipy.integrate._ode': { 'scipy.integrate._ode.complex_ode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.complex_ode.html#scipy.integrate.complex_ode',
                                      'scipy.integrate._ode.ode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.integrate.ode.html#scipy.integrate.ode'},
            'scipy.interpolate': { 'scipy.interpolate.Akima1DInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.html#scipy.interpolate.Akima1DInterpolator',
                                   'scipy.interpolate.Akima1DInterpolator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.__call__.html#scipy.interpolate.Akima1DInterpolator.__call__',
                                   'scipy.interpolate.Akima1DInterpolator.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.antiderivative.html#scipy.interpolate.Akima1DInterpolator.antiderivative',
                                   'scipy.interpolate.Akima1DInterpolator.construct_fast': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.construct_fast.html#scipy.interpolate.Akima1DInterpolator.construct_fast',
                                   'scipy.interpolate.Akima1DInterpolator.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.derivative.html#scipy.interpolate.Akima1DInterpolator.derivative',
                                   'scipy.interpolate.Akima1DInterpolator.extend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.extend.html#scipy.interpolate.Akima1DInterpolator.extend',
                                   'scipy.interpolate.Akima1DInterpolator.from_bernstein_basis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.from_bernstein_basis.html#scipy.interpolate.Akima1DInterpolator.from_bernstein_basis',
                                   'scipy.interpolate.Akima1DInterpolator.from_spline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.from_spline.html#scipy.interpolate.Akima1DInterpolator.from_spline',
                                   'scipy.interpolate.Akima1DInterpolator.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.integrate.html#scipy.interpolate.Akima1DInterpolator.integrate',
                                   'scipy.interpolate.Akima1DInterpolator.roots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.roots.html#scipy.interpolate.Akima1DInterpolator.roots',
                                   'scipy.interpolate.Akima1DInterpolator.solve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.solve.html#scipy.interpolate.Akima1DInterpolator.solve',
                                   'scipy.interpolate.BPoly': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.html#scipy.interpolate.BPoly',
                                   'scipy.interpolate.BPoly.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.__call__.html#scipy.interpolate.BPoly.__call__',
                                   'scipy.interpolate.BPoly.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.antiderivative.html#scipy.interpolate.BPoly.antiderivative',
                                   'scipy.interpolate.BPoly.construct_fast': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.construct_fast.html#scipy.interpolate.BPoly.construct_fast',
                                   'scipy.interpolate.BPoly.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.derivative.html#scipy.interpolate.BPoly.derivative',
                                   'scipy.interpolate.BPoly.extend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.extend.html#scipy.interpolate.BPoly.extend',
                                   'scipy.interpolate.BPoly.from_derivatives': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.from_derivatives.html#scipy.interpolate.BPoly.from_derivatives',
                                   'scipy.interpolate.BPoly.from_power_basis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.from_power_basis.html#scipy.interpolate.BPoly.from_power_basis',
                                   'scipy.interpolate.BPoly.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.integrate.html#scipy.interpolate.BPoly.integrate',
                                   'scipy.interpolate.BSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.html#scipy.interpolate.BSpline',
                                   'scipy.interpolate.BSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.__call__.html#scipy.interpolate.BSpline.__call__',
                                   'scipy.interpolate.BSpline.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.antiderivative.html#scipy.interpolate.BSpline.antiderivative',
                                   'scipy.interpolate.BSpline.basis_element': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.basis_element.html#scipy.interpolate.BSpline.basis_element',
                                   'scipy.interpolate.BSpline.construct_fast': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.construct_fast.html#scipy.interpolate.BSpline.construct_fast',
                                   'scipy.interpolate.BSpline.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.derivative.html#scipy.interpolate.BSpline.derivative',
                                   'scipy.interpolate.BSpline.design_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.design_matrix.html#scipy.interpolate.BSpline.design_matrix',
                                   'scipy.interpolate.BSpline.from_power_basis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.from_power_basis.html#scipy.interpolate.BSpline.from_power_basis',
                                   'scipy.interpolate.BSpline.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.integrate.html#scipy.interpolate.BSpline.integrate',
                                   'scipy.interpolate.BarycentricInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BarycentricInterpolator.html#scipy.interpolate.BarycentricInterpolator',
                                   'scipy.interpolate.BarycentricInterpolator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BarycentricInterpolator.__call__.html#scipy.interpolate.BarycentricInterpolator.__call__',
                                   'scipy.interpolate.BarycentricInterpolator.add_xi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BarycentricInterpolator.add_xi.html#scipy.interpolate.BarycentricInterpolator.add_xi',
                                   'scipy.interpolate.BarycentricInterpolator.set_yi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BarycentricInterpolator.set_yi.html#scipy.interpolate.BarycentricInterpolator.set_yi',
                                   'scipy.interpolate.BivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BivariateSpline.html#scipy.interpolate.BivariateSpline',
                                   'scipy.interpolate.BivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BivariateSpline.__call__.html#scipy.interpolate.BivariateSpline.__call__',
                                   'scipy.interpolate.BivariateSpline.ev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BivariateSpline.ev.html#scipy.interpolate.BivariateSpline.ev',
                                   'scipy.interpolate.BivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BivariateSpline.get_coeffs.html#scipy.interpolate.BivariateSpline.get_coeffs',
                                   'scipy.interpolate.BivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BivariateSpline.get_knots.html#scipy.interpolate.BivariateSpline.get_knots',
                                   'scipy.interpolate.BivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BivariateSpline.get_residual.html#scipy.interpolate.BivariateSpline.get_residual',
                                   'scipy.interpolate.BivariateSpline.integral': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BivariateSpline.integral.html#scipy.interpolate.BivariateSpline.integral',
                                   'scipy.interpolate.BivariateSpline.partial_derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BivariateSpline.partial_derivative.html#scipy.interpolate.BivariateSpline.partial_derivative',
                                   'scipy.interpolate.CloughTocher2DInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CloughTocher2DInterpolator.html#scipy.interpolate.CloughTocher2DInterpolator',
                                   'scipy.interpolate.CloughTocher2DInterpolator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CloughTocher2DInterpolator.__call__.html#scipy.interpolate.CloughTocher2DInterpolator.__call__',
                                   'scipy.interpolate.CubicHermiteSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.html#scipy.interpolate.CubicHermiteSpline',
                                   'scipy.interpolate.CubicHermiteSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.__call__.html#scipy.interpolate.CubicHermiteSpline.__call__',
                                   'scipy.interpolate.CubicHermiteSpline.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.antiderivative.html#scipy.interpolate.CubicHermiteSpline.antiderivative',
                                   'scipy.interpolate.CubicHermiteSpline.construct_fast': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.construct_fast.html#scipy.interpolate.CubicHermiteSpline.construct_fast',
                                   'scipy.interpolate.CubicHermiteSpline.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.derivative.html#scipy.interpolate.CubicHermiteSpline.derivative',
                                   'scipy.interpolate.CubicHermiteSpline.extend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.extend.html#scipy.interpolate.CubicHermiteSpline.extend',
                                   'scipy.interpolate.CubicHermiteSpline.from_bernstein_basis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.from_bernstein_basis.html#scipy.interpolate.CubicHermiteSpline.from_bernstein_basis',
                                   'scipy.interpolate.CubicHermiteSpline.from_spline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.from_spline.html#scipy.interpolate.CubicHermiteSpline.from_spline',
                                   'scipy.interpolate.CubicHermiteSpline.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.integrate.html#scipy.interpolate.CubicHermiteSpline.integrate',
                                   'scipy.interpolate.CubicHermiteSpline.roots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.roots.html#scipy.interpolate.CubicHermiteSpline.roots',
                                   'scipy.interpolate.CubicHermiteSpline.solve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.solve.html#scipy.interpolate.CubicHermiteSpline.solve',
                                   'scipy.interpolate.CubicSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.html#scipy.interpolate.CubicSpline',
                                   'scipy.interpolate.CubicSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.__call__.html#scipy.interpolate.CubicSpline.__call__',
                                   'scipy.interpolate.CubicSpline.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.antiderivative.html#scipy.interpolate.CubicSpline.antiderivative',
                                   'scipy.interpolate.CubicSpline.construct_fast': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.construct_fast.html#scipy.interpolate.CubicSpline.construct_fast',
                                   'scipy.interpolate.CubicSpline.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.derivative.html#scipy.interpolate.CubicSpline.derivative',
                                   'scipy.interpolate.CubicSpline.extend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.extend.html#scipy.interpolate.CubicSpline.extend',
                                   'scipy.interpolate.CubicSpline.from_bernstein_basis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.from_bernstein_basis.html#scipy.interpolate.CubicSpline.from_bernstein_basis',
                                   'scipy.interpolate.CubicSpline.from_spline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.from_spline.html#scipy.interpolate.CubicSpline.from_spline',
                                   'scipy.interpolate.CubicSpline.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.integrate.html#scipy.interpolate.CubicSpline.integrate',
                                   'scipy.interpolate.CubicSpline.roots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.roots.html#scipy.interpolate.CubicSpline.roots',
                                   'scipy.interpolate.CubicSpline.solve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.solve.html#scipy.interpolate.CubicSpline.solve',
                                   'scipy.interpolate.InterpolatedUnivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.html#scipy.interpolate.InterpolatedUnivariateSpline',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.__call__.html#scipy.interpolate.InterpolatedUnivariateSpline.__call__',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.antiderivative.html#scipy.interpolate.InterpolatedUnivariateSpline.antiderivative',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.derivative.html#scipy.interpolate.InterpolatedUnivariateSpline.derivative',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.derivatives': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.derivatives.html#scipy.interpolate.InterpolatedUnivariateSpline.derivatives',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.get_coeffs.html#scipy.interpolate.InterpolatedUnivariateSpline.get_coeffs',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.get_knots.html#scipy.interpolate.InterpolatedUnivariateSpline.get_knots',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.get_residual.html#scipy.interpolate.InterpolatedUnivariateSpline.get_residual',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.integral': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.integral.html#scipy.interpolate.InterpolatedUnivariateSpline.integral',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.roots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.roots.html#scipy.interpolate.InterpolatedUnivariateSpline.roots',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.set_smoothing_factor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.set_smoothing_factor.html#scipy.interpolate.InterpolatedUnivariateSpline.set_smoothing_factor',
                                   'scipy.interpolate.InterpolatedUnivariateSpline.validate_input': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.validate_input.html#scipy.interpolate.InterpolatedUnivariateSpline.validate_input',
                                   'scipy.interpolate.KroghInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.KroghInterpolator.html#scipy.interpolate.KroghInterpolator',
                                   'scipy.interpolate.KroghInterpolator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.KroghInterpolator.__call__.html#scipy.interpolate.KroghInterpolator.__call__',
                                   'scipy.interpolate.KroghInterpolator.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.KroghInterpolator.derivative.html#scipy.interpolate.KroghInterpolator.derivative',
                                   'scipy.interpolate.KroghInterpolator.derivatives': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.KroghInterpolator.derivatives.html#scipy.interpolate.KroghInterpolator.derivatives',
                                   'scipy.interpolate.LSQBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQBivariateSpline.html#scipy.interpolate.LSQBivariateSpline',
                                   'scipy.interpolate.LSQBivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQBivariateSpline.__call__.html#scipy.interpolate.LSQBivariateSpline.__call__',
                                   'scipy.interpolate.LSQBivariateSpline.ev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQBivariateSpline.ev.html#scipy.interpolate.LSQBivariateSpline.ev',
                                   'scipy.interpolate.LSQBivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQBivariateSpline.get_coeffs.html#scipy.interpolate.LSQBivariateSpline.get_coeffs',
                                   'scipy.interpolate.LSQBivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQBivariateSpline.get_knots.html#scipy.interpolate.LSQBivariateSpline.get_knots',
                                   'scipy.interpolate.LSQBivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQBivariateSpline.get_residual.html#scipy.interpolate.LSQBivariateSpline.get_residual',
                                   'scipy.interpolate.LSQBivariateSpline.integral': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQBivariateSpline.integral.html#scipy.interpolate.LSQBivariateSpline.integral',
                                   'scipy.interpolate.LSQBivariateSpline.partial_derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQBivariateSpline.partial_derivative.html#scipy.interpolate.LSQBivariateSpline.partial_derivative',
                                   'scipy.interpolate.LSQSphereBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQSphereBivariateSpline.html#scipy.interpolate.LSQSphereBivariateSpline',
                                   'scipy.interpolate.LSQSphereBivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQSphereBivariateSpline.__call__.html#scipy.interpolate.LSQSphereBivariateSpline.__call__',
                                   'scipy.interpolate.LSQSphereBivariateSpline.ev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQSphereBivariateSpline.ev.html#scipy.interpolate.LSQSphereBivariateSpline.ev',
                                   'scipy.interpolate.LSQSphereBivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQSphereBivariateSpline.get_coeffs.html#scipy.interpolate.LSQSphereBivariateSpline.get_coeffs',
                                   'scipy.interpolate.LSQSphereBivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQSphereBivariateSpline.get_knots.html#scipy.interpolate.LSQSphereBivariateSpline.get_knots',
                                   'scipy.interpolate.LSQSphereBivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQSphereBivariateSpline.get_residual.html#scipy.interpolate.LSQSphereBivariateSpline.get_residual',
                                   'scipy.interpolate.LSQSphereBivariateSpline.partial_derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQSphereBivariateSpline.partial_derivative.html#scipy.interpolate.LSQSphereBivariateSpline.partial_derivative',
                                   'scipy.interpolate.LSQUnivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.html#scipy.interpolate.LSQUnivariateSpline',
                                   'scipy.interpolate.LSQUnivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.__call__.html#scipy.interpolate.LSQUnivariateSpline.__call__',
                                   'scipy.interpolate.LSQUnivariateSpline.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.antiderivative.html#scipy.interpolate.LSQUnivariateSpline.antiderivative',
                                   'scipy.interpolate.LSQUnivariateSpline.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.derivative.html#scipy.interpolate.LSQUnivariateSpline.derivative',
                                   'scipy.interpolate.LSQUnivariateSpline.derivatives': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.derivatives.html#scipy.interpolate.LSQUnivariateSpline.derivatives',
                                   'scipy.interpolate.LSQUnivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.get_coeffs.html#scipy.interpolate.LSQUnivariateSpline.get_coeffs',
                                   'scipy.interpolate.LSQUnivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.get_knots.html#scipy.interpolate.LSQUnivariateSpline.get_knots',
                                   'scipy.interpolate.LSQUnivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.get_residual.html#scipy.interpolate.LSQUnivariateSpline.get_residual',
                                   'scipy.interpolate.LSQUnivariateSpline.integral': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.integral.html#scipy.interpolate.LSQUnivariateSpline.integral',
                                   'scipy.interpolate.LSQUnivariateSpline.roots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.roots.html#scipy.interpolate.LSQUnivariateSpline.roots',
                                   'scipy.interpolate.LSQUnivariateSpline.set_smoothing_factor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.set_smoothing_factor.html#scipy.interpolate.LSQUnivariateSpline.set_smoothing_factor',
                                   'scipy.interpolate.LSQUnivariateSpline.validate_input': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.validate_input.html#scipy.interpolate.LSQUnivariateSpline.validate_input',
                                   'scipy.interpolate.LinearNDInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LinearNDInterpolator.html#scipy.interpolate.LinearNDInterpolator',
                                   'scipy.interpolate.LinearNDInterpolator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LinearNDInterpolator.__call__.html#scipy.interpolate.LinearNDInterpolator.__call__',
                                   'scipy.interpolate.NdPPoly': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NdPPoly.html#scipy.interpolate.NdPPoly',
                                   'scipy.interpolate.NdPPoly.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NdPPoly.__call__.html#scipy.interpolate.NdPPoly.__call__',
                                   'scipy.interpolate.NdPPoly.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NdPPoly.antiderivative.html#scipy.interpolate.NdPPoly.antiderivative',
                                   'scipy.interpolate.NdPPoly.construct_fast': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NdPPoly.construct_fast.html#scipy.interpolate.NdPPoly.construct_fast',
                                   'scipy.interpolate.NdPPoly.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NdPPoly.derivative.html#scipy.interpolate.NdPPoly.derivative',
                                   'scipy.interpolate.NdPPoly.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NdPPoly.integrate.html#scipy.interpolate.NdPPoly.integrate',
                                   'scipy.interpolate.NdPPoly.integrate_1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NdPPoly.integrate_1d.html#scipy.interpolate.NdPPoly.integrate_1d',
                                   'scipy.interpolate.NearestNDInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NearestNDInterpolator.html#scipy.interpolate.NearestNDInterpolator',
                                   'scipy.interpolate.NearestNDInterpolator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NearestNDInterpolator.__call__.html#scipy.interpolate.NearestNDInterpolator.__call__',
                                   'scipy.interpolate.PPoly': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.html#scipy.interpolate.PPoly',
                                   'scipy.interpolate.PPoly.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.__call__.html#scipy.interpolate.PPoly.__call__',
                                   'scipy.interpolate.PPoly.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.antiderivative.html#scipy.interpolate.PPoly.antiderivative',
                                   'scipy.interpolate.PPoly.construct_fast': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.construct_fast.html#scipy.interpolate.PPoly.construct_fast',
                                   'scipy.interpolate.PPoly.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.derivative.html#scipy.interpolate.PPoly.derivative',
                                   'scipy.interpolate.PPoly.extend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.extend.html#scipy.interpolate.PPoly.extend',
                                   'scipy.interpolate.PPoly.from_bernstein_basis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.from_bernstein_basis.html#scipy.interpolate.PPoly.from_bernstein_basis',
                                   'scipy.interpolate.PPoly.from_spline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.from_spline.html#scipy.interpolate.PPoly.from_spline',
                                   'scipy.interpolate.PPoly.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.integrate.html#scipy.interpolate.PPoly.integrate',
                                   'scipy.interpolate.PPoly.roots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.roots.html#scipy.interpolate.PPoly.roots',
                                   'scipy.interpolate.PPoly.solve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.solve.html#scipy.interpolate.PPoly.solve',
                                   'scipy.interpolate.PchipInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.html#scipy.interpolate.PchipInterpolator',
                                   'scipy.interpolate.PchipInterpolator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.__call__.html#scipy.interpolate.PchipInterpolator.__call__',
                                   'scipy.interpolate.PchipInterpolator.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.antiderivative.html#scipy.interpolate.PchipInterpolator.antiderivative',
                                   'scipy.interpolate.PchipInterpolator.construct_fast': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.construct_fast.html#scipy.interpolate.PchipInterpolator.construct_fast',
                                   'scipy.interpolate.PchipInterpolator.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.derivative.html#scipy.interpolate.PchipInterpolator.derivative',
                                   'scipy.interpolate.PchipInterpolator.extend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.extend.html#scipy.interpolate.PchipInterpolator.extend',
                                   'scipy.interpolate.PchipInterpolator.from_bernstein_basis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.from_bernstein_basis.html#scipy.interpolate.PchipInterpolator.from_bernstein_basis',
                                   'scipy.interpolate.PchipInterpolator.from_spline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.from_spline.html#scipy.interpolate.PchipInterpolator.from_spline',
                                   'scipy.interpolate.PchipInterpolator.integrate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.integrate.html#scipy.interpolate.PchipInterpolator.integrate',
                                   'scipy.interpolate.PchipInterpolator.roots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.roots.html#scipy.interpolate.PchipInterpolator.roots',
                                   'scipy.interpolate.PchipInterpolator.solve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.solve.html#scipy.interpolate.PchipInterpolator.solve',
                                   'scipy.interpolate.RBFInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RBFInterpolator.html#scipy.interpolate.RBFInterpolator',
                                   'scipy.interpolate.RBFInterpolator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RBFInterpolator.__call__.html#scipy.interpolate.RBFInterpolator.__call__',
                                   'scipy.interpolate.Rbf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Rbf.html#scipy.interpolate.Rbf',
                                   'scipy.interpolate.Rbf.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Rbf.__call__.html#scipy.interpolate.Rbf.__call__',
                                   'scipy.interpolate.RectBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectBivariateSpline.html#scipy.interpolate.RectBivariateSpline',
                                   'scipy.interpolate.RectBivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectBivariateSpline.__call__.html#scipy.interpolate.RectBivariateSpline.__call__',
                                   'scipy.interpolate.RectBivariateSpline.ev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectBivariateSpline.ev.html#scipy.interpolate.RectBivariateSpline.ev',
                                   'scipy.interpolate.RectBivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectBivariateSpline.get_coeffs.html#scipy.interpolate.RectBivariateSpline.get_coeffs',
                                   'scipy.interpolate.RectBivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectBivariateSpline.get_knots.html#scipy.interpolate.RectBivariateSpline.get_knots',
                                   'scipy.interpolate.RectBivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectBivariateSpline.get_residual.html#scipy.interpolate.RectBivariateSpline.get_residual',
                                   'scipy.interpolate.RectBivariateSpline.integral': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectBivariateSpline.integral.html#scipy.interpolate.RectBivariateSpline.integral',
                                   'scipy.interpolate.RectBivariateSpline.partial_derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectBivariateSpline.partial_derivative.html#scipy.interpolate.RectBivariateSpline.partial_derivative',
                                   'scipy.interpolate.RectSphereBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectSphereBivariateSpline.html#scipy.interpolate.RectSphereBivariateSpline',
                                   'scipy.interpolate.RectSphereBivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectSphereBivariateSpline.__call__.html#scipy.interpolate.RectSphereBivariateSpline.__call__',
                                   'scipy.interpolate.RectSphereBivariateSpline.ev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectSphereBivariateSpline.ev.html#scipy.interpolate.RectSphereBivariateSpline.ev',
                                   'scipy.interpolate.RectSphereBivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectSphereBivariateSpline.get_coeffs.html#scipy.interpolate.RectSphereBivariateSpline.get_coeffs',
                                   'scipy.interpolate.RectSphereBivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectSphereBivariateSpline.get_knots.html#scipy.interpolate.RectSphereBivariateSpline.get_knots',
                                   'scipy.interpolate.RectSphereBivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectSphereBivariateSpline.get_residual.html#scipy.interpolate.RectSphereBivariateSpline.get_residual',
                                   'scipy.interpolate.RectSphereBivariateSpline.partial_derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectSphereBivariateSpline.partial_derivative.html#scipy.interpolate.RectSphereBivariateSpline.partial_derivative',
                                   'scipy.interpolate.RegularGridInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RegularGridInterpolator.html#scipy.interpolate.RegularGridInterpolator',
                                   'scipy.interpolate.RegularGridInterpolator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RegularGridInterpolator.__call__.html#scipy.interpolate.RegularGridInterpolator.__call__',
                                   'scipy.interpolate.SmoothBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothBivariateSpline.html#scipy.interpolate.SmoothBivariateSpline',
                                   'scipy.interpolate.SmoothBivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothBivariateSpline.__call__.html#scipy.interpolate.SmoothBivariateSpline.__call__',
                                   'scipy.interpolate.SmoothBivariateSpline.ev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothBivariateSpline.ev.html#scipy.interpolate.SmoothBivariateSpline.ev',
                                   'scipy.interpolate.SmoothBivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothBivariateSpline.get_coeffs.html#scipy.interpolate.SmoothBivariateSpline.get_coeffs',
                                   'scipy.interpolate.SmoothBivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothBivariateSpline.get_knots.html#scipy.interpolate.SmoothBivariateSpline.get_knots',
                                   'scipy.interpolate.SmoothBivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothBivariateSpline.get_residual.html#scipy.interpolate.SmoothBivariateSpline.get_residual',
                                   'scipy.interpolate.SmoothBivariateSpline.integral': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothBivariateSpline.integral.html#scipy.interpolate.SmoothBivariateSpline.integral',
                                   'scipy.interpolate.SmoothBivariateSpline.partial_derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothBivariateSpline.partial_derivative.html#scipy.interpolate.SmoothBivariateSpline.partial_derivative',
                                   'scipy.interpolate.SmoothSphereBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothSphereBivariateSpline.html#scipy.interpolate.SmoothSphereBivariateSpline',
                                   'scipy.interpolate.SmoothSphereBivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothSphereBivariateSpline.__call__.html#scipy.interpolate.SmoothSphereBivariateSpline.__call__',
                                   'scipy.interpolate.SmoothSphereBivariateSpline.ev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothSphereBivariateSpline.ev.html#scipy.interpolate.SmoothSphereBivariateSpline.ev',
                                   'scipy.interpolate.SmoothSphereBivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothSphereBivariateSpline.get_coeffs.html#scipy.interpolate.SmoothSphereBivariateSpline.get_coeffs',
                                   'scipy.interpolate.SmoothSphereBivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothSphereBivariateSpline.get_knots.html#scipy.interpolate.SmoothSphereBivariateSpline.get_knots',
                                   'scipy.interpolate.SmoothSphereBivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothSphereBivariateSpline.get_residual.html#scipy.interpolate.SmoothSphereBivariateSpline.get_residual',
                                   'scipy.interpolate.SmoothSphereBivariateSpline.partial_derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothSphereBivariateSpline.partial_derivative.html#scipy.interpolate.SmoothSphereBivariateSpline.partial_derivative',
                                   'scipy.interpolate.UnivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.html#scipy.interpolate.UnivariateSpline',
                                   'scipy.interpolate.UnivariateSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.__call__.html#scipy.interpolate.UnivariateSpline.__call__',
                                   'scipy.interpolate.UnivariateSpline.antiderivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.antiderivative.html#scipy.interpolate.UnivariateSpline.antiderivative',
                                   'scipy.interpolate.UnivariateSpline.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.derivative.html#scipy.interpolate.UnivariateSpline.derivative',
                                   'scipy.interpolate.UnivariateSpline.derivatives': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.derivatives.html#scipy.interpolate.UnivariateSpline.derivatives',
                                   'scipy.interpolate.UnivariateSpline.get_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.get_coeffs.html#scipy.interpolate.UnivariateSpline.get_coeffs',
                                   'scipy.interpolate.UnivariateSpline.get_knots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.get_knots.html#scipy.interpolate.UnivariateSpline.get_knots',
                                   'scipy.interpolate.UnivariateSpline.get_residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.get_residual.html#scipy.interpolate.UnivariateSpline.get_residual',
                                   'scipy.interpolate.UnivariateSpline.integral': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.integral.html#scipy.interpolate.UnivariateSpline.integral',
                                   'scipy.interpolate.UnivariateSpline.roots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.roots.html#scipy.interpolate.UnivariateSpline.roots',
                                   'scipy.interpolate.UnivariateSpline.set_smoothing_factor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.set_smoothing_factor.html#scipy.interpolate.UnivariateSpline.set_smoothing_factor',
                                   'scipy.interpolate.UnivariateSpline.validate_input': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.validate_input.html#scipy.interpolate.UnivariateSpline.validate_input',
                                   'scipy.interpolate.approximate_taylor_polynomial': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.approximate_taylor_polynomial.html#scipy.interpolate.approximate_taylor_polynomial',
                                   'scipy.interpolate.barycentric_interpolate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.barycentric_interpolate.html#scipy.interpolate.barycentric_interpolate',
                                   'scipy.interpolate.bisplev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.bisplev.html#scipy.interpolate.bisplev',
                                   'scipy.interpolate.bisplrep': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.bisplrep.html#scipy.interpolate.bisplrep',
                                   'scipy.interpolate.griddata': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.griddata.html#scipy.interpolate.griddata',
                                   'scipy.interpolate.insert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.insert.html#scipy.interpolate.insert',
                                   'scipy.interpolate.interp1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.interp1d.html#scipy.interpolate.interp1d',
                                   'scipy.interpolate.interp1d.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.interp1d.__call__.html#scipy.interpolate.interp1d.__call__',
                                   'scipy.interpolate.interp2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.interp2d.html#scipy.interpolate.interp2d',
                                   'scipy.interpolate.interp2d.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.interp2d.__call__.html#scipy.interpolate.interp2d.__call__',
                                   'scipy.interpolate.interpn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.interpn.html#scipy.interpolate.interpn',
                                   'scipy.interpolate.krogh_interpolate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.krogh_interpolate.html#scipy.interpolate.krogh_interpolate',
                                   'scipy.interpolate.lagrange': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.lagrange.html#scipy.interpolate.lagrange',
                                   'scipy.interpolate.make_interp_spline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.make_interp_spline.html#scipy.interpolate.make_interp_spline',
                                   'scipy.interpolate.make_lsq_spline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.make_lsq_spline.html#scipy.interpolate.make_lsq_spline',
                                   'scipy.interpolate.pade': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.pade.html#scipy.interpolate.pade',
                                   'scipy.interpolate.pchip_interpolate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.pchip_interpolate.html#scipy.interpolate.pchip_interpolate',
                                   'scipy.interpolate.spalde': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.spalde.html#scipy.interpolate.spalde',
                                   'scipy.interpolate.splantider': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.splantider.html#scipy.interpolate.splantider',
                                   'scipy.interpolate.splder': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.splder.html#scipy.interpolate.splder',
                                   'scipy.interpolate.splev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.splev.html#scipy.interpolate.splev',
                                   'scipy.interpolate.splint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.splint.html#scipy.interpolate.splint',
                                   'scipy.interpolate.splprep': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.splprep.html#scipy.interpolate.splprep',
                                   'scipy.interpolate.splrep': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.splrep.html#scipy.interpolate.splrep',
                                   'scipy.interpolate.sproot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.sproot.html#scipy.interpolate.sproot'},
            'scipy.interpolate._bsplines': { 'scipy.interpolate._bsplines.BSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BSpline.html#scipy.interpolate.BSpline'},
            'scipy.interpolate._cubic': { 'scipy.interpolate._cubic.Akima1DInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Akima1DInterpolator.html#scipy.interpolate.Akima1DInterpolator',
                                          'scipy.interpolate._cubic.CubicHermiteSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicHermiteSpline.html#scipy.interpolate.CubicHermiteSpline',
                                          'scipy.interpolate._cubic.CubicSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CubicSpline.html#scipy.interpolate.CubicSpline',
                                          'scipy.interpolate._cubic.PchipInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PchipInterpolator.html#scipy.interpolate.PchipInterpolator'},
            'scipy.interpolate._fitpack2': { 'scipy.interpolate._fitpack2.BivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BivariateSpline.html#scipy.interpolate.BivariateSpline',
                                             'scipy.interpolate._fitpack2.InterpolatedUnivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.InterpolatedUnivariateSpline.html#scipy.interpolate.InterpolatedUnivariateSpline',
                                             'scipy.interpolate._fitpack2.LSQBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQBivariateSpline.html#scipy.interpolate.LSQBivariateSpline',
                                             'scipy.interpolate._fitpack2.LSQSphereBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQSphereBivariateSpline.html#scipy.interpolate.LSQSphereBivariateSpline',
                                             'scipy.interpolate._fitpack2.LSQUnivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LSQUnivariateSpline.html#scipy.interpolate.LSQUnivariateSpline',
                                             'scipy.interpolate._fitpack2.RectBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectBivariateSpline.html#scipy.interpolate.RectBivariateSpline',
                                             'scipy.interpolate._fitpack2.RectSphereBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RectSphereBivariateSpline.html#scipy.interpolate.RectSphereBivariateSpline',
                                             'scipy.interpolate._fitpack2.SmoothBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothBivariateSpline.html#scipy.interpolate.SmoothBivariateSpline',
                                             'scipy.interpolate._fitpack2.SmoothSphereBivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.SmoothSphereBivariateSpline.html#scipy.interpolate.SmoothSphereBivariateSpline',
                                             'scipy.interpolate._fitpack2.UnivariateSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.UnivariateSpline.html#scipy.interpolate.UnivariateSpline'},
            'scipy.interpolate._interpolate': { 'scipy.interpolate._interpolate.BPoly': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BPoly.html#scipy.interpolate.BPoly',
                                                'scipy.interpolate._interpolate.NdPPoly': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NdPPoly.html#scipy.interpolate.NdPPoly',
                                                'scipy.interpolate._interpolate.PPoly': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.PPoly.html#scipy.interpolate.PPoly',
                                                'scipy.interpolate._interpolate.interp1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.interp1d.html#scipy.interpolate.interp1d',
                                                'scipy.interpolate._interpolate.interp2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.interp2d.html#scipy.interpolate.interp2d'},
            'scipy.interpolate._ndgriddata': { 'scipy.interpolate._ndgriddata.NearestNDInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.NearestNDInterpolator.html#scipy.interpolate.NearestNDInterpolator'},
            'scipy.interpolate._polyint': { 'scipy.interpolate._polyint.BarycentricInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.BarycentricInterpolator.html#scipy.interpolate.BarycentricInterpolator',
                                            'scipy.interpolate._polyint.KroghInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.KroghInterpolator.html#scipy.interpolate.KroghInterpolator'},
            'scipy.interpolate._rbf': { 'scipy.interpolate._rbf.Rbf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.Rbf.html#scipy.interpolate.Rbf'},
            'scipy.interpolate._rbfinterp': { 'scipy.interpolate._rbfinterp.RBFInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RBFInterpolator.html#scipy.interpolate.RBFInterpolator'},
            'scipy.interpolate._rgi': { 'scipy.interpolate._rgi.RegularGridInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.RegularGridInterpolator.html#scipy.interpolate.RegularGridInterpolator'},
            'scipy.interpolate.interpnd': { 'scipy.interpolate.interpnd.CloughTocher2DInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.CloughTocher2DInterpolator.html#scipy.interpolate.CloughTocher2DInterpolator',
                                            'scipy.interpolate.interpnd.LinearNDInterpolator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.interpolate.LinearNDInterpolator.html#scipy.interpolate.LinearNDInterpolator'},
            'scipy.io': { 'scipy.io.FortranEOFError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.FortranEOFError.html#scipy.io.FortranEOFError.with_traceback',
                          'scipy.io.FortranFile': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.FortranFile.html#scipy.io.FortranFile',
                          'scipy.io.FortranFile.close': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.FortranFile.close.html#scipy.io.FortranFile.close',
                          'scipy.io.FortranFile.read_ints': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.FortranFile.read_ints.html#scipy.io.FortranFile.read_ints',
                          'scipy.io.FortranFile.read_reals': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.FortranFile.read_reals.html#scipy.io.FortranFile.read_reals',
                          'scipy.io.FortranFile.read_record': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.FortranFile.read_record.html#scipy.io.FortranFile.read_record',
                          'scipy.io.FortranFile.write_record': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.FortranFile.write_record.html#scipy.io.FortranFile.write_record',
                          'scipy.io.FortranFormattingError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.FortranFormattingError.html#scipy.io.FortranFormattingError.with_traceback',
                          'scipy.io.arff': 'https://docs.scipy.org/doc/scipy/reference/reference/io.html#module-scipy.io.arff',
                          'scipy.io.hb_read': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.hb_read.html#scipy.io.hb_read',
                          'scipy.io.hb_write': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.hb_write.html#scipy.io.hb_write',
                          'scipy.io.loadmat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.loadmat.html#scipy.io.loadmat',
                          'scipy.io.matlab': 'https://docs.scipy.org/doc/scipy/reference/reference/io.matlab.html#module-scipy.io.matlab',
                          'scipy.io.mminfo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.mminfo.html#scipy.io.mminfo',
                          'scipy.io.mmread': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.mmread.html#scipy.io.mmread',
                          'scipy.io.mmwrite': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.mmwrite.html#scipy.io.mmwrite',
                          'scipy.io.netcdf_file': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_file.html#scipy.io.netcdf_file',
                          'scipy.io.netcdf_file.close': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_file.close.html#scipy.io.netcdf_file.close',
                          'scipy.io.netcdf_file.createDimension': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_file.createDimension.html#scipy.io.netcdf_file.createDimension',
                          'scipy.io.netcdf_file.createVariable': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_file.createVariable.html#scipy.io.netcdf_file.createVariable',
                          'scipy.io.netcdf_file.flush': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_file.flush.html#scipy.io.netcdf_file.flush',
                          'scipy.io.netcdf_file.sync': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_file.sync.html#scipy.io.netcdf_file.sync',
                          'scipy.io.netcdf_variable': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_variable.html#scipy.io.netcdf_variable',
                          'scipy.io.netcdf_variable.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_variable.__getitem__.html#scipy.io.netcdf_variable.__getitem__',
                          'scipy.io.netcdf_variable.assignValue': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_variable.assignValue.html#scipy.io.netcdf_variable.assignValue',
                          'scipy.io.netcdf_variable.getValue': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_variable.getValue.html#scipy.io.netcdf_variable.getValue',
                          'scipy.io.netcdf_variable.itemsize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_variable.itemsize.html#scipy.io.netcdf_variable.itemsize',
                          'scipy.io.netcdf_variable.typecode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_variable.typecode.html#scipy.io.netcdf_variable.typecode',
                          'scipy.io.readsav': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.readsav.html#scipy.io.readsav',
                          'scipy.io.savemat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.savemat.html#scipy.io.savemat',
                          'scipy.io.wavfile': 'https://docs.scipy.org/doc/scipy/reference/reference/io.html#module-scipy.io.wavfile',
                          'scipy.io.whosmat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.whosmat.html#scipy.io.whosmat'},
            'scipy.io._fortran': { 'scipy.io._fortran.FortranFile': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.FortranFile.html#scipy.io.FortranFile'},
            'scipy.io._netcdf': { 'scipy.io._netcdf.netcdf_file': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_file.html#scipy.io.netcdf_file',
                                  'scipy.io._netcdf.netcdf_variable': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.netcdf_variable.html#scipy.io.netcdf_variable'},
            'scipy.io.arff': { 'scipy.io.arff.ArffError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.arff.ArffError.html#scipy.io.arff.ArffError.with_traceback',
                               'scipy.io.arff.MetaData': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.arff.MetaData.html#scipy.io.arff.MetaData',
                               'scipy.io.arff.MetaData.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.arff.MetaData.__getitem__.html#scipy.io.arff.MetaData.__getitem__',
                               'scipy.io.arff.MetaData.names': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.arff.MetaData.names.html#scipy.io.arff.MetaData.names',
                               'scipy.io.arff.MetaData.types': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.arff.MetaData.types.html#scipy.io.arff.MetaData.types',
                               'scipy.io.arff.ParseArffError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.arff.ParseArffError.html#scipy.io.arff.ParseArffError.with_traceback',
                               'scipy.io.arff.loadarff': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.arff.loadarff.html#scipy.io.arff.loadarff'},
            'scipy.io.arff._arffread': { 'scipy.io.arff._arffread.MetaData': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.arff.MetaData.html#scipy.io.arff.MetaData'},
            'scipy.io.matlab': { 'scipy.io.matlab.MatReadError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.MatReadError.html#scipy.io.matlab.MatReadError.with_traceback',
                                 'scipy.io.matlab.MatReadWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.MatReadWarning.html#scipy.io.matlab.MatReadWarning.with_traceback',
                                 'scipy.io.matlab.MatWriteError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.MatWriteError.html#scipy.io.matlab.MatWriteError.with_traceback',
                                 'scipy.io.matlab.MatlabFunction': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.MatlabFunction.html#scipy.io.matlab.MatlabFunction',
                                 'scipy.io.matlab.MatlabObject': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.MatlabObject.html#scipy.io.matlab.MatlabObject',
                                 'scipy.io.matlab.MatlabOpaque': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.MatlabOpaque.html#scipy.io.matlab.MatlabOpaque',
                                 'scipy.io.matlab.loadmat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.loadmat.html#scipy.io.matlab.loadmat',
                                 'scipy.io.matlab.mat_struct': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.mat_struct.html#scipy.io.matlab.mat_struct',
                                 'scipy.io.matlab.matfile_version': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.matfile_version.html#scipy.io.matlab.matfile_version',
                                 'scipy.io.matlab.savemat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.savemat.html#scipy.io.matlab.savemat',
                                 'scipy.io.matlab.whosmat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.whosmat.html#scipy.io.matlab.whosmat'},
            'scipy.io.matlab._mio5_params': { 'scipy.io.matlab._mio5_params.mat_struct': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.matlab.mat_struct.html#scipy.io.matlab.mat_struct'},
            'scipy.io.wavfile': { 'scipy.io.wavfile.WavFileWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.wavfile.WavFileWarning.html#scipy.io.wavfile.WavFileWarning.with_traceback',
                                  'scipy.io.wavfile.read': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.wavfile.read.html#scipy.io.wavfile.read',
                                  'scipy.io.wavfile.write': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.io.wavfile.write.html#scipy.io.wavfile.write'},
            'scipy.linalg': { 'scipy.linalg.LinAlgError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.LinAlgError.html#scipy.linalg.LinAlgError.with_traceback',
                              'scipy.linalg.LinAlgWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.LinAlgWarning.html#scipy.linalg.LinAlgWarning.with_traceback',
                              'scipy.linalg.bandwidth': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.bandwidth.html#scipy.linalg.bandwidth',
                              'scipy.linalg.blas': 'https://docs.scipy.org/doc/scipy/reference/reference/linalg.blas.html#module-scipy.linalg.blas',
                              'scipy.linalg.block_diag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.block_diag.html#scipy.linalg.block_diag',
                              'scipy.linalg.cdf2rdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.cdf2rdf.html#scipy.linalg.cdf2rdf',
                              'scipy.linalg.cho_factor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.cho_factor.html#scipy.linalg.cho_factor',
                              'scipy.linalg.cho_solve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.cho_solve.html#scipy.linalg.cho_solve',
                              'scipy.linalg.cho_solve_banded': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.cho_solve_banded.html#scipy.linalg.cho_solve_banded',
                              'scipy.linalg.cholesky': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.cholesky.html#scipy.linalg.cholesky',
                              'scipy.linalg.cholesky_banded': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.cholesky_banded.html#scipy.linalg.cholesky_banded',
                              'scipy.linalg.circulant': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.circulant.html#scipy.linalg.circulant',
                              'scipy.linalg.clarkson_woodruff_transform': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.clarkson_woodruff_transform.html#scipy.linalg.clarkson_woodruff_transform',
                              'scipy.linalg.companion': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.companion.html#scipy.linalg.companion',
                              'scipy.linalg.convolution_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.convolution_matrix.html#scipy.linalg.convolution_matrix',
                              'scipy.linalg.coshm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.coshm.html#scipy.linalg.coshm',
                              'scipy.linalg.cosm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.cosm.html#scipy.linalg.cosm',
                              'scipy.linalg.cossin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.cossin.html#scipy.linalg.cossin',
                              'scipy.linalg.cython_blas': 'https://docs.scipy.org/doc/scipy/reference/reference/linalg.cython_blas.html#module-scipy.linalg.cython_blas',
                              'scipy.linalg.cython_lapack': 'https://docs.scipy.org/doc/scipy/reference/reference/linalg.cython_lapack.html#module-scipy.linalg.cython_lapack',
                              'scipy.linalg.det': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.det.html#scipy.linalg.det',
                              'scipy.linalg.dft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.dft.html#scipy.linalg.dft',
                              'scipy.linalg.diagsvd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.diagsvd.html#scipy.linalg.diagsvd',
                              'scipy.linalg.eig': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.eig.html#scipy.linalg.eig',
                              'scipy.linalg.eig_banded': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.eig_banded.html#scipy.linalg.eig_banded',
                              'scipy.linalg.eigh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.eigh.html#scipy.linalg.eigh',
                              'scipy.linalg.eigh_tridiagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.eigh_tridiagonal.html#scipy.linalg.eigh_tridiagonal',
                              'scipy.linalg.eigvals': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.eigvals.html#scipy.linalg.eigvals',
                              'scipy.linalg.eigvals_banded': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.eigvals_banded.html#scipy.linalg.eigvals_banded',
                              'scipy.linalg.eigvalsh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.eigvalsh.html#scipy.linalg.eigvalsh',
                              'scipy.linalg.eigvalsh_tridiagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.eigvalsh_tridiagonal.html#scipy.linalg.eigvalsh_tridiagonal',
                              'scipy.linalg.expm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.expm.html#scipy.linalg.expm',
                              'scipy.linalg.expm_cond': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.expm_cond.html#scipy.linalg.expm_cond',
                              'scipy.linalg.expm_frechet': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.expm_frechet.html#scipy.linalg.expm_frechet',
                              'scipy.linalg.fiedler': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.fiedler.html#scipy.linalg.fiedler',
                              'scipy.linalg.fiedler_companion': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.fiedler_companion.html#scipy.linalg.fiedler_companion',
                              'scipy.linalg.find_best_blas_type': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.find_best_blas_type.html#scipy.linalg.find_best_blas_type',
                              'scipy.linalg.fractional_matrix_power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.fractional_matrix_power.html#scipy.linalg.fractional_matrix_power',
                              'scipy.linalg.funm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.funm.html#scipy.linalg.funm',
                              'scipy.linalg.get_blas_funcs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.get_blas_funcs.html#scipy.linalg.get_blas_funcs',
                              'scipy.linalg.get_lapack_funcs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.get_lapack_funcs.html#scipy.linalg.get_lapack_funcs',
                              'scipy.linalg.hadamard': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.hadamard.html#scipy.linalg.hadamard',
                              'scipy.linalg.hankel': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.hankel.html#scipy.linalg.hankel',
                              'scipy.linalg.helmert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.helmert.html#scipy.linalg.helmert',
                              'scipy.linalg.hessenberg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.hessenberg.html#scipy.linalg.hessenberg',
                              'scipy.linalg.hilbert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.hilbert.html#scipy.linalg.hilbert',
                              'scipy.linalg.interpolative': 'https://docs.scipy.org/doc/scipy/reference/reference/linalg.interpolative.html#module-scipy.linalg.interpolative',
                              'scipy.linalg.inv': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.inv.html#scipy.linalg.inv',
                              'scipy.linalg.invhilbert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.invhilbert.html#scipy.linalg.invhilbert',
                              'scipy.linalg.invpascal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.invpascal.html#scipy.linalg.invpascal',
                              'scipy.linalg.ishermitian': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.ishermitian.html#scipy.linalg.ishermitian',
                              'scipy.linalg.issymmetric': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.issymmetric.html#scipy.linalg.issymmetric',
                              'scipy.linalg.khatri_rao': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.khatri_rao.html#scipy.linalg.khatri_rao',
                              'scipy.linalg.kron': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.kron.html#scipy.linalg.kron',
                              'scipy.linalg.lapack': 'https://docs.scipy.org/doc/scipy/reference/reference/linalg.lapack.html#module-scipy.linalg.lapack',
                              'scipy.linalg.ldl': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.ldl.html#scipy.linalg.ldl',
                              'scipy.linalg.leslie': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.leslie.html#scipy.linalg.leslie',
                              'scipy.linalg.logm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.logm.html#scipy.linalg.logm',
                              'scipy.linalg.lstsq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.lstsq.html#scipy.linalg.lstsq',
                              'scipy.linalg.lu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.lu.html#scipy.linalg.lu',
                              'scipy.linalg.lu_factor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.lu_factor.html#scipy.linalg.lu_factor',
                              'scipy.linalg.lu_solve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.lu_solve.html#scipy.linalg.lu_solve',
                              'scipy.linalg.matmul_toeplitz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.matmul_toeplitz.html#scipy.linalg.matmul_toeplitz',
                              'scipy.linalg.matrix_balance': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.matrix_balance.html#scipy.linalg.matrix_balance',
                              'scipy.linalg.norm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.norm.html#scipy.linalg.norm',
                              'scipy.linalg.null_space': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.null_space.html#scipy.linalg.null_space',
                              'scipy.linalg.ordqz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.ordqz.html#scipy.linalg.ordqz',
                              'scipy.linalg.orth': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.orth.html#scipy.linalg.orth',
                              'scipy.linalg.orthogonal_procrustes': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.orthogonal_procrustes.html#scipy.linalg.orthogonal_procrustes',
                              'scipy.linalg.pascal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.pascal.html#scipy.linalg.pascal',
                              'scipy.linalg.pinv': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.pinv.html#scipy.linalg.pinv',
                              'scipy.linalg.pinvh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.pinvh.html#scipy.linalg.pinvh',
                              'scipy.linalg.polar': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.polar.html#scipy.linalg.polar',
                              'scipy.linalg.qr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.qr.html#scipy.linalg.qr',
                              'scipy.linalg.qr_delete': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.qr_delete.html#scipy.linalg.qr_delete',
                              'scipy.linalg.qr_insert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.qr_insert.html#scipy.linalg.qr_insert',
                              'scipy.linalg.qr_multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.qr_multiply.html#scipy.linalg.qr_multiply',
                              'scipy.linalg.qr_update': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.qr_update.html#scipy.linalg.qr_update',
                              'scipy.linalg.qz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.qz.html#scipy.linalg.qz',
                              'scipy.linalg.rq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.rq.html#scipy.linalg.rq',
                              'scipy.linalg.rsf2csf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.rsf2csf.html#scipy.linalg.rsf2csf',
                              'scipy.linalg.schur': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.schur.html#scipy.linalg.schur',
                              'scipy.linalg.signm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.signm.html#scipy.linalg.signm',
                              'scipy.linalg.sinhm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.sinhm.html#scipy.linalg.sinhm',
                              'scipy.linalg.sinm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.sinm.html#scipy.linalg.sinm',
                              'scipy.linalg.solve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve.html#scipy.linalg.solve',
                              'scipy.linalg.solve_banded': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve_banded.html#scipy.linalg.solve_banded',
                              'scipy.linalg.solve_circulant': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve_circulant.html#scipy.linalg.solve_circulant',
                              'scipy.linalg.solve_continuous_are': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve_continuous_are.html#scipy.linalg.solve_continuous_are',
                              'scipy.linalg.solve_continuous_lyapunov': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve_continuous_lyapunov.html#scipy.linalg.solve_continuous_lyapunov',
                              'scipy.linalg.solve_discrete_are': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve_discrete_are.html#scipy.linalg.solve_discrete_are',
                              'scipy.linalg.solve_discrete_lyapunov': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve_discrete_lyapunov.html#scipy.linalg.solve_discrete_lyapunov',
                              'scipy.linalg.solve_sylvester': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve_sylvester.html#scipy.linalg.solve_sylvester',
                              'scipy.linalg.solve_toeplitz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve_toeplitz.html#scipy.linalg.solve_toeplitz',
                              'scipy.linalg.solve_triangular': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solve_triangular.html#scipy.linalg.solve_triangular',
                              'scipy.linalg.solveh_banded': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.solveh_banded.html#scipy.linalg.solveh_banded',
                              'scipy.linalg.sqrtm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.sqrtm.html#scipy.linalg.sqrtm',
                              'scipy.linalg.subspace_angles': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.subspace_angles.html#scipy.linalg.subspace_angles',
                              'scipy.linalg.svd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.svd.html#scipy.linalg.svd',
                              'scipy.linalg.svdvals': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.svdvals.html#scipy.linalg.svdvals',
                              'scipy.linalg.tanhm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.tanhm.html#scipy.linalg.tanhm',
                              'scipy.linalg.tanm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.tanm.html#scipy.linalg.tanm',
                              'scipy.linalg.toeplitz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.toeplitz.html#scipy.linalg.toeplitz',
                              'scipy.linalg.tri': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.tri.html#scipy.linalg.tri',
                              'scipy.linalg.tril': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.tril.html#scipy.linalg.tril',
                              'scipy.linalg.triu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.triu.html#scipy.linalg.triu'},
            'scipy.linalg.blas': { 'scipy.linalg.blas.find_best_blas_type': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.blas.find_best_blas_type.html#scipy.linalg.blas.find_best_blas_type',
                                   'scipy.linalg.blas.get_blas_funcs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.blas.get_blas_funcs.html#scipy.linalg.blas.get_blas_funcs'},
            'scipy.linalg.interpolative': { 'scipy.linalg.interpolative.estimate_rank': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.estimate_rank.html#scipy.linalg.interpolative.estimate_rank',
                                            'scipy.linalg.interpolative.estimate_spectral_norm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.estimate_spectral_norm.html#scipy.linalg.interpolative.estimate_spectral_norm',
                                            'scipy.linalg.interpolative.estimate_spectral_norm_diff': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.estimate_spectral_norm_diff.html#scipy.linalg.interpolative.estimate_spectral_norm_diff',
                                            'scipy.linalg.interpolative.id_to_svd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.id_to_svd.html#scipy.linalg.interpolative.id_to_svd',
                                            'scipy.linalg.interpolative.interp_decomp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.interp_decomp.html#scipy.linalg.interpolative.interp_decomp',
                                            'scipy.linalg.interpolative.rand': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.rand.html#scipy.linalg.interpolative.rand',
                                            'scipy.linalg.interpolative.reconstruct_interp_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.reconstruct_interp_matrix.html#scipy.linalg.interpolative.reconstruct_interp_matrix',
                                            'scipy.linalg.interpolative.reconstruct_matrix_from_id': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.reconstruct_matrix_from_id.html#scipy.linalg.interpolative.reconstruct_matrix_from_id',
                                            'scipy.linalg.interpolative.reconstruct_skel_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.reconstruct_skel_matrix.html#scipy.linalg.interpolative.reconstruct_skel_matrix',
                                            'scipy.linalg.interpolative.seed': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.seed.html#scipy.linalg.interpolative.seed',
                                            'scipy.linalg.interpolative.svd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.interpolative.svd.html#scipy.linalg.interpolative.svd'},
            'scipy.linalg.lapack': { 'scipy.linalg.lapack.get_lapack_funcs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.linalg.lapack.get_lapack_funcs.html#scipy.linalg.lapack.get_lapack_funcs'},
            'scipy.misc': { 'scipy.misc.ascent': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.misc.ascent.html#scipy.misc.ascent',
                            'scipy.misc.central_diff_weights': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.misc.central_diff_weights.html#scipy.misc.central_diff_weights',
                            'scipy.misc.derivative': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.misc.derivative.html#scipy.misc.derivative',
                            'scipy.misc.electrocardiogram': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.misc.electrocardiogram.html#scipy.misc.electrocardiogram',
                            'scipy.misc.face': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.misc.face.html#scipy.misc.face'},
            'scipy.ndimage': { 'scipy.ndimage.affine_transform': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.affine_transform.html#scipy.ndimage.affine_transform',
                               'scipy.ndimage.binary_closing': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.binary_closing.html#scipy.ndimage.binary_closing',
                               'scipy.ndimage.binary_dilation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.binary_dilation.html#scipy.ndimage.binary_dilation',
                               'scipy.ndimage.binary_erosion': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.binary_erosion.html#scipy.ndimage.binary_erosion',
                               'scipy.ndimage.binary_fill_holes': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.binary_fill_holes.html#scipy.ndimage.binary_fill_holes',
                               'scipy.ndimage.binary_hit_or_miss': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.binary_hit_or_miss.html#scipy.ndimage.binary_hit_or_miss',
                               'scipy.ndimage.binary_opening': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.binary_opening.html#scipy.ndimage.binary_opening',
                               'scipy.ndimage.binary_propagation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.binary_propagation.html#scipy.ndimage.binary_propagation',
                               'scipy.ndimage.black_tophat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.black_tophat.html#scipy.ndimage.black_tophat',
                               'scipy.ndimage.center_of_mass': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.center_of_mass.html#scipy.ndimage.center_of_mass',
                               'scipy.ndimage.convolve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.convolve.html#scipy.ndimage.convolve',
                               'scipy.ndimage.convolve1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.convolve1d.html#scipy.ndimage.convolve1d',
                               'scipy.ndimage.correlate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.correlate.html#scipy.ndimage.correlate',
                               'scipy.ndimage.correlate1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.correlate1d.html#scipy.ndimage.correlate1d',
                               'scipy.ndimage.distance_transform_bf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.distance_transform_bf.html#scipy.ndimage.distance_transform_bf',
                               'scipy.ndimage.distance_transform_cdt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.distance_transform_cdt.html#scipy.ndimage.distance_transform_cdt',
                               'scipy.ndimage.distance_transform_edt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.distance_transform_edt.html#scipy.ndimage.distance_transform_edt',
                               'scipy.ndimage.extrema': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.extrema.html#scipy.ndimage.extrema',
                               'scipy.ndimage.find_objects': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.find_objects.html#scipy.ndimage.find_objects',
                               'scipy.ndimage.fourier_ellipsoid': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.fourier_ellipsoid.html#scipy.ndimage.fourier_ellipsoid',
                               'scipy.ndimage.fourier_gaussian': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.fourier_gaussian.html#scipy.ndimage.fourier_gaussian',
                               'scipy.ndimage.fourier_shift': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.fourier_shift.html#scipy.ndimage.fourier_shift',
                               'scipy.ndimage.fourier_uniform': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.fourier_uniform.html#scipy.ndimage.fourier_uniform',
                               'scipy.ndimage.gaussian_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.gaussian_filter.html#scipy.ndimage.gaussian_filter',
                               'scipy.ndimage.gaussian_filter1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.gaussian_filter1d.html#scipy.ndimage.gaussian_filter1d',
                               'scipy.ndimage.gaussian_gradient_magnitude': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.gaussian_gradient_magnitude.html#scipy.ndimage.gaussian_gradient_magnitude',
                               'scipy.ndimage.gaussian_laplace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.gaussian_laplace.html#scipy.ndimage.gaussian_laplace',
                               'scipy.ndimage.generate_binary_structure': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.generate_binary_structure.html#scipy.ndimage.generate_binary_structure',
                               'scipy.ndimage.generic_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.generic_filter.html#scipy.ndimage.generic_filter',
                               'scipy.ndimage.generic_filter1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.generic_filter1d.html#scipy.ndimage.generic_filter1d',
                               'scipy.ndimage.generic_gradient_magnitude': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.generic_gradient_magnitude.html#scipy.ndimage.generic_gradient_magnitude',
                               'scipy.ndimage.generic_laplace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.generic_laplace.html#scipy.ndimage.generic_laplace',
                               'scipy.ndimage.geometric_transform': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.geometric_transform.html#scipy.ndimage.geometric_transform',
                               'scipy.ndimage.grey_closing': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.grey_closing.html#scipy.ndimage.grey_closing',
                               'scipy.ndimage.grey_dilation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.grey_dilation.html#scipy.ndimage.grey_dilation',
                               'scipy.ndimage.grey_erosion': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.grey_erosion.html#scipy.ndimage.grey_erosion',
                               'scipy.ndimage.grey_opening': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.grey_opening.html#scipy.ndimage.grey_opening',
                               'scipy.ndimage.histogram': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.histogram.html#scipy.ndimage.histogram',
                               'scipy.ndimage.iterate_structure': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.iterate_structure.html#scipy.ndimage.iterate_structure',
                               'scipy.ndimage.label': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.label.html#scipy.ndimage.label',
                               'scipy.ndimage.labeled_comprehension': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.labeled_comprehension.html#scipy.ndimage.labeled_comprehension',
                               'scipy.ndimage.laplace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.laplace.html#scipy.ndimage.laplace',
                               'scipy.ndimage.map_coordinates': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.map_coordinates.html#scipy.ndimage.map_coordinates',
                               'scipy.ndimage.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.maximum.html#scipy.ndimage.maximum',
                               'scipy.ndimage.maximum_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.maximum_filter.html#scipy.ndimage.maximum_filter',
                               'scipy.ndimage.maximum_filter1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.maximum_filter1d.html#scipy.ndimage.maximum_filter1d',
                               'scipy.ndimage.maximum_position': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.maximum_position.html#scipy.ndimage.maximum_position',
                               'scipy.ndimage.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.mean.html#scipy.ndimage.mean',
                               'scipy.ndimage.median': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.median.html#scipy.ndimage.median',
                               'scipy.ndimage.median_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.median_filter.html#scipy.ndimage.median_filter',
                               'scipy.ndimage.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.minimum.html#scipy.ndimage.minimum',
                               'scipy.ndimage.minimum_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.minimum_filter.html#scipy.ndimage.minimum_filter',
                               'scipy.ndimage.minimum_filter1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.minimum_filter1d.html#scipy.ndimage.minimum_filter1d',
                               'scipy.ndimage.minimum_position': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.minimum_position.html#scipy.ndimage.minimum_position',
                               'scipy.ndimage.morphological_gradient': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.morphological_gradient.html#scipy.ndimage.morphological_gradient',
                               'scipy.ndimage.morphological_laplace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.morphological_laplace.html#scipy.ndimage.morphological_laplace',
                               'scipy.ndimage.percentile_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.percentile_filter.html#scipy.ndimage.percentile_filter',
                               'scipy.ndimage.prewitt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.prewitt.html#scipy.ndimage.prewitt',
                               'scipy.ndimage.rank_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.rank_filter.html#scipy.ndimage.rank_filter',
                               'scipy.ndimage.rotate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.rotate.html#scipy.ndimage.rotate',
                               'scipy.ndimage.shift': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.shift.html#scipy.ndimage.shift',
                               'scipy.ndimage.sobel': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.sobel.html#scipy.ndimage.sobel',
                               'scipy.ndimage.spline_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.spline_filter.html#scipy.ndimage.spline_filter',
                               'scipy.ndimage.spline_filter1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.spline_filter1d.html#scipy.ndimage.spline_filter1d',
                               'scipy.ndimage.standard_deviation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.standard_deviation.html#scipy.ndimage.standard_deviation',
                               'scipy.ndimage.sum_labels': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.sum_labels.html#scipy.ndimage.sum_labels',
                               'scipy.ndimage.uniform_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.uniform_filter.html#scipy.ndimage.uniform_filter',
                               'scipy.ndimage.uniform_filter1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.uniform_filter1d.html#scipy.ndimage.uniform_filter1d',
                               'scipy.ndimage.variance': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.variance.html#scipy.ndimage.variance',
                               'scipy.ndimage.watershed_ift': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.watershed_ift.html#scipy.ndimage.watershed_ift',
                               'scipy.ndimage.white_tophat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.white_tophat.html#scipy.ndimage.white_tophat',
                               'scipy.ndimage.zoom': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.ndimage.zoom.html#scipy.ndimage.zoom'},
            'scipy.odr': { 'scipy.odr.Data': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.Data.html#scipy.odr.Data',
                           'scipy.odr.Data.set_meta': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.Data.set_meta.html#scipy.odr.Data.set_meta',
                           'scipy.odr.Model': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.Model.html#scipy.odr.Model',
                           'scipy.odr.Model.set_meta': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.Model.set_meta.html#scipy.odr.Model.set_meta',
                           'scipy.odr.ODR': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.ODR.html#scipy.odr.ODR',
                           'scipy.odr.ODR.restart': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.ODR.restart.html#scipy.odr.ODR.restart',
                           'scipy.odr.ODR.run': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.ODR.run.html#scipy.odr.ODR.run',
                           'scipy.odr.ODR.set_iprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.ODR.set_iprint.html#scipy.odr.ODR.set_iprint',
                           'scipy.odr.ODR.set_job': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.ODR.set_job.html#scipy.odr.ODR.set_job',
                           'scipy.odr.OdrError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.OdrError.html#scipy.odr.OdrError.with_traceback',
                           'scipy.odr.OdrStop.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.OdrStop.html#scipy.odr.OdrStop.with_traceback',
                           'scipy.odr.OdrWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.OdrWarning.html#scipy.odr.OdrWarning.with_traceback',
                           'scipy.odr.Output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.Output.html#scipy.odr.Output',
                           'scipy.odr.Output.pprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.Output.pprint.html#scipy.odr.Output.pprint',
                           'scipy.odr.RealData': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.RealData.html#scipy.odr.RealData',
                           'scipy.odr.RealData.set_meta': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.RealData.set_meta.html#scipy.odr.RealData.set_meta',
                           'scipy.odr.odr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/odr-function.html#scipy.odr.odr',
                           'scipy.odr.polynomial': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.polynomial.html#scipy.odr.polynomial'},
            'scipy.odr._odrpack': { 'scipy.odr._odrpack.Data': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.Data.html#scipy.odr.Data',
                                    'scipy.odr._odrpack.Model': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.Model.html#scipy.odr.Model',
                                    'scipy.odr._odrpack.ODR': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.ODR.html#scipy.odr.ODR',
                                    'scipy.odr._odrpack.Output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.Output.html#scipy.odr.Output',
                                    'scipy.odr._odrpack.RealData': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.odr.RealData.html#scipy.odr.RealData'},
            'scipy.optimize': { 'scipy.optimize.BFGS': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.BFGS.html#scipy.optimize.BFGS',
                                'scipy.optimize.BFGS.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.BFGS.dot.html#scipy.optimize.BFGS.dot',
                                'scipy.optimize.BFGS.get_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.BFGS.get_matrix.html#scipy.optimize.BFGS.get_matrix',
                                'scipy.optimize.BFGS.initialize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.BFGS.initialize.html#scipy.optimize.BFGS.initialize',
                                'scipy.optimize.BFGS.update': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.BFGS.update.html#scipy.optimize.BFGS.update',
                                'scipy.optimize.Bounds': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.Bounds.html#scipy.optimize.Bounds',
                                'scipy.optimize.Bounds.residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.Bounds.residual.html#scipy.optimize.Bounds.residual',
                                'scipy.optimize.HessianUpdateStrategy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.HessianUpdateStrategy.html#scipy.optimize.HessianUpdateStrategy',
                                'scipy.optimize.HessianUpdateStrategy.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.HessianUpdateStrategy.dot.html#scipy.optimize.HessianUpdateStrategy.dot',
                                'scipy.optimize.HessianUpdateStrategy.get_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.HessianUpdateStrategy.get_matrix.html#scipy.optimize.HessianUpdateStrategy.get_matrix',
                                'scipy.optimize.HessianUpdateStrategy.initialize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.HessianUpdateStrategy.initialize.html#scipy.optimize.HessianUpdateStrategy.initialize',
                                'scipy.optimize.HessianUpdateStrategy.update': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.HessianUpdateStrategy.update.html#scipy.optimize.HessianUpdateStrategy.update',
                                'scipy.optimize.LbfgsInvHessProduct': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.html#scipy.optimize.LbfgsInvHessProduct',
                                'scipy.optimize.LbfgsInvHessProduct.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.__call__.html#scipy.optimize.LbfgsInvHessProduct.__call__',
                                'scipy.optimize.LbfgsInvHessProduct.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.__mul__.html#scipy.optimize.LbfgsInvHessProduct.__mul__',
                                'scipy.optimize.LbfgsInvHessProduct.adjoint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.adjoint.html#scipy.optimize.LbfgsInvHessProduct.adjoint',
                                'scipy.optimize.LbfgsInvHessProduct.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.dot.html#scipy.optimize.LbfgsInvHessProduct.dot',
                                'scipy.optimize.LbfgsInvHessProduct.matmat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.matmat.html#scipy.optimize.LbfgsInvHessProduct.matmat',
                                'scipy.optimize.LbfgsInvHessProduct.matvec': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.matvec.html#scipy.optimize.LbfgsInvHessProduct.matvec',
                                'scipy.optimize.LbfgsInvHessProduct.rmatmat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.rmatmat.html#scipy.optimize.LbfgsInvHessProduct.rmatmat',
                                'scipy.optimize.LbfgsInvHessProduct.rmatvec': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.rmatvec.html#scipy.optimize.LbfgsInvHessProduct.rmatvec',
                                'scipy.optimize.LbfgsInvHessProduct.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.todense.html#scipy.optimize.LbfgsInvHessProduct.todense',
                                'scipy.optimize.LbfgsInvHessProduct.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.transpose.html#scipy.optimize.LbfgsInvHessProduct.transpose',
                                'scipy.optimize.LinearConstraint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LinearConstraint.html#scipy.optimize.LinearConstraint',
                                'scipy.optimize.LinearConstraint.residual': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LinearConstraint.residual.html#scipy.optimize.LinearConstraint.residual',
                                'scipy.optimize.NonlinearConstraint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.NonlinearConstraint.html#scipy.optimize.NonlinearConstraint',
                                'scipy.optimize.OptimizeResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.html#scipy.optimize.OptimizeResult',
                                'scipy.optimize.OptimizeResult.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.__getitem__.html#scipy.optimize.OptimizeResult.__getitem__',
                                'scipy.optimize.OptimizeResult.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.__len__.html#scipy.optimize.OptimizeResult.__len__',
                                'scipy.optimize.OptimizeResult.clear': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.clear.html#scipy.optimize.OptimizeResult.clear',
                                'scipy.optimize.OptimizeResult.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.copy.html#scipy.optimize.OptimizeResult.copy',
                                'scipy.optimize.OptimizeResult.fromkeys': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.fromkeys.html#scipy.optimize.OptimizeResult.fromkeys',
                                'scipy.optimize.OptimizeResult.get': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.get.html#scipy.optimize.OptimizeResult.get',
                                'scipy.optimize.OptimizeResult.items': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.items.html#scipy.optimize.OptimizeResult.items',
                                'scipy.optimize.OptimizeResult.keys': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.keys.html#scipy.optimize.OptimizeResult.keys',
                                'scipy.optimize.OptimizeResult.pop': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.pop.html#scipy.optimize.OptimizeResult.pop',
                                'scipy.optimize.OptimizeResult.popitem': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.popitem.html#scipy.optimize.OptimizeResult.popitem',
                                'scipy.optimize.OptimizeResult.setdefault': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.setdefault.html#scipy.optimize.OptimizeResult.setdefault',
                                'scipy.optimize.OptimizeResult.update': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.update.html#scipy.optimize.OptimizeResult.update',
                                'scipy.optimize.OptimizeResult.values': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.values.html#scipy.optimize.OptimizeResult.values',
                                'scipy.optimize.OptimizeWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeWarning.html#scipy.optimize.OptimizeWarning.with_traceback',
                                'scipy.optimize.RootResults': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.RootResults.html#scipy.optimize.RootResults',
                                'scipy.optimize.SR1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.SR1.html#scipy.optimize.SR1',
                                'scipy.optimize.SR1.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.SR1.dot.html#scipy.optimize.SR1.dot',
                                'scipy.optimize.SR1.get_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.SR1.get_matrix.html#scipy.optimize.SR1.get_matrix',
                                'scipy.optimize.SR1.initialize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.SR1.initialize.html#scipy.optimize.SR1.initialize',
                                'scipy.optimize.SR1.update': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.SR1.update.html#scipy.optimize.SR1.update',
                                'scipy.optimize.anderson': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.anderson.html#scipy.optimize.anderson',
                                'scipy.optimize.approx_fprime': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.approx_fprime.html#scipy.optimize.approx_fprime',
                                'scipy.optimize.basinhopping': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.basinhopping.html#scipy.optimize.basinhopping',
                                'scipy.optimize.bisect': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.bisect.html#scipy.optimize.bisect',
                                'scipy.optimize.bracket': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.bracket.html#scipy.optimize.bracket',
                                'scipy.optimize.brent': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.brent.html#scipy.optimize.brent',
                                'scipy.optimize.brenth': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.brenth.html#scipy.optimize.brenth',
                                'scipy.optimize.brentq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.brentq.html#scipy.optimize.brentq',
                                'scipy.optimize.broyden1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.broyden1.html#scipy.optimize.broyden1',
                                'scipy.optimize.broyden2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.broyden2.html#scipy.optimize.broyden2',
                                'scipy.optimize.brute': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.brute.html#scipy.optimize.brute',
                                'scipy.optimize.check_grad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.check_grad.html#scipy.optimize.check_grad',
                                'scipy.optimize.curve_fit': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.curve_fit.html#scipy.optimize.curve_fit',
                                'scipy.optimize.cython_optimize': 'https://docs.scipy.org/doc/scipy/reference/reference/optimize.cython_optimize.html#module-scipy.optimize.cython_optimize',
                                'scipy.optimize.diagbroyden': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.diagbroyden.html#scipy.optimize.diagbroyden',
                                'scipy.optimize.differential_evolution': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.differential_evolution.html#scipy.optimize.differential_evolution',
                                'scipy.optimize.direct': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.direct.html#scipy.optimize.direct',
                                'scipy.optimize.dual_annealing': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.dual_annealing.html#scipy.optimize.dual_annealing',
                                'scipy.optimize.excitingmixing': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.excitingmixing.html#scipy.optimize.excitingmixing',
                                'scipy.optimize.fixed_point': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fixed_point.html#scipy.optimize.fixed_point',
                                'scipy.optimize.fmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fmin.html#scipy.optimize.fmin',
                                'scipy.optimize.fmin_bfgs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fmin_bfgs.html#scipy.optimize.fmin_bfgs',
                                'scipy.optimize.fmin_cg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fmin_cg.html#scipy.optimize.fmin_cg',
                                'scipy.optimize.fmin_cobyla': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fmin_cobyla.html#scipy.optimize.fmin_cobyla',
                                'scipy.optimize.fmin_l_bfgs_b': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fmin_l_bfgs_b.html#scipy.optimize.fmin_l_bfgs_b',
                                'scipy.optimize.fmin_ncg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fmin_ncg.html#scipy.optimize.fmin_ncg',
                                'scipy.optimize.fmin_powell': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fmin_powell.html#scipy.optimize.fmin_powell',
                                'scipy.optimize.fmin_slsqp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fmin_slsqp.html#scipy.optimize.fmin_slsqp',
                                'scipy.optimize.fmin_tnc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fmin_tnc.html#scipy.optimize.fmin_tnc',
                                'scipy.optimize.fminbound': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fminbound.html#scipy.optimize.fminbound',
                                'scipy.optimize.fsolve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.fsolve.html#scipy.optimize.fsolve',
                                'scipy.optimize.golden': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.golden.html#scipy.optimize.golden',
                                'scipy.optimize.least_squares': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.least_squares.html#scipy.optimize.least_squares',
                                'scipy.optimize.leastsq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.leastsq.html#scipy.optimize.leastsq',
                                'scipy.optimize.line_search': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.line_search.html#scipy.optimize.line_search',
                                'scipy.optimize.linear_sum_assignment': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.linear_sum_assignment.html#scipy.optimize.linear_sum_assignment',
                                'scipy.optimize.linearmixing': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.linearmixing.html#scipy.optimize.linearmixing',
                                'scipy.optimize.linprog': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.linprog.html#scipy.optimize.linprog',
                                'scipy.optimize.linprog_verbose_callback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.linprog_verbose_callback.html#scipy.optimize.linprog_verbose_callback',
                                'scipy.optimize.lsq_linear': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.lsq_linear.html#scipy.optimize.lsq_linear',
                                'scipy.optimize.milp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.milp.html#scipy.optimize.milp',
                                'scipy.optimize.minimize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.minimize.html#scipy.optimize.minimize',
                                'scipy.optimize.minimize_scalar': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.minimize_scalar.html#scipy.optimize.minimize_scalar',
                                'scipy.optimize.newton': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.newton.html#scipy.optimize.newton',
                                'scipy.optimize.newton_krylov': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.newton_krylov.html#scipy.optimize.newton_krylov',
                                'scipy.optimize.nnls': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.nnls.html#scipy.optimize.nnls',
                                'scipy.optimize.quadratic_assignment': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.quadratic_assignment.html#scipy.optimize.quadratic_assignment',
                                'scipy.optimize.ridder': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.ridder.html#scipy.optimize.ridder',
                                'scipy.optimize.root': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.root.html#scipy.optimize.root',
                                'scipy.optimize.root_scalar': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.root_scalar.html#scipy.optimize.root_scalar',
                                'scipy.optimize.rosen': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.rosen.html#scipy.optimize.rosen',
                                'scipy.optimize.rosen_der': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.rosen_der.html#scipy.optimize.rosen_der',
                                'scipy.optimize.rosen_hess': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.rosen_hess.html#scipy.optimize.rosen_hess',
                                'scipy.optimize.rosen_hess_prod': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.rosen_hess_prod.html#scipy.optimize.rosen_hess_prod',
                                'scipy.optimize.shgo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.shgo.html#scipy.optimize.shgo',
                                'scipy.optimize.show_options': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.show_options.html#scipy.optimize.show_options',
                                'scipy.optimize.toms748': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.toms748.html#scipy.optimize.toms748'},
            'scipy.optimize._constraints': { 'scipy.optimize._constraints.Bounds': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.Bounds.html#scipy.optimize.Bounds',
                                             'scipy.optimize._constraints.LinearConstraint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LinearConstraint.html#scipy.optimize.LinearConstraint',
                                             'scipy.optimize._constraints.NonlinearConstraint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.NonlinearConstraint.html#scipy.optimize.NonlinearConstraint'},
            'scipy.optimize._hessian_update_strategy': { 'scipy.optimize._hessian_update_strategy.BFGS': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.BFGS.html#scipy.optimize.BFGS',
                                                         'scipy.optimize._hessian_update_strategy.HessianUpdateStrategy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.HessianUpdateStrategy.html#scipy.optimize.HessianUpdateStrategy',
                                                         'scipy.optimize._hessian_update_strategy.SR1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.SR1.html#scipy.optimize.SR1'},
            'scipy.optimize._lbfgsb_py': { 'scipy.optimize._lbfgsb_py.LbfgsInvHessProduct': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.LbfgsInvHessProduct.html#scipy.optimize.LbfgsInvHessProduct'},
            'scipy.optimize._optimize': { 'scipy.optimize._optimize.OptimizeResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.OptimizeResult.html#scipy.optimize.OptimizeResult'},
            'scipy.optimize._zeros_py': { 'scipy.optimize._zeros_py.RootResults': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.optimize.RootResults.html#scipy.optimize.RootResults'},
            'scipy.signal': { 'scipy.signal.BadCoefficients.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.BadCoefficients.html#scipy.signal.BadCoefficients.with_traceback',
                              'scipy.signal.CZT': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.CZT.html#scipy.signal.CZT',
                              'scipy.signal.CZT.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.CZT.__call__.html#scipy.signal.CZT.__call__',
                              'scipy.signal.CZT.points': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.CZT.points.html#scipy.signal.CZT.points',
                              'scipy.signal.StateSpace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.StateSpace.html#scipy.signal.StateSpace',
                              'scipy.signal.StateSpace.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.StateSpace.__mul__.html#scipy.signal.StateSpace.__mul__',
                              'scipy.signal.StateSpace.to_ss': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.StateSpace.to_ss.html#scipy.signal.StateSpace.to_ss',
                              'scipy.signal.StateSpace.to_tf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.StateSpace.to_tf.html#scipy.signal.StateSpace.to_tf',
                              'scipy.signal.StateSpace.to_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.StateSpace.to_zpk.html#scipy.signal.StateSpace.to_zpk',
                              'scipy.signal.TransferFunction': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.TransferFunction.html#scipy.signal.TransferFunction',
                              'scipy.signal.TransferFunction.to_ss': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.TransferFunction.to_ss.html#scipy.signal.TransferFunction.to_ss',
                              'scipy.signal.TransferFunction.to_tf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.TransferFunction.to_tf.html#scipy.signal.TransferFunction.to_tf',
                              'scipy.signal.TransferFunction.to_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.TransferFunction.to_zpk.html#scipy.signal.TransferFunction.to_zpk',
                              'scipy.signal.ZerosPolesGain': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ZerosPolesGain.html#scipy.signal.ZerosPolesGain',
                              'scipy.signal.ZerosPolesGain.to_ss': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ZerosPolesGain.to_ss.html#scipy.signal.ZerosPolesGain.to_ss',
                              'scipy.signal.ZerosPolesGain.to_tf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ZerosPolesGain.to_tf.html#scipy.signal.ZerosPolesGain.to_tf',
                              'scipy.signal.ZerosPolesGain.to_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ZerosPolesGain.to_zpk.html#scipy.signal.ZerosPolesGain.to_zpk',
                              'scipy.signal.ZoomFFT': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ZoomFFT.html#scipy.signal.ZoomFFT',
                              'scipy.signal.ZoomFFT.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ZoomFFT.__call__.html#scipy.signal.ZoomFFT.__call__',
                              'scipy.signal.ZoomFFT.points': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ZoomFFT.points.html#scipy.signal.ZoomFFT.points',
                              'scipy.signal.abcd_normalize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.abcd_normalize.html#scipy.signal.abcd_normalize',
                              'scipy.signal.argrelextrema': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.argrelextrema.html#scipy.signal.argrelextrema',
                              'scipy.signal.argrelmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.argrelmax.html#scipy.signal.argrelmax',
                              'scipy.signal.argrelmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.argrelmin.html#scipy.signal.argrelmin',
                              'scipy.signal.band_stop_obj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.band_stop_obj.html#scipy.signal.band_stop_obj',
                              'scipy.signal.bessel': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.bessel.html#scipy.signal.bessel',
                              'scipy.signal.besselap': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.besselap.html#scipy.signal.besselap',
                              'scipy.signal.bilinear': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.bilinear.html#scipy.signal.bilinear',
                              'scipy.signal.bilinear_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.bilinear_zpk.html#scipy.signal.bilinear_zpk',
                              'scipy.signal.bode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.bode.html#scipy.signal.bode',
                              'scipy.signal.bspline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.bspline.html#scipy.signal.bspline',
                              'scipy.signal.buttap': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.buttap.html#scipy.signal.buttap',
                              'scipy.signal.butter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.butter.html#scipy.signal.butter',
                              'scipy.signal.buttord': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.buttord.html#scipy.signal.buttord',
                              'scipy.signal.cascade': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cascade.html#scipy.signal.cascade',
                              'scipy.signal.cheb1ap': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cheb1ap.html#scipy.signal.cheb1ap',
                              'scipy.signal.cheb1ord': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cheb1ord.html#scipy.signal.cheb1ord',
                              'scipy.signal.cheb2ap': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cheb2ap.html#scipy.signal.cheb2ap',
                              'scipy.signal.cheb2ord': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cheb2ord.html#scipy.signal.cheb2ord',
                              'scipy.signal.cheby1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cheby1.html#scipy.signal.cheby1',
                              'scipy.signal.cheby2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cheby2.html#scipy.signal.cheby2',
                              'scipy.signal.check_COLA': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.check_COLA.html#scipy.signal.check_COLA',
                              'scipy.signal.check_NOLA': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.check_NOLA.html#scipy.signal.check_NOLA',
                              'scipy.signal.chirp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.chirp.html#scipy.signal.chirp',
                              'scipy.signal.choose_conv_method': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.choose_conv_method.html#scipy.signal.choose_conv_method',
                              'scipy.signal.cmplx_sort': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cmplx_sort.html#scipy.signal.cmplx_sort',
                              'scipy.signal.coherence': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.coherence.html#scipy.signal.coherence',
                              'scipy.signal.cont2discrete': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cont2discrete.html#scipy.signal.cont2discrete',
                              'scipy.signal.convolve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.convolve.html#scipy.signal.convolve',
                              'scipy.signal.convolve2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.convolve2d.html#scipy.signal.convolve2d',
                              'scipy.signal.correlate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.correlate.html#scipy.signal.correlate',
                              'scipy.signal.correlate2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.correlate2d.html#scipy.signal.correlate2d',
                              'scipy.signal.correlation_lags': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.correlation_lags.html#scipy.signal.correlation_lags',
                              'scipy.signal.csd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.csd.html#scipy.signal.csd',
                              'scipy.signal.cspline1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cspline1d.html#scipy.signal.cspline1d',
                              'scipy.signal.cspline1d_eval': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cspline1d_eval.html#scipy.signal.cspline1d_eval',
                              'scipy.signal.cspline2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cspline2d.html#scipy.signal.cspline2d',
                              'scipy.signal.cubic': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cubic.html#scipy.signal.cubic',
                              'scipy.signal.cwt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.cwt.html#scipy.signal.cwt',
                              'scipy.signal.czt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/czt-function.html#scipy.signal.czt',
                              'scipy.signal.czt_points': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.czt_points.html#scipy.signal.czt_points',
                              'scipy.signal.daub': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.daub.html#scipy.signal.daub',
                              'scipy.signal.dbode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dbode.html#scipy.signal.dbode',
                              'scipy.signal.decimate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.decimate.html#scipy.signal.decimate',
                              'scipy.signal.deconvolve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.deconvolve.html#scipy.signal.deconvolve',
                              'scipy.signal.detrend': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.detrend.html#scipy.signal.detrend',
                              'scipy.signal.dfreqresp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dfreqresp.html#scipy.signal.dfreqresp',
                              'scipy.signal.dimpulse': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dimpulse.html#scipy.signal.dimpulse',
                              'scipy.signal.dlsim': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dlsim.html#scipy.signal.dlsim',
                              'scipy.signal.dlti': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dlti.html#scipy.signal.dlti',
                              'scipy.signal.dlti.bode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dlti.bode.html#scipy.signal.dlti.bode',
                              'scipy.signal.dlti.freqresp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dlti.freqresp.html#scipy.signal.dlti.freqresp',
                              'scipy.signal.dlti.impulse': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dlti.impulse.html#scipy.signal.dlti.impulse',
                              'scipy.signal.dlti.output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dlti.output.html#scipy.signal.dlti.output',
                              'scipy.signal.dlti.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dlti.step.html#scipy.signal.dlti.step',
                              'scipy.signal.dstep': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dstep.html#scipy.signal.dstep',
                              'scipy.signal.ellip': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ellip.html#scipy.signal.ellip',
                              'scipy.signal.ellipap': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ellipap.html#scipy.signal.ellipap',
                              'scipy.signal.ellipord': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ellipord.html#scipy.signal.ellipord',
                              'scipy.signal.fftconvolve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.fftconvolve.html#scipy.signal.fftconvolve',
                              'scipy.signal.filtfilt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.filtfilt.html#scipy.signal.filtfilt',
                              'scipy.signal.find_peaks': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.find_peaks.html#scipy.signal.find_peaks',
                              'scipy.signal.find_peaks_cwt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.find_peaks_cwt.html#scipy.signal.find_peaks_cwt',
                              'scipy.signal.findfreqs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.findfreqs.html#scipy.signal.findfreqs',
                              'scipy.signal.firls': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.firls.html#scipy.signal.firls',
                              'scipy.signal.firwin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.firwin.html#scipy.signal.firwin',
                              'scipy.signal.firwin2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.firwin2.html#scipy.signal.firwin2',
                              'scipy.signal.freqresp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.freqresp.html#scipy.signal.freqresp',
                              'scipy.signal.freqs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.freqs.html#scipy.signal.freqs',
                              'scipy.signal.freqs_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.freqs_zpk.html#scipy.signal.freqs_zpk',
                              'scipy.signal.freqz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.freqz.html#scipy.signal.freqz',
                              'scipy.signal.freqz_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.freqz_zpk.html#scipy.signal.freqz_zpk',
                              'scipy.signal.gammatone': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.gammatone.html#scipy.signal.gammatone',
                              'scipy.signal.gauss_spline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.gauss_spline.html#scipy.signal.gauss_spline',
                              'scipy.signal.gausspulse': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.gausspulse.html#scipy.signal.gausspulse',
                              'scipy.signal.get_window': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.get_window.html#scipy.signal.get_window',
                              'scipy.signal.group_delay': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.group_delay.html#scipy.signal.group_delay',
                              'scipy.signal.hilbert': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.hilbert.html#scipy.signal.hilbert',
                              'scipy.signal.hilbert2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.hilbert2.html#scipy.signal.hilbert2',
                              'scipy.signal.iircomb': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.iircomb.html#scipy.signal.iircomb',
                              'scipy.signal.iirdesign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.iirdesign.html#scipy.signal.iirdesign',
                              'scipy.signal.iirfilter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.iirfilter.html#scipy.signal.iirfilter',
                              'scipy.signal.iirnotch': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.iirnotch.html#scipy.signal.iirnotch',
                              'scipy.signal.iirpeak': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.iirpeak.html#scipy.signal.iirpeak',
                              'scipy.signal.impulse': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.impulse.html#scipy.signal.impulse',
                              'scipy.signal.impulse2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.impulse2.html#scipy.signal.impulse2',
                              'scipy.signal.invres': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.invres.html#scipy.signal.invres',
                              'scipy.signal.invresz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.invresz.html#scipy.signal.invresz',
                              'scipy.signal.istft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.istft.html#scipy.signal.istft',
                              'scipy.signal.kaiser_atten': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.kaiser_atten.html#scipy.signal.kaiser_atten',
                              'scipy.signal.kaiser_beta': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.kaiser_beta.html#scipy.signal.kaiser_beta',
                              'scipy.signal.kaiserord': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.kaiserord.html#scipy.signal.kaiserord',
                              'scipy.signal.lfilter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lfilter.html#scipy.signal.lfilter',
                              'scipy.signal.lfilter_zi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lfilter_zi.html#scipy.signal.lfilter_zi',
                              'scipy.signal.lfiltic': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lfiltic.html#scipy.signal.lfiltic',
                              'scipy.signal.lombscargle': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lombscargle.html#scipy.signal.lombscargle',
                              'scipy.signal.lp2bp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lp2bp.html#scipy.signal.lp2bp',
                              'scipy.signal.lp2bp_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lp2bp_zpk.html#scipy.signal.lp2bp_zpk',
                              'scipy.signal.lp2bs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lp2bs.html#scipy.signal.lp2bs',
                              'scipy.signal.lp2bs_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lp2bs_zpk.html#scipy.signal.lp2bs_zpk',
                              'scipy.signal.lp2hp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lp2hp.html#scipy.signal.lp2hp',
                              'scipy.signal.lp2hp_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lp2hp_zpk.html#scipy.signal.lp2hp_zpk',
                              'scipy.signal.lp2lp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lp2lp.html#scipy.signal.lp2lp',
                              'scipy.signal.lp2lp_zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lp2lp_zpk.html#scipy.signal.lp2lp_zpk',
                              'scipy.signal.lsim': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lsim.html#scipy.signal.lsim',
                              'scipy.signal.lsim2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lsim2.html#scipy.signal.lsim2',
                              'scipy.signal.lti': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lti.html#scipy.signal.lti',
                              'scipy.signal.lti.bode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lti.bode.html#scipy.signal.lti.bode',
                              'scipy.signal.lti.freqresp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lti.freqresp.html#scipy.signal.lti.freqresp',
                              'scipy.signal.lti.impulse': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lti.impulse.html#scipy.signal.lti.impulse',
                              'scipy.signal.lti.output': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lti.output.html#scipy.signal.lti.output',
                              'scipy.signal.lti.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lti.step.html#scipy.signal.lti.step',
                              'scipy.signal.lti.to_discrete': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lti.to_discrete.html#scipy.signal.lti.to_discrete',
                              'scipy.signal.max_len_seq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.max_len_seq.html#scipy.signal.max_len_seq',
                              'scipy.signal.medfilt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.medfilt.html#scipy.signal.medfilt',
                              'scipy.signal.medfilt2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.medfilt2d.html#scipy.signal.medfilt2d',
                              'scipy.signal.minimum_phase': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.minimum_phase.html#scipy.signal.minimum_phase',
                              'scipy.signal.morlet': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.morlet.html#scipy.signal.morlet',
                              'scipy.signal.morlet2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.morlet2.html#scipy.signal.morlet2',
                              'scipy.signal.normalize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.normalize.html#scipy.signal.normalize',
                              'scipy.signal.oaconvolve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.oaconvolve.html#scipy.signal.oaconvolve',
                              'scipy.signal.order_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.order_filter.html#scipy.signal.order_filter',
                              'scipy.signal.peak_prominences': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.peak_prominences.html#scipy.signal.peak_prominences',
                              'scipy.signal.peak_widths': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.peak_widths.html#scipy.signal.peak_widths',
                              'scipy.signal.periodogram': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.periodogram.html#scipy.signal.periodogram',
                              'scipy.signal.place_poles': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.place_poles.html#scipy.signal.place_poles',
                              'scipy.signal.qmf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.qmf.html#scipy.signal.qmf',
                              'scipy.signal.qspline1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.qspline1d.html#scipy.signal.qspline1d',
                              'scipy.signal.qspline1d_eval': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.qspline1d_eval.html#scipy.signal.qspline1d_eval',
                              'scipy.signal.qspline2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.qspline2d.html#scipy.signal.qspline2d',
                              'scipy.signal.quadratic': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.quadratic.html#scipy.signal.quadratic',
                              'scipy.signal.remez': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.remez.html#scipy.signal.remez',
                              'scipy.signal.resample': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.resample.html#scipy.signal.resample',
                              'scipy.signal.resample_poly': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.resample_poly.html#scipy.signal.resample_poly',
                              'scipy.signal.residue': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.residue.html#scipy.signal.residue',
                              'scipy.signal.residuez': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.residuez.html#scipy.signal.residuez',
                              'scipy.signal.ricker': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ricker.html#scipy.signal.ricker',
                              'scipy.signal.savgol_coeffs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.savgol_coeffs.html#scipy.signal.savgol_coeffs',
                              'scipy.signal.savgol_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.savgol_filter.html#scipy.signal.savgol_filter',
                              'scipy.signal.sawtooth': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.sawtooth.html#scipy.signal.sawtooth',
                              'scipy.signal.sepfir2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.sepfir2d.html#scipy.signal.sepfir2d',
                              'scipy.signal.sos2tf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.sos2tf.html#scipy.signal.sos2tf',
                              'scipy.signal.sos2zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.sos2zpk.html#scipy.signal.sos2zpk',
                              'scipy.signal.sosfilt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.sosfilt.html#scipy.signal.sosfilt',
                              'scipy.signal.sosfilt_zi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.sosfilt_zi.html#scipy.signal.sosfilt_zi',
                              'scipy.signal.sosfiltfilt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.sosfiltfilt.html#scipy.signal.sosfiltfilt',
                              'scipy.signal.sosfreqz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.sosfreqz.html#scipy.signal.sosfreqz',
                              'scipy.signal.spectrogram': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.spectrogram.html#scipy.signal.spectrogram',
                              'scipy.signal.spline_filter': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.spline_filter.html#scipy.signal.spline_filter',
                              'scipy.signal.square': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.square.html#scipy.signal.square',
                              'scipy.signal.ss2tf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ss2tf.html#scipy.signal.ss2tf',
                              'scipy.signal.ss2zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ss2zpk.html#scipy.signal.ss2zpk',
                              'scipy.signal.step': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.step.html#scipy.signal.step',
                              'scipy.signal.step2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.step2.html#scipy.signal.step2',
                              'scipy.signal.stft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.stft.html#scipy.signal.stft',
                              'scipy.signal.sweep_poly': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.sweep_poly.html#scipy.signal.sweep_poly',
                              'scipy.signal.symiirorder1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.symiirorder1.html#scipy.signal.symiirorder1',
                              'scipy.signal.symiirorder2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.symiirorder2.html#scipy.signal.symiirorder2',
                              'scipy.signal.tf2sos': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.tf2sos.html#scipy.signal.tf2sos',
                              'scipy.signal.tf2ss': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.tf2ss.html#scipy.signal.tf2ss',
                              'scipy.signal.tf2zpk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.tf2zpk.html#scipy.signal.tf2zpk',
                              'scipy.signal.unique_roots': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.unique_roots.html#scipy.signal.unique_roots',
                              'scipy.signal.unit_impulse': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.unit_impulse.html#scipy.signal.unit_impulse',
                              'scipy.signal.upfirdn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.upfirdn.html#scipy.signal.upfirdn',
                              'scipy.signal.vectorstrength': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.vectorstrength.html#scipy.signal.vectorstrength',
                              'scipy.signal.welch': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.welch.html#scipy.signal.welch',
                              'scipy.signal.wiener': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.wiener.html#scipy.signal.wiener',
                              'scipy.signal.windows': 'https://docs.scipy.org/doc/scipy/reference/reference/signal.windows.html#module-scipy.signal.windows',
                              'scipy.signal.zoom_fft': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.zoom_fft.html#scipy.signal.zoom_fft',
                              'scipy.signal.zpk2sos': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.zpk2sos.html#scipy.signal.zpk2sos',
                              'scipy.signal.zpk2ss': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.zpk2ss.html#scipy.signal.zpk2ss',
                              'scipy.signal.zpk2tf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.zpk2tf.html#scipy.signal.zpk2tf'},
            'scipy.signal._czt': { 'scipy.signal._czt.CZT': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.CZT.html#scipy.signal.CZT',
                                   'scipy.signal._czt.ZoomFFT': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ZoomFFT.html#scipy.signal.ZoomFFT'},
            'scipy.signal._ltisys': { 'scipy.signal._ltisys.StateSpace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.StateSpace.html#scipy.signal.StateSpace',
                                      'scipy.signal._ltisys.TransferFunction': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.TransferFunction.html#scipy.signal.TransferFunction',
                                      'scipy.signal._ltisys.ZerosPolesGain': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.ZerosPolesGain.html#scipy.signal.ZerosPolesGain',
                                      'scipy.signal._ltisys.dlti': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.dlti.html#scipy.signal.dlti',
                                      'scipy.signal._ltisys.lti': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.lti.html#scipy.signal.lti'},
            'scipy.signal.windows': { 'scipy.signal.windows.barthann': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.barthann.html#scipy.signal.windows.barthann',
                                      'scipy.signal.windows.bartlett': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.bartlett.html#scipy.signal.windows.bartlett',
                                      'scipy.signal.windows.blackman': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.blackman.html#scipy.signal.windows.blackman',
                                      'scipy.signal.windows.blackmanharris': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.blackmanharris.html#scipy.signal.windows.blackmanharris',
                                      'scipy.signal.windows.bohman': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.bohman.html#scipy.signal.windows.bohman',
                                      'scipy.signal.windows.boxcar': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.boxcar.html#scipy.signal.windows.boxcar',
                                      'scipy.signal.windows.chebwin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.chebwin.html#scipy.signal.windows.chebwin',
                                      'scipy.signal.windows.cosine': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.cosine.html#scipy.signal.windows.cosine',
                                      'scipy.signal.windows.dpss': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.dpss.html#scipy.signal.windows.dpss',
                                      'scipy.signal.windows.exponential': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.exponential.html#scipy.signal.windows.exponential',
                                      'scipy.signal.windows.flattop': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.flattop.html#scipy.signal.windows.flattop',
                                      'scipy.signal.windows.gaussian': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.gaussian.html#scipy.signal.windows.gaussian',
                                      'scipy.signal.windows.general_cosine': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.general_cosine.html#scipy.signal.windows.general_cosine',
                                      'scipy.signal.windows.general_gaussian': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.general_gaussian.html#scipy.signal.windows.general_gaussian',
                                      'scipy.signal.windows.general_hamming': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.general_hamming.html#scipy.signal.windows.general_hamming',
                                      'scipy.signal.windows.get_window': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.get_window.html#scipy.signal.windows.get_window',
                                      'scipy.signal.windows.hamming': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.hamming.html#scipy.signal.windows.hamming',
                                      'scipy.signal.windows.hann': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.hann.html#scipy.signal.windows.hann',
                                      'scipy.signal.windows.kaiser': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.kaiser.html#scipy.signal.windows.kaiser',
                                      'scipy.signal.windows.kaiser_bessel_derived': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.kaiser_bessel_derived.html#scipy.signal.windows.kaiser_bessel_derived',
                                      'scipy.signal.windows.nuttall': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.nuttall.html#scipy.signal.windows.nuttall',
                                      'scipy.signal.windows.parzen': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.parzen.html#scipy.signal.windows.parzen',
                                      'scipy.signal.windows.taylor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.taylor.html#scipy.signal.windows.taylor',
                                      'scipy.signal.windows.triang': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.triang.html#scipy.signal.windows.triang',
                                      'scipy.signal.windows.tukey': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.signal.windows.tukey.html#scipy.signal.windows.tukey'},
            'scipy.sparse': { 'scipy.sparse.SparseEfficiencyWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.SparseEfficiencyWarning.html#scipy.sparse.SparseEfficiencyWarning.with_traceback',
                              'scipy.sparse.SparseWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.SparseWarning.html#scipy.sparse.SparseWarning.with_traceback',
                              'scipy.sparse.block_diag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.block_diag.html#scipy.sparse.block_diag',
                              'scipy.sparse.bmat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bmat.html#scipy.sparse.bmat',
                              'scipy.sparse.bsr_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.html#scipy.sparse.bsr_array',
                              'scipy.sparse.bsr_array.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.__getitem__.html#scipy.sparse.bsr_array.__getitem__',
                              'scipy.sparse.bsr_array.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.__len__.html#scipy.sparse.bsr_array.__len__',
                              'scipy.sparse.bsr_array.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.__mul__.html#scipy.sparse.bsr_array.__mul__',
                              'scipy.sparse.bsr_array.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.arcsin.html#scipy.sparse.bsr_array.arcsin',
                              'scipy.sparse.bsr_array.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.arcsinh.html#scipy.sparse.bsr_array.arcsinh',
                              'scipy.sparse.bsr_array.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.arctan.html#scipy.sparse.bsr_array.arctan',
                              'scipy.sparse.bsr_array.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.arctanh.html#scipy.sparse.bsr_array.arctanh',
                              'scipy.sparse.bsr_array.argmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.argmax.html#scipy.sparse.bsr_array.argmax',
                              'scipy.sparse.bsr_array.argmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.argmin.html#scipy.sparse.bsr_array.argmin',
                              'scipy.sparse.bsr_array.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.asformat.html#scipy.sparse.bsr_array.asformat',
                              'scipy.sparse.bsr_array.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.asfptype.html#scipy.sparse.bsr_array.asfptype',
                              'scipy.sparse.bsr_array.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.astype.html#scipy.sparse.bsr_array.astype',
                              'scipy.sparse.bsr_array.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.ceil.html#scipy.sparse.bsr_array.ceil',
                              'scipy.sparse.bsr_array.check_format': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.check_format.html#scipy.sparse.bsr_array.check_format',
                              'scipy.sparse.bsr_array.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.conj.html#scipy.sparse.bsr_array.conj',
                              'scipy.sparse.bsr_array.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.conjugate.html#scipy.sparse.bsr_array.conjugate',
                              'scipy.sparse.bsr_array.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.copy.html#scipy.sparse.bsr_array.copy',
                              'scipy.sparse.bsr_array.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.count_nonzero.html#scipy.sparse.bsr_array.count_nonzero',
                              'scipy.sparse.bsr_array.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.deg2rad.html#scipy.sparse.bsr_array.deg2rad',
                              'scipy.sparse.bsr_array.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.diagonal.html#scipy.sparse.bsr_array.diagonal',
                              'scipy.sparse.bsr_array.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.dot.html#scipy.sparse.bsr_array.dot',
                              'scipy.sparse.bsr_array.eliminate_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.eliminate_zeros.html#scipy.sparse.bsr_array.eliminate_zeros',
                              'scipy.sparse.bsr_array.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.expm1.html#scipy.sparse.bsr_array.expm1',
                              'scipy.sparse.bsr_array.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.floor.html#scipy.sparse.bsr_array.floor',
                              'scipy.sparse.bsr_array.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.getH.html#scipy.sparse.bsr_array.getH',
                              'scipy.sparse.bsr_array.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.get_shape.html#scipy.sparse.bsr_array.get_shape',
                              'scipy.sparse.bsr_array.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.getcol.html#scipy.sparse.bsr_array.getcol',
                              'scipy.sparse.bsr_array.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.getformat.html#scipy.sparse.bsr_array.getformat',
                              'scipy.sparse.bsr_array.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.getmaxprint.html#scipy.sparse.bsr_array.getmaxprint',
                              'scipy.sparse.bsr_array.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.getnnz.html#scipy.sparse.bsr_array.getnnz',
                              'scipy.sparse.bsr_array.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.getrow.html#scipy.sparse.bsr_array.getrow',
                              'scipy.sparse.bsr_array.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.log1p.html#scipy.sparse.bsr_array.log1p',
                              'scipy.sparse.bsr_array.max': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.max.html#scipy.sparse.bsr_array.max',
                              'scipy.sparse.bsr_array.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.maximum.html#scipy.sparse.bsr_array.maximum',
                              'scipy.sparse.bsr_array.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.mean.html#scipy.sparse.bsr_array.mean',
                              'scipy.sparse.bsr_array.min': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.min.html#scipy.sparse.bsr_array.min',
                              'scipy.sparse.bsr_array.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.minimum.html#scipy.sparse.bsr_array.minimum',
                              'scipy.sparse.bsr_array.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.multiply.html#scipy.sparse.bsr_array.multiply',
                              'scipy.sparse.bsr_array.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.nonzero.html#scipy.sparse.bsr_array.nonzero',
                              'scipy.sparse.bsr_array.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.power.html#scipy.sparse.bsr_array.power',
                              'scipy.sparse.bsr_array.prune': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.prune.html#scipy.sparse.bsr_array.prune',
                              'scipy.sparse.bsr_array.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.rad2deg.html#scipy.sparse.bsr_array.rad2deg',
                              'scipy.sparse.bsr_array.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.reshape.html#scipy.sparse.bsr_array.reshape',
                              'scipy.sparse.bsr_array.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.resize.html#scipy.sparse.bsr_array.resize',
                              'scipy.sparse.bsr_array.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.rint.html#scipy.sparse.bsr_array.rint',
                              'scipy.sparse.bsr_array.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.set_shape.html#scipy.sparse.bsr_array.set_shape',
                              'scipy.sparse.bsr_array.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.setdiag.html#scipy.sparse.bsr_array.setdiag',
                              'scipy.sparse.bsr_array.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.sign.html#scipy.sparse.bsr_array.sign',
                              'scipy.sparse.bsr_array.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.sin.html#scipy.sparse.bsr_array.sin',
                              'scipy.sparse.bsr_array.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.sinh.html#scipy.sparse.bsr_array.sinh',
                              'scipy.sparse.bsr_array.sort_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.sort_indices.html#scipy.sparse.bsr_array.sort_indices',
                              'scipy.sparse.bsr_array.sorted_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.sorted_indices.html#scipy.sparse.bsr_array.sorted_indices',
                              'scipy.sparse.bsr_array.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.sqrt.html#scipy.sparse.bsr_array.sqrt',
                              'scipy.sparse.bsr_array.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.sum.html#scipy.sparse.bsr_array.sum',
                              'scipy.sparse.bsr_array.sum_duplicates': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.sum_duplicates.html#scipy.sparse.bsr_array.sum_duplicates',
                              'scipy.sparse.bsr_array.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.tan.html#scipy.sparse.bsr_array.tan',
                              'scipy.sparse.bsr_array.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.tanh.html#scipy.sparse.bsr_array.tanh',
                              'scipy.sparse.bsr_array.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.toarray.html#scipy.sparse.bsr_array.toarray',
                              'scipy.sparse.bsr_array.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.tobsr.html#scipy.sparse.bsr_array.tobsr',
                              'scipy.sparse.bsr_array.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.tocoo.html#scipy.sparse.bsr_array.tocoo',
                              'scipy.sparse.bsr_array.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.tocsc.html#scipy.sparse.bsr_array.tocsc',
                              'scipy.sparse.bsr_array.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.tocsr.html#scipy.sparse.bsr_array.tocsr',
                              'scipy.sparse.bsr_array.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.todense.html#scipy.sparse.bsr_array.todense',
                              'scipy.sparse.bsr_array.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.todia.html#scipy.sparse.bsr_array.todia',
                              'scipy.sparse.bsr_array.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.todok.html#scipy.sparse.bsr_array.todok',
                              'scipy.sparse.bsr_array.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.tolil.html#scipy.sparse.bsr_array.tolil',
                              'scipy.sparse.bsr_array.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.trace.html#scipy.sparse.bsr_array.trace',
                              'scipy.sparse.bsr_array.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.transpose.html#scipy.sparse.bsr_array.transpose',
                              'scipy.sparse.bsr_array.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.trunc.html#scipy.sparse.bsr_array.trunc',
                              'scipy.sparse.bsr_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.html#scipy.sparse.bsr_matrix',
                              'scipy.sparse.bsr_matrix.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.__getitem__.html#scipy.sparse.bsr_matrix.__getitem__',
                              'scipy.sparse.bsr_matrix.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.__len__.html#scipy.sparse.bsr_matrix.__len__',
                              'scipy.sparse.bsr_matrix.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.__mul__.html#scipy.sparse.bsr_matrix.__mul__',
                              'scipy.sparse.bsr_matrix.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.arcsin.html#scipy.sparse.bsr_matrix.arcsin',
                              'scipy.sparse.bsr_matrix.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.arcsinh.html#scipy.sparse.bsr_matrix.arcsinh',
                              'scipy.sparse.bsr_matrix.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.arctan.html#scipy.sparse.bsr_matrix.arctan',
                              'scipy.sparse.bsr_matrix.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.arctanh.html#scipy.sparse.bsr_matrix.arctanh',
                              'scipy.sparse.bsr_matrix.argmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.argmax.html#scipy.sparse.bsr_matrix.argmax',
                              'scipy.sparse.bsr_matrix.argmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.argmin.html#scipy.sparse.bsr_matrix.argmin',
                              'scipy.sparse.bsr_matrix.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.asformat.html#scipy.sparse.bsr_matrix.asformat',
                              'scipy.sparse.bsr_matrix.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.asfptype.html#scipy.sparse.bsr_matrix.asfptype',
                              'scipy.sparse.bsr_matrix.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.astype.html#scipy.sparse.bsr_matrix.astype',
                              'scipy.sparse.bsr_matrix.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.ceil.html#scipy.sparse.bsr_matrix.ceil',
                              'scipy.sparse.bsr_matrix.check_format': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.check_format.html#scipy.sparse.bsr_matrix.check_format',
                              'scipy.sparse.bsr_matrix.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.conj.html#scipy.sparse.bsr_matrix.conj',
                              'scipy.sparse.bsr_matrix.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.conjugate.html#scipy.sparse.bsr_matrix.conjugate',
                              'scipy.sparse.bsr_matrix.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.copy.html#scipy.sparse.bsr_matrix.copy',
                              'scipy.sparse.bsr_matrix.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.count_nonzero.html#scipy.sparse.bsr_matrix.count_nonzero',
                              'scipy.sparse.bsr_matrix.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.deg2rad.html#scipy.sparse.bsr_matrix.deg2rad',
                              'scipy.sparse.bsr_matrix.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.diagonal.html#scipy.sparse.bsr_matrix.diagonal',
                              'scipy.sparse.bsr_matrix.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.dot.html#scipy.sparse.bsr_matrix.dot',
                              'scipy.sparse.bsr_matrix.eliminate_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.eliminate_zeros.html#scipy.sparse.bsr_matrix.eliminate_zeros',
                              'scipy.sparse.bsr_matrix.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.expm1.html#scipy.sparse.bsr_matrix.expm1',
                              'scipy.sparse.bsr_matrix.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.floor.html#scipy.sparse.bsr_matrix.floor',
                              'scipy.sparse.bsr_matrix.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.getH.html#scipy.sparse.bsr_matrix.getH',
                              'scipy.sparse.bsr_matrix.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.get_shape.html#scipy.sparse.bsr_matrix.get_shape',
                              'scipy.sparse.bsr_matrix.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.getcol.html#scipy.sparse.bsr_matrix.getcol',
                              'scipy.sparse.bsr_matrix.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.getformat.html#scipy.sparse.bsr_matrix.getformat',
                              'scipy.sparse.bsr_matrix.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.getmaxprint.html#scipy.sparse.bsr_matrix.getmaxprint',
                              'scipy.sparse.bsr_matrix.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.getnnz.html#scipy.sparse.bsr_matrix.getnnz',
                              'scipy.sparse.bsr_matrix.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.getrow.html#scipy.sparse.bsr_matrix.getrow',
                              'scipy.sparse.bsr_matrix.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.log1p.html#scipy.sparse.bsr_matrix.log1p',
                              'scipy.sparse.bsr_matrix.max': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.max.html#scipy.sparse.bsr_matrix.max',
                              'scipy.sparse.bsr_matrix.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.maximum.html#scipy.sparse.bsr_matrix.maximum',
                              'scipy.sparse.bsr_matrix.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.mean.html#scipy.sparse.bsr_matrix.mean',
                              'scipy.sparse.bsr_matrix.min': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.min.html#scipy.sparse.bsr_matrix.min',
                              'scipy.sparse.bsr_matrix.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.minimum.html#scipy.sparse.bsr_matrix.minimum',
                              'scipy.sparse.bsr_matrix.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.multiply.html#scipy.sparse.bsr_matrix.multiply',
                              'scipy.sparse.bsr_matrix.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.nonzero.html#scipy.sparse.bsr_matrix.nonzero',
                              'scipy.sparse.bsr_matrix.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.power.html#scipy.sparse.bsr_matrix.power',
                              'scipy.sparse.bsr_matrix.prune': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.prune.html#scipy.sparse.bsr_matrix.prune',
                              'scipy.sparse.bsr_matrix.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.rad2deg.html#scipy.sparse.bsr_matrix.rad2deg',
                              'scipy.sparse.bsr_matrix.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.reshape.html#scipy.sparse.bsr_matrix.reshape',
                              'scipy.sparse.bsr_matrix.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.resize.html#scipy.sparse.bsr_matrix.resize',
                              'scipy.sparse.bsr_matrix.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.rint.html#scipy.sparse.bsr_matrix.rint',
                              'scipy.sparse.bsr_matrix.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.set_shape.html#scipy.sparse.bsr_matrix.set_shape',
                              'scipy.sparse.bsr_matrix.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.setdiag.html#scipy.sparse.bsr_matrix.setdiag',
                              'scipy.sparse.bsr_matrix.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.sign.html#scipy.sparse.bsr_matrix.sign',
                              'scipy.sparse.bsr_matrix.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.sin.html#scipy.sparse.bsr_matrix.sin',
                              'scipy.sparse.bsr_matrix.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.sinh.html#scipy.sparse.bsr_matrix.sinh',
                              'scipy.sparse.bsr_matrix.sort_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.sort_indices.html#scipy.sparse.bsr_matrix.sort_indices',
                              'scipy.sparse.bsr_matrix.sorted_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.sorted_indices.html#scipy.sparse.bsr_matrix.sorted_indices',
                              'scipy.sparse.bsr_matrix.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.sqrt.html#scipy.sparse.bsr_matrix.sqrt',
                              'scipy.sparse.bsr_matrix.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.sum.html#scipy.sparse.bsr_matrix.sum',
                              'scipy.sparse.bsr_matrix.sum_duplicates': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.sum_duplicates.html#scipy.sparse.bsr_matrix.sum_duplicates',
                              'scipy.sparse.bsr_matrix.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.tan.html#scipy.sparse.bsr_matrix.tan',
                              'scipy.sparse.bsr_matrix.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.tanh.html#scipy.sparse.bsr_matrix.tanh',
                              'scipy.sparse.bsr_matrix.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.toarray.html#scipy.sparse.bsr_matrix.toarray',
                              'scipy.sparse.bsr_matrix.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.tobsr.html#scipy.sparse.bsr_matrix.tobsr',
                              'scipy.sparse.bsr_matrix.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.tocoo.html#scipy.sparse.bsr_matrix.tocoo',
                              'scipy.sparse.bsr_matrix.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.tocsc.html#scipy.sparse.bsr_matrix.tocsc',
                              'scipy.sparse.bsr_matrix.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.tocsr.html#scipy.sparse.bsr_matrix.tocsr',
                              'scipy.sparse.bsr_matrix.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.todense.html#scipy.sparse.bsr_matrix.todense',
                              'scipy.sparse.bsr_matrix.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.todia.html#scipy.sparse.bsr_matrix.todia',
                              'scipy.sparse.bsr_matrix.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.todok.html#scipy.sparse.bsr_matrix.todok',
                              'scipy.sparse.bsr_matrix.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.tolil.html#scipy.sparse.bsr_matrix.tolil',
                              'scipy.sparse.bsr_matrix.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.trace.html#scipy.sparse.bsr_matrix.trace',
                              'scipy.sparse.bsr_matrix.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.transpose.html#scipy.sparse.bsr_matrix.transpose',
                              'scipy.sparse.bsr_matrix.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.trunc.html#scipy.sparse.bsr_matrix.trunc',
                              'scipy.sparse.coo_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.html#scipy.sparse.coo_array',
                              'scipy.sparse.coo_array.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.__len__.html#scipy.sparse.coo_array.__len__',
                              'scipy.sparse.coo_array.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.__mul__.html#scipy.sparse.coo_array.__mul__',
                              'scipy.sparse.coo_array.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.arcsin.html#scipy.sparse.coo_array.arcsin',
                              'scipy.sparse.coo_array.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.arcsinh.html#scipy.sparse.coo_array.arcsinh',
                              'scipy.sparse.coo_array.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.arctan.html#scipy.sparse.coo_array.arctan',
                              'scipy.sparse.coo_array.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.arctanh.html#scipy.sparse.coo_array.arctanh',
                              'scipy.sparse.coo_array.argmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.argmax.html#scipy.sparse.coo_array.argmax',
                              'scipy.sparse.coo_array.argmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.argmin.html#scipy.sparse.coo_array.argmin',
                              'scipy.sparse.coo_array.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.asformat.html#scipy.sparse.coo_array.asformat',
                              'scipy.sparse.coo_array.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.asfptype.html#scipy.sparse.coo_array.asfptype',
                              'scipy.sparse.coo_array.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.astype.html#scipy.sparse.coo_array.astype',
                              'scipy.sparse.coo_array.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.ceil.html#scipy.sparse.coo_array.ceil',
                              'scipy.sparse.coo_array.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.conj.html#scipy.sparse.coo_array.conj',
                              'scipy.sparse.coo_array.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.conjugate.html#scipy.sparse.coo_array.conjugate',
                              'scipy.sparse.coo_array.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.copy.html#scipy.sparse.coo_array.copy',
                              'scipy.sparse.coo_array.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.count_nonzero.html#scipy.sparse.coo_array.count_nonzero',
                              'scipy.sparse.coo_array.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.deg2rad.html#scipy.sparse.coo_array.deg2rad',
                              'scipy.sparse.coo_array.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.diagonal.html#scipy.sparse.coo_array.diagonal',
                              'scipy.sparse.coo_array.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.dot.html#scipy.sparse.coo_array.dot',
                              'scipy.sparse.coo_array.eliminate_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.eliminate_zeros.html#scipy.sparse.coo_array.eliminate_zeros',
                              'scipy.sparse.coo_array.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.expm1.html#scipy.sparse.coo_array.expm1',
                              'scipy.sparse.coo_array.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.floor.html#scipy.sparse.coo_array.floor',
                              'scipy.sparse.coo_array.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.getH.html#scipy.sparse.coo_array.getH',
                              'scipy.sparse.coo_array.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.get_shape.html#scipy.sparse.coo_array.get_shape',
                              'scipy.sparse.coo_array.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.getcol.html#scipy.sparse.coo_array.getcol',
                              'scipy.sparse.coo_array.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.getformat.html#scipy.sparse.coo_array.getformat',
                              'scipy.sparse.coo_array.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.getmaxprint.html#scipy.sparse.coo_array.getmaxprint',
                              'scipy.sparse.coo_array.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.getnnz.html#scipy.sparse.coo_array.getnnz',
                              'scipy.sparse.coo_array.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.getrow.html#scipy.sparse.coo_array.getrow',
                              'scipy.sparse.coo_array.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.log1p.html#scipy.sparse.coo_array.log1p',
                              'scipy.sparse.coo_array.max': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.max.html#scipy.sparse.coo_array.max',
                              'scipy.sparse.coo_array.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.maximum.html#scipy.sparse.coo_array.maximum',
                              'scipy.sparse.coo_array.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.mean.html#scipy.sparse.coo_array.mean',
                              'scipy.sparse.coo_array.min': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.min.html#scipy.sparse.coo_array.min',
                              'scipy.sparse.coo_array.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.minimum.html#scipy.sparse.coo_array.minimum',
                              'scipy.sparse.coo_array.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.multiply.html#scipy.sparse.coo_array.multiply',
                              'scipy.sparse.coo_array.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.nonzero.html#scipy.sparse.coo_array.nonzero',
                              'scipy.sparse.coo_array.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.power.html#scipy.sparse.coo_array.power',
                              'scipy.sparse.coo_array.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.rad2deg.html#scipy.sparse.coo_array.rad2deg',
                              'scipy.sparse.coo_array.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.reshape.html#scipy.sparse.coo_array.reshape',
                              'scipy.sparse.coo_array.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.resize.html#scipy.sparse.coo_array.resize',
                              'scipy.sparse.coo_array.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.rint.html#scipy.sparse.coo_array.rint',
                              'scipy.sparse.coo_array.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.set_shape.html#scipy.sparse.coo_array.set_shape',
                              'scipy.sparse.coo_array.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.setdiag.html#scipy.sparse.coo_array.setdiag',
                              'scipy.sparse.coo_array.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.sign.html#scipy.sparse.coo_array.sign',
                              'scipy.sparse.coo_array.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.sin.html#scipy.sparse.coo_array.sin',
                              'scipy.sparse.coo_array.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.sinh.html#scipy.sparse.coo_array.sinh',
                              'scipy.sparse.coo_array.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.sqrt.html#scipy.sparse.coo_array.sqrt',
                              'scipy.sparse.coo_array.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.sum.html#scipy.sparse.coo_array.sum',
                              'scipy.sparse.coo_array.sum_duplicates': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.sum_duplicates.html#scipy.sparse.coo_array.sum_duplicates',
                              'scipy.sparse.coo_array.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.tan.html#scipy.sparse.coo_array.tan',
                              'scipy.sparse.coo_array.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.tanh.html#scipy.sparse.coo_array.tanh',
                              'scipy.sparse.coo_array.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.toarray.html#scipy.sparse.coo_array.toarray',
                              'scipy.sparse.coo_array.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.tobsr.html#scipy.sparse.coo_array.tobsr',
                              'scipy.sparse.coo_array.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.tocoo.html#scipy.sparse.coo_array.tocoo',
                              'scipy.sparse.coo_array.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.tocsc.html#scipy.sparse.coo_array.tocsc',
                              'scipy.sparse.coo_array.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.tocsr.html#scipy.sparse.coo_array.tocsr',
                              'scipy.sparse.coo_array.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.todense.html#scipy.sparse.coo_array.todense',
                              'scipy.sparse.coo_array.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.todia.html#scipy.sparse.coo_array.todia',
                              'scipy.sparse.coo_array.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.todok.html#scipy.sparse.coo_array.todok',
                              'scipy.sparse.coo_array.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.tolil.html#scipy.sparse.coo_array.tolil',
                              'scipy.sparse.coo_array.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.trace.html#scipy.sparse.coo_array.trace',
                              'scipy.sparse.coo_array.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.transpose.html#scipy.sparse.coo_array.transpose',
                              'scipy.sparse.coo_array.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.trunc.html#scipy.sparse.coo_array.trunc',
                              'scipy.sparse.coo_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.html#scipy.sparse.coo_matrix',
                              'scipy.sparse.coo_matrix.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.__len__.html#scipy.sparse.coo_matrix.__len__',
                              'scipy.sparse.coo_matrix.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.__mul__.html#scipy.sparse.coo_matrix.__mul__',
                              'scipy.sparse.coo_matrix.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.arcsin.html#scipy.sparse.coo_matrix.arcsin',
                              'scipy.sparse.coo_matrix.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.arcsinh.html#scipy.sparse.coo_matrix.arcsinh',
                              'scipy.sparse.coo_matrix.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.arctan.html#scipy.sparse.coo_matrix.arctan',
                              'scipy.sparse.coo_matrix.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.arctanh.html#scipy.sparse.coo_matrix.arctanh',
                              'scipy.sparse.coo_matrix.argmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.argmax.html#scipy.sparse.coo_matrix.argmax',
                              'scipy.sparse.coo_matrix.argmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.argmin.html#scipy.sparse.coo_matrix.argmin',
                              'scipy.sparse.coo_matrix.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.asformat.html#scipy.sparse.coo_matrix.asformat',
                              'scipy.sparse.coo_matrix.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.asfptype.html#scipy.sparse.coo_matrix.asfptype',
                              'scipy.sparse.coo_matrix.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.astype.html#scipy.sparse.coo_matrix.astype',
                              'scipy.sparse.coo_matrix.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.ceil.html#scipy.sparse.coo_matrix.ceil',
                              'scipy.sparse.coo_matrix.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.conj.html#scipy.sparse.coo_matrix.conj',
                              'scipy.sparse.coo_matrix.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.conjugate.html#scipy.sparse.coo_matrix.conjugate',
                              'scipy.sparse.coo_matrix.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.copy.html#scipy.sparse.coo_matrix.copy',
                              'scipy.sparse.coo_matrix.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.count_nonzero.html#scipy.sparse.coo_matrix.count_nonzero',
                              'scipy.sparse.coo_matrix.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.deg2rad.html#scipy.sparse.coo_matrix.deg2rad',
                              'scipy.sparse.coo_matrix.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.diagonal.html#scipy.sparse.coo_matrix.diagonal',
                              'scipy.sparse.coo_matrix.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.dot.html#scipy.sparse.coo_matrix.dot',
                              'scipy.sparse.coo_matrix.eliminate_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.eliminate_zeros.html#scipy.sparse.coo_matrix.eliminate_zeros',
                              'scipy.sparse.coo_matrix.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.expm1.html#scipy.sparse.coo_matrix.expm1',
                              'scipy.sparse.coo_matrix.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.floor.html#scipy.sparse.coo_matrix.floor',
                              'scipy.sparse.coo_matrix.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.getH.html#scipy.sparse.coo_matrix.getH',
                              'scipy.sparse.coo_matrix.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.get_shape.html#scipy.sparse.coo_matrix.get_shape',
                              'scipy.sparse.coo_matrix.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.getcol.html#scipy.sparse.coo_matrix.getcol',
                              'scipy.sparse.coo_matrix.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.getformat.html#scipy.sparse.coo_matrix.getformat',
                              'scipy.sparse.coo_matrix.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.getmaxprint.html#scipy.sparse.coo_matrix.getmaxprint',
                              'scipy.sparse.coo_matrix.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.getnnz.html#scipy.sparse.coo_matrix.getnnz',
                              'scipy.sparse.coo_matrix.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.getrow.html#scipy.sparse.coo_matrix.getrow',
                              'scipy.sparse.coo_matrix.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.log1p.html#scipy.sparse.coo_matrix.log1p',
                              'scipy.sparse.coo_matrix.max': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.max.html#scipy.sparse.coo_matrix.max',
                              'scipy.sparse.coo_matrix.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.maximum.html#scipy.sparse.coo_matrix.maximum',
                              'scipy.sparse.coo_matrix.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.mean.html#scipy.sparse.coo_matrix.mean',
                              'scipy.sparse.coo_matrix.min': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.min.html#scipy.sparse.coo_matrix.min',
                              'scipy.sparse.coo_matrix.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.minimum.html#scipy.sparse.coo_matrix.minimum',
                              'scipy.sparse.coo_matrix.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.multiply.html#scipy.sparse.coo_matrix.multiply',
                              'scipy.sparse.coo_matrix.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.nonzero.html#scipy.sparse.coo_matrix.nonzero',
                              'scipy.sparse.coo_matrix.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.power.html#scipy.sparse.coo_matrix.power',
                              'scipy.sparse.coo_matrix.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.rad2deg.html#scipy.sparse.coo_matrix.rad2deg',
                              'scipy.sparse.coo_matrix.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.reshape.html#scipy.sparse.coo_matrix.reshape',
                              'scipy.sparse.coo_matrix.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.resize.html#scipy.sparse.coo_matrix.resize',
                              'scipy.sparse.coo_matrix.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.rint.html#scipy.sparse.coo_matrix.rint',
                              'scipy.sparse.coo_matrix.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.set_shape.html#scipy.sparse.coo_matrix.set_shape',
                              'scipy.sparse.coo_matrix.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.setdiag.html#scipy.sparse.coo_matrix.setdiag',
                              'scipy.sparse.coo_matrix.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.sign.html#scipy.sparse.coo_matrix.sign',
                              'scipy.sparse.coo_matrix.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.sin.html#scipy.sparse.coo_matrix.sin',
                              'scipy.sparse.coo_matrix.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.sinh.html#scipy.sparse.coo_matrix.sinh',
                              'scipy.sparse.coo_matrix.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.sqrt.html#scipy.sparse.coo_matrix.sqrt',
                              'scipy.sparse.coo_matrix.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.sum.html#scipy.sparse.coo_matrix.sum',
                              'scipy.sparse.coo_matrix.sum_duplicates': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.sum_duplicates.html#scipy.sparse.coo_matrix.sum_duplicates',
                              'scipy.sparse.coo_matrix.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.tan.html#scipy.sparse.coo_matrix.tan',
                              'scipy.sparse.coo_matrix.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.tanh.html#scipy.sparse.coo_matrix.tanh',
                              'scipy.sparse.coo_matrix.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.toarray.html#scipy.sparse.coo_matrix.toarray',
                              'scipy.sparse.coo_matrix.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.tobsr.html#scipy.sparse.coo_matrix.tobsr',
                              'scipy.sparse.coo_matrix.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.tocoo.html#scipy.sparse.coo_matrix.tocoo',
                              'scipy.sparse.coo_matrix.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.tocsc.html#scipy.sparse.coo_matrix.tocsc',
                              'scipy.sparse.coo_matrix.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.tocsr.html#scipy.sparse.coo_matrix.tocsr',
                              'scipy.sparse.coo_matrix.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.todense.html#scipy.sparse.coo_matrix.todense',
                              'scipy.sparse.coo_matrix.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.todia.html#scipy.sparse.coo_matrix.todia',
                              'scipy.sparse.coo_matrix.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.todok.html#scipy.sparse.coo_matrix.todok',
                              'scipy.sparse.coo_matrix.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.tolil.html#scipy.sparse.coo_matrix.tolil',
                              'scipy.sparse.coo_matrix.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.trace.html#scipy.sparse.coo_matrix.trace',
                              'scipy.sparse.coo_matrix.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.transpose.html#scipy.sparse.coo_matrix.transpose',
                              'scipy.sparse.coo_matrix.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.trunc.html#scipy.sparse.coo_matrix.trunc',
                              'scipy.sparse.csc_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.html#scipy.sparse.csc_array',
                              'scipy.sparse.csc_array.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.__getitem__.html#scipy.sparse.csc_array.__getitem__',
                              'scipy.sparse.csc_array.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.__len__.html#scipy.sparse.csc_array.__len__',
                              'scipy.sparse.csc_array.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.__mul__.html#scipy.sparse.csc_array.__mul__',
                              'scipy.sparse.csc_array.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.arcsin.html#scipy.sparse.csc_array.arcsin',
                              'scipy.sparse.csc_array.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.arcsinh.html#scipy.sparse.csc_array.arcsinh',
                              'scipy.sparse.csc_array.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.arctan.html#scipy.sparse.csc_array.arctan',
                              'scipy.sparse.csc_array.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.arctanh.html#scipy.sparse.csc_array.arctanh',
                              'scipy.sparse.csc_array.argmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.argmax.html#scipy.sparse.csc_array.argmax',
                              'scipy.sparse.csc_array.argmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.argmin.html#scipy.sparse.csc_array.argmin',
                              'scipy.sparse.csc_array.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.asformat.html#scipy.sparse.csc_array.asformat',
                              'scipy.sparse.csc_array.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.asfptype.html#scipy.sparse.csc_array.asfptype',
                              'scipy.sparse.csc_array.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.astype.html#scipy.sparse.csc_array.astype',
                              'scipy.sparse.csc_array.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.ceil.html#scipy.sparse.csc_array.ceil',
                              'scipy.sparse.csc_array.check_format': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.check_format.html#scipy.sparse.csc_array.check_format',
                              'scipy.sparse.csc_array.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.conj.html#scipy.sparse.csc_array.conj',
                              'scipy.sparse.csc_array.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.conjugate.html#scipy.sparse.csc_array.conjugate',
                              'scipy.sparse.csc_array.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.copy.html#scipy.sparse.csc_array.copy',
                              'scipy.sparse.csc_array.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.count_nonzero.html#scipy.sparse.csc_array.count_nonzero',
                              'scipy.sparse.csc_array.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.deg2rad.html#scipy.sparse.csc_array.deg2rad',
                              'scipy.sparse.csc_array.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.diagonal.html#scipy.sparse.csc_array.diagonal',
                              'scipy.sparse.csc_array.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.dot.html#scipy.sparse.csc_array.dot',
                              'scipy.sparse.csc_array.eliminate_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.eliminate_zeros.html#scipy.sparse.csc_array.eliminate_zeros',
                              'scipy.sparse.csc_array.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.expm1.html#scipy.sparse.csc_array.expm1',
                              'scipy.sparse.csc_array.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.floor.html#scipy.sparse.csc_array.floor',
                              'scipy.sparse.csc_array.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.getH.html#scipy.sparse.csc_array.getH',
                              'scipy.sparse.csc_array.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.get_shape.html#scipy.sparse.csc_array.get_shape',
                              'scipy.sparse.csc_array.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.getcol.html#scipy.sparse.csc_array.getcol',
                              'scipy.sparse.csc_array.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.getformat.html#scipy.sparse.csc_array.getformat',
                              'scipy.sparse.csc_array.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.getmaxprint.html#scipy.sparse.csc_array.getmaxprint',
                              'scipy.sparse.csc_array.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.getnnz.html#scipy.sparse.csc_array.getnnz',
                              'scipy.sparse.csc_array.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.getrow.html#scipy.sparse.csc_array.getrow',
                              'scipy.sparse.csc_array.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.log1p.html#scipy.sparse.csc_array.log1p',
                              'scipy.sparse.csc_array.max': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.max.html#scipy.sparse.csc_array.max',
                              'scipy.sparse.csc_array.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.maximum.html#scipy.sparse.csc_array.maximum',
                              'scipy.sparse.csc_array.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.mean.html#scipy.sparse.csc_array.mean',
                              'scipy.sparse.csc_array.min': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.min.html#scipy.sparse.csc_array.min',
                              'scipy.sparse.csc_array.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.minimum.html#scipy.sparse.csc_array.minimum',
                              'scipy.sparse.csc_array.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.multiply.html#scipy.sparse.csc_array.multiply',
                              'scipy.sparse.csc_array.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.nonzero.html#scipy.sparse.csc_array.nonzero',
                              'scipy.sparse.csc_array.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.power.html#scipy.sparse.csc_array.power',
                              'scipy.sparse.csc_array.prune': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.prune.html#scipy.sparse.csc_array.prune',
                              'scipy.sparse.csc_array.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.rad2deg.html#scipy.sparse.csc_array.rad2deg',
                              'scipy.sparse.csc_array.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.reshape.html#scipy.sparse.csc_array.reshape',
                              'scipy.sparse.csc_array.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.resize.html#scipy.sparse.csc_array.resize',
                              'scipy.sparse.csc_array.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.rint.html#scipy.sparse.csc_array.rint',
                              'scipy.sparse.csc_array.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.set_shape.html#scipy.sparse.csc_array.set_shape',
                              'scipy.sparse.csc_array.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.setdiag.html#scipy.sparse.csc_array.setdiag',
                              'scipy.sparse.csc_array.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.sign.html#scipy.sparse.csc_array.sign',
                              'scipy.sparse.csc_array.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.sin.html#scipy.sparse.csc_array.sin',
                              'scipy.sparse.csc_array.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.sinh.html#scipy.sparse.csc_array.sinh',
                              'scipy.sparse.csc_array.sort_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.sort_indices.html#scipy.sparse.csc_array.sort_indices',
                              'scipy.sparse.csc_array.sorted_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.sorted_indices.html#scipy.sparse.csc_array.sorted_indices',
                              'scipy.sparse.csc_array.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.sqrt.html#scipy.sparse.csc_array.sqrt',
                              'scipy.sparse.csc_array.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.sum.html#scipy.sparse.csc_array.sum',
                              'scipy.sparse.csc_array.sum_duplicates': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.sum_duplicates.html#scipy.sparse.csc_array.sum_duplicates',
                              'scipy.sparse.csc_array.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.tan.html#scipy.sparse.csc_array.tan',
                              'scipy.sparse.csc_array.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.tanh.html#scipy.sparse.csc_array.tanh',
                              'scipy.sparse.csc_array.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.toarray.html#scipy.sparse.csc_array.toarray',
                              'scipy.sparse.csc_array.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.tobsr.html#scipy.sparse.csc_array.tobsr',
                              'scipy.sparse.csc_array.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.tocoo.html#scipy.sparse.csc_array.tocoo',
                              'scipy.sparse.csc_array.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.tocsc.html#scipy.sparse.csc_array.tocsc',
                              'scipy.sparse.csc_array.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.tocsr.html#scipy.sparse.csc_array.tocsr',
                              'scipy.sparse.csc_array.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.todense.html#scipy.sparse.csc_array.todense',
                              'scipy.sparse.csc_array.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.todia.html#scipy.sparse.csc_array.todia',
                              'scipy.sparse.csc_array.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.todok.html#scipy.sparse.csc_array.todok',
                              'scipy.sparse.csc_array.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.tolil.html#scipy.sparse.csc_array.tolil',
                              'scipy.sparse.csc_array.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.trace.html#scipy.sparse.csc_array.trace',
                              'scipy.sparse.csc_array.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.transpose.html#scipy.sparse.csc_array.transpose',
                              'scipy.sparse.csc_array.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.trunc.html#scipy.sparse.csc_array.trunc',
                              'scipy.sparse.csc_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.html#scipy.sparse.csc_matrix',
                              'scipy.sparse.csc_matrix.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.__getitem__.html#scipy.sparse.csc_matrix.__getitem__',
                              'scipy.sparse.csc_matrix.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.__len__.html#scipy.sparse.csc_matrix.__len__',
                              'scipy.sparse.csc_matrix.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.__mul__.html#scipy.sparse.csc_matrix.__mul__',
                              'scipy.sparse.csc_matrix.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.arcsin.html#scipy.sparse.csc_matrix.arcsin',
                              'scipy.sparse.csc_matrix.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.arcsinh.html#scipy.sparse.csc_matrix.arcsinh',
                              'scipy.sparse.csc_matrix.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.arctan.html#scipy.sparse.csc_matrix.arctan',
                              'scipy.sparse.csc_matrix.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.arctanh.html#scipy.sparse.csc_matrix.arctanh',
                              'scipy.sparse.csc_matrix.argmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.argmax.html#scipy.sparse.csc_matrix.argmax',
                              'scipy.sparse.csc_matrix.argmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.argmin.html#scipy.sparse.csc_matrix.argmin',
                              'scipy.sparse.csc_matrix.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.asformat.html#scipy.sparse.csc_matrix.asformat',
                              'scipy.sparse.csc_matrix.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.asfptype.html#scipy.sparse.csc_matrix.asfptype',
                              'scipy.sparse.csc_matrix.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.astype.html#scipy.sparse.csc_matrix.astype',
                              'scipy.sparse.csc_matrix.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.ceil.html#scipy.sparse.csc_matrix.ceil',
                              'scipy.sparse.csc_matrix.check_format': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.check_format.html#scipy.sparse.csc_matrix.check_format',
                              'scipy.sparse.csc_matrix.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.conj.html#scipy.sparse.csc_matrix.conj',
                              'scipy.sparse.csc_matrix.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.conjugate.html#scipy.sparse.csc_matrix.conjugate',
                              'scipy.sparse.csc_matrix.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.copy.html#scipy.sparse.csc_matrix.copy',
                              'scipy.sparse.csc_matrix.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.count_nonzero.html#scipy.sparse.csc_matrix.count_nonzero',
                              'scipy.sparse.csc_matrix.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.deg2rad.html#scipy.sparse.csc_matrix.deg2rad',
                              'scipy.sparse.csc_matrix.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.diagonal.html#scipy.sparse.csc_matrix.diagonal',
                              'scipy.sparse.csc_matrix.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.dot.html#scipy.sparse.csc_matrix.dot',
                              'scipy.sparse.csc_matrix.eliminate_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.eliminate_zeros.html#scipy.sparse.csc_matrix.eliminate_zeros',
                              'scipy.sparse.csc_matrix.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.expm1.html#scipy.sparse.csc_matrix.expm1',
                              'scipy.sparse.csc_matrix.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.floor.html#scipy.sparse.csc_matrix.floor',
                              'scipy.sparse.csc_matrix.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.getH.html#scipy.sparse.csc_matrix.getH',
                              'scipy.sparse.csc_matrix.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.get_shape.html#scipy.sparse.csc_matrix.get_shape',
                              'scipy.sparse.csc_matrix.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.getcol.html#scipy.sparse.csc_matrix.getcol',
                              'scipy.sparse.csc_matrix.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.getformat.html#scipy.sparse.csc_matrix.getformat',
                              'scipy.sparse.csc_matrix.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.getmaxprint.html#scipy.sparse.csc_matrix.getmaxprint',
                              'scipy.sparse.csc_matrix.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.getnnz.html#scipy.sparse.csc_matrix.getnnz',
                              'scipy.sparse.csc_matrix.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.getrow.html#scipy.sparse.csc_matrix.getrow',
                              'scipy.sparse.csc_matrix.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.log1p.html#scipy.sparse.csc_matrix.log1p',
                              'scipy.sparse.csc_matrix.max': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.max.html#scipy.sparse.csc_matrix.max',
                              'scipy.sparse.csc_matrix.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.maximum.html#scipy.sparse.csc_matrix.maximum',
                              'scipy.sparse.csc_matrix.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.mean.html#scipy.sparse.csc_matrix.mean',
                              'scipy.sparse.csc_matrix.min': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.min.html#scipy.sparse.csc_matrix.min',
                              'scipy.sparse.csc_matrix.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.minimum.html#scipy.sparse.csc_matrix.minimum',
                              'scipy.sparse.csc_matrix.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.multiply.html#scipy.sparse.csc_matrix.multiply',
                              'scipy.sparse.csc_matrix.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.nonzero.html#scipy.sparse.csc_matrix.nonzero',
                              'scipy.sparse.csc_matrix.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.power.html#scipy.sparse.csc_matrix.power',
                              'scipy.sparse.csc_matrix.prune': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.prune.html#scipy.sparse.csc_matrix.prune',
                              'scipy.sparse.csc_matrix.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.rad2deg.html#scipy.sparse.csc_matrix.rad2deg',
                              'scipy.sparse.csc_matrix.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.reshape.html#scipy.sparse.csc_matrix.reshape',
                              'scipy.sparse.csc_matrix.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.resize.html#scipy.sparse.csc_matrix.resize',
                              'scipy.sparse.csc_matrix.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.rint.html#scipy.sparse.csc_matrix.rint',
                              'scipy.sparse.csc_matrix.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.set_shape.html#scipy.sparse.csc_matrix.set_shape',
                              'scipy.sparse.csc_matrix.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.setdiag.html#scipy.sparse.csc_matrix.setdiag',
                              'scipy.sparse.csc_matrix.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.sign.html#scipy.sparse.csc_matrix.sign',
                              'scipy.sparse.csc_matrix.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.sin.html#scipy.sparse.csc_matrix.sin',
                              'scipy.sparse.csc_matrix.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.sinh.html#scipy.sparse.csc_matrix.sinh',
                              'scipy.sparse.csc_matrix.sort_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.sort_indices.html#scipy.sparse.csc_matrix.sort_indices',
                              'scipy.sparse.csc_matrix.sorted_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.sorted_indices.html#scipy.sparse.csc_matrix.sorted_indices',
                              'scipy.sparse.csc_matrix.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.sqrt.html#scipy.sparse.csc_matrix.sqrt',
                              'scipy.sparse.csc_matrix.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.sum.html#scipy.sparse.csc_matrix.sum',
                              'scipy.sparse.csc_matrix.sum_duplicates': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.sum_duplicates.html#scipy.sparse.csc_matrix.sum_duplicates',
                              'scipy.sparse.csc_matrix.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.tan.html#scipy.sparse.csc_matrix.tan',
                              'scipy.sparse.csc_matrix.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.tanh.html#scipy.sparse.csc_matrix.tanh',
                              'scipy.sparse.csc_matrix.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.toarray.html#scipy.sparse.csc_matrix.toarray',
                              'scipy.sparse.csc_matrix.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.tobsr.html#scipy.sparse.csc_matrix.tobsr',
                              'scipy.sparse.csc_matrix.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.tocoo.html#scipy.sparse.csc_matrix.tocoo',
                              'scipy.sparse.csc_matrix.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.tocsc.html#scipy.sparse.csc_matrix.tocsc',
                              'scipy.sparse.csc_matrix.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.tocsr.html#scipy.sparse.csc_matrix.tocsr',
                              'scipy.sparse.csc_matrix.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.todense.html#scipy.sparse.csc_matrix.todense',
                              'scipy.sparse.csc_matrix.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.todia.html#scipy.sparse.csc_matrix.todia',
                              'scipy.sparse.csc_matrix.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.todok.html#scipy.sparse.csc_matrix.todok',
                              'scipy.sparse.csc_matrix.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.tolil.html#scipy.sparse.csc_matrix.tolil',
                              'scipy.sparse.csc_matrix.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.trace.html#scipy.sparse.csc_matrix.trace',
                              'scipy.sparse.csc_matrix.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.transpose.html#scipy.sparse.csc_matrix.transpose',
                              'scipy.sparse.csc_matrix.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.trunc.html#scipy.sparse.csc_matrix.trunc',
                              'scipy.sparse.csgraph': 'https://docs.scipy.org/doc/scipy/reference/reference/sparse.csgraph.html#module-scipy.sparse.csgraph',
                              'scipy.sparse.csr_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.html#scipy.sparse.csr_array',
                              'scipy.sparse.csr_array.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.__getitem__.html#scipy.sparse.csr_array.__getitem__',
                              'scipy.sparse.csr_array.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.__len__.html#scipy.sparse.csr_array.__len__',
                              'scipy.sparse.csr_array.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.__mul__.html#scipy.sparse.csr_array.__mul__',
                              'scipy.sparse.csr_array.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.arcsin.html#scipy.sparse.csr_array.arcsin',
                              'scipy.sparse.csr_array.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.arcsinh.html#scipy.sparse.csr_array.arcsinh',
                              'scipy.sparse.csr_array.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.arctan.html#scipy.sparse.csr_array.arctan',
                              'scipy.sparse.csr_array.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.arctanh.html#scipy.sparse.csr_array.arctanh',
                              'scipy.sparse.csr_array.argmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.argmax.html#scipy.sparse.csr_array.argmax',
                              'scipy.sparse.csr_array.argmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.argmin.html#scipy.sparse.csr_array.argmin',
                              'scipy.sparse.csr_array.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.asformat.html#scipy.sparse.csr_array.asformat',
                              'scipy.sparse.csr_array.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.asfptype.html#scipy.sparse.csr_array.asfptype',
                              'scipy.sparse.csr_array.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.astype.html#scipy.sparse.csr_array.astype',
                              'scipy.sparse.csr_array.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.ceil.html#scipy.sparse.csr_array.ceil',
                              'scipy.sparse.csr_array.check_format': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.check_format.html#scipy.sparse.csr_array.check_format',
                              'scipy.sparse.csr_array.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.conj.html#scipy.sparse.csr_array.conj',
                              'scipy.sparse.csr_array.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.conjugate.html#scipy.sparse.csr_array.conjugate',
                              'scipy.sparse.csr_array.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.copy.html#scipy.sparse.csr_array.copy',
                              'scipy.sparse.csr_array.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.count_nonzero.html#scipy.sparse.csr_array.count_nonzero',
                              'scipy.sparse.csr_array.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.deg2rad.html#scipy.sparse.csr_array.deg2rad',
                              'scipy.sparse.csr_array.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.diagonal.html#scipy.sparse.csr_array.diagonal',
                              'scipy.sparse.csr_array.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.dot.html#scipy.sparse.csr_array.dot',
                              'scipy.sparse.csr_array.eliminate_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.eliminate_zeros.html#scipy.sparse.csr_array.eliminate_zeros',
                              'scipy.sparse.csr_array.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.expm1.html#scipy.sparse.csr_array.expm1',
                              'scipy.sparse.csr_array.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.floor.html#scipy.sparse.csr_array.floor',
                              'scipy.sparse.csr_array.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.getH.html#scipy.sparse.csr_array.getH',
                              'scipy.sparse.csr_array.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.get_shape.html#scipy.sparse.csr_array.get_shape',
                              'scipy.sparse.csr_array.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.getcol.html#scipy.sparse.csr_array.getcol',
                              'scipy.sparse.csr_array.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.getformat.html#scipy.sparse.csr_array.getformat',
                              'scipy.sparse.csr_array.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.getmaxprint.html#scipy.sparse.csr_array.getmaxprint',
                              'scipy.sparse.csr_array.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.getnnz.html#scipy.sparse.csr_array.getnnz',
                              'scipy.sparse.csr_array.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.getrow.html#scipy.sparse.csr_array.getrow',
                              'scipy.sparse.csr_array.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.log1p.html#scipy.sparse.csr_array.log1p',
                              'scipy.sparse.csr_array.max': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.max.html#scipy.sparse.csr_array.max',
                              'scipy.sparse.csr_array.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.maximum.html#scipy.sparse.csr_array.maximum',
                              'scipy.sparse.csr_array.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.mean.html#scipy.sparse.csr_array.mean',
                              'scipy.sparse.csr_array.min': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.min.html#scipy.sparse.csr_array.min',
                              'scipy.sparse.csr_array.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.minimum.html#scipy.sparse.csr_array.minimum',
                              'scipy.sparse.csr_array.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.multiply.html#scipy.sparse.csr_array.multiply',
                              'scipy.sparse.csr_array.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.nonzero.html#scipy.sparse.csr_array.nonzero',
                              'scipy.sparse.csr_array.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.power.html#scipy.sparse.csr_array.power',
                              'scipy.sparse.csr_array.prune': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.prune.html#scipy.sparse.csr_array.prune',
                              'scipy.sparse.csr_array.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.rad2deg.html#scipy.sparse.csr_array.rad2deg',
                              'scipy.sparse.csr_array.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.reshape.html#scipy.sparse.csr_array.reshape',
                              'scipy.sparse.csr_array.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.resize.html#scipy.sparse.csr_array.resize',
                              'scipy.sparse.csr_array.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.rint.html#scipy.sparse.csr_array.rint',
                              'scipy.sparse.csr_array.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.set_shape.html#scipy.sparse.csr_array.set_shape',
                              'scipy.sparse.csr_array.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.setdiag.html#scipy.sparse.csr_array.setdiag',
                              'scipy.sparse.csr_array.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.sign.html#scipy.sparse.csr_array.sign',
                              'scipy.sparse.csr_array.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.sin.html#scipy.sparse.csr_array.sin',
                              'scipy.sparse.csr_array.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.sinh.html#scipy.sparse.csr_array.sinh',
                              'scipy.sparse.csr_array.sort_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.sort_indices.html#scipy.sparse.csr_array.sort_indices',
                              'scipy.sparse.csr_array.sorted_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.sorted_indices.html#scipy.sparse.csr_array.sorted_indices',
                              'scipy.sparse.csr_array.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.sqrt.html#scipy.sparse.csr_array.sqrt',
                              'scipy.sparse.csr_array.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.sum.html#scipy.sparse.csr_array.sum',
                              'scipy.sparse.csr_array.sum_duplicates': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.sum_duplicates.html#scipy.sparse.csr_array.sum_duplicates',
                              'scipy.sparse.csr_array.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.tan.html#scipy.sparse.csr_array.tan',
                              'scipy.sparse.csr_array.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.tanh.html#scipy.sparse.csr_array.tanh',
                              'scipy.sparse.csr_array.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.toarray.html#scipy.sparse.csr_array.toarray',
                              'scipy.sparse.csr_array.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.tobsr.html#scipy.sparse.csr_array.tobsr',
                              'scipy.sparse.csr_array.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.tocoo.html#scipy.sparse.csr_array.tocoo',
                              'scipy.sparse.csr_array.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.tocsc.html#scipy.sparse.csr_array.tocsc',
                              'scipy.sparse.csr_array.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.tocsr.html#scipy.sparse.csr_array.tocsr',
                              'scipy.sparse.csr_array.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.todense.html#scipy.sparse.csr_array.todense',
                              'scipy.sparse.csr_array.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.todia.html#scipy.sparse.csr_array.todia',
                              'scipy.sparse.csr_array.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.todok.html#scipy.sparse.csr_array.todok',
                              'scipy.sparse.csr_array.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.tolil.html#scipy.sparse.csr_array.tolil',
                              'scipy.sparse.csr_array.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.trace.html#scipy.sparse.csr_array.trace',
                              'scipy.sparse.csr_array.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.transpose.html#scipy.sparse.csr_array.transpose',
                              'scipy.sparse.csr_array.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.trunc.html#scipy.sparse.csr_array.trunc',
                              'scipy.sparse.csr_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.html#scipy.sparse.csr_matrix',
                              'scipy.sparse.csr_matrix.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.__getitem__.html#scipy.sparse.csr_matrix.__getitem__',
                              'scipy.sparse.csr_matrix.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.__len__.html#scipy.sparse.csr_matrix.__len__',
                              'scipy.sparse.csr_matrix.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.__mul__.html#scipy.sparse.csr_matrix.__mul__',
                              'scipy.sparse.csr_matrix.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.arcsin.html#scipy.sparse.csr_matrix.arcsin',
                              'scipy.sparse.csr_matrix.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.arcsinh.html#scipy.sparse.csr_matrix.arcsinh',
                              'scipy.sparse.csr_matrix.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.arctan.html#scipy.sparse.csr_matrix.arctan',
                              'scipy.sparse.csr_matrix.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.arctanh.html#scipy.sparse.csr_matrix.arctanh',
                              'scipy.sparse.csr_matrix.argmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.argmax.html#scipy.sparse.csr_matrix.argmax',
                              'scipy.sparse.csr_matrix.argmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.argmin.html#scipy.sparse.csr_matrix.argmin',
                              'scipy.sparse.csr_matrix.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.asformat.html#scipy.sparse.csr_matrix.asformat',
                              'scipy.sparse.csr_matrix.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.asfptype.html#scipy.sparse.csr_matrix.asfptype',
                              'scipy.sparse.csr_matrix.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.astype.html#scipy.sparse.csr_matrix.astype',
                              'scipy.sparse.csr_matrix.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.ceil.html#scipy.sparse.csr_matrix.ceil',
                              'scipy.sparse.csr_matrix.check_format': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.check_format.html#scipy.sparse.csr_matrix.check_format',
                              'scipy.sparse.csr_matrix.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.conj.html#scipy.sparse.csr_matrix.conj',
                              'scipy.sparse.csr_matrix.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.conjugate.html#scipy.sparse.csr_matrix.conjugate',
                              'scipy.sparse.csr_matrix.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.copy.html#scipy.sparse.csr_matrix.copy',
                              'scipy.sparse.csr_matrix.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.count_nonzero.html#scipy.sparse.csr_matrix.count_nonzero',
                              'scipy.sparse.csr_matrix.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.deg2rad.html#scipy.sparse.csr_matrix.deg2rad',
                              'scipy.sparse.csr_matrix.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.diagonal.html#scipy.sparse.csr_matrix.diagonal',
                              'scipy.sparse.csr_matrix.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.dot.html#scipy.sparse.csr_matrix.dot',
                              'scipy.sparse.csr_matrix.eliminate_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.eliminate_zeros.html#scipy.sparse.csr_matrix.eliminate_zeros',
                              'scipy.sparse.csr_matrix.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.expm1.html#scipy.sparse.csr_matrix.expm1',
                              'scipy.sparse.csr_matrix.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.floor.html#scipy.sparse.csr_matrix.floor',
                              'scipy.sparse.csr_matrix.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.getH.html#scipy.sparse.csr_matrix.getH',
                              'scipy.sparse.csr_matrix.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.get_shape.html#scipy.sparse.csr_matrix.get_shape',
                              'scipy.sparse.csr_matrix.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.getcol.html#scipy.sparse.csr_matrix.getcol',
                              'scipy.sparse.csr_matrix.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.getformat.html#scipy.sparse.csr_matrix.getformat',
                              'scipy.sparse.csr_matrix.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.getmaxprint.html#scipy.sparse.csr_matrix.getmaxprint',
                              'scipy.sparse.csr_matrix.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.getnnz.html#scipy.sparse.csr_matrix.getnnz',
                              'scipy.sparse.csr_matrix.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.getrow.html#scipy.sparse.csr_matrix.getrow',
                              'scipy.sparse.csr_matrix.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.log1p.html#scipy.sparse.csr_matrix.log1p',
                              'scipy.sparse.csr_matrix.max': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.max.html#scipy.sparse.csr_matrix.max',
                              'scipy.sparse.csr_matrix.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.maximum.html#scipy.sparse.csr_matrix.maximum',
                              'scipy.sparse.csr_matrix.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.mean.html#scipy.sparse.csr_matrix.mean',
                              'scipy.sparse.csr_matrix.min': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.min.html#scipy.sparse.csr_matrix.min',
                              'scipy.sparse.csr_matrix.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.minimum.html#scipy.sparse.csr_matrix.minimum',
                              'scipy.sparse.csr_matrix.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.multiply.html#scipy.sparse.csr_matrix.multiply',
                              'scipy.sparse.csr_matrix.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.nonzero.html#scipy.sparse.csr_matrix.nonzero',
                              'scipy.sparse.csr_matrix.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.power.html#scipy.sparse.csr_matrix.power',
                              'scipy.sparse.csr_matrix.prune': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.prune.html#scipy.sparse.csr_matrix.prune',
                              'scipy.sparse.csr_matrix.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.rad2deg.html#scipy.sparse.csr_matrix.rad2deg',
                              'scipy.sparse.csr_matrix.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.reshape.html#scipy.sparse.csr_matrix.reshape',
                              'scipy.sparse.csr_matrix.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.resize.html#scipy.sparse.csr_matrix.resize',
                              'scipy.sparse.csr_matrix.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.rint.html#scipy.sparse.csr_matrix.rint',
                              'scipy.sparse.csr_matrix.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.set_shape.html#scipy.sparse.csr_matrix.set_shape',
                              'scipy.sparse.csr_matrix.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.setdiag.html#scipy.sparse.csr_matrix.setdiag',
                              'scipy.sparse.csr_matrix.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.sign.html#scipy.sparse.csr_matrix.sign',
                              'scipy.sparse.csr_matrix.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.sin.html#scipy.sparse.csr_matrix.sin',
                              'scipy.sparse.csr_matrix.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.sinh.html#scipy.sparse.csr_matrix.sinh',
                              'scipy.sparse.csr_matrix.sort_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.sort_indices.html#scipy.sparse.csr_matrix.sort_indices',
                              'scipy.sparse.csr_matrix.sorted_indices': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.sorted_indices.html#scipy.sparse.csr_matrix.sorted_indices',
                              'scipy.sparse.csr_matrix.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.sqrt.html#scipy.sparse.csr_matrix.sqrt',
                              'scipy.sparse.csr_matrix.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.sum.html#scipy.sparse.csr_matrix.sum',
                              'scipy.sparse.csr_matrix.sum_duplicates': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.sum_duplicates.html#scipy.sparse.csr_matrix.sum_duplicates',
                              'scipy.sparse.csr_matrix.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.tan.html#scipy.sparse.csr_matrix.tan',
                              'scipy.sparse.csr_matrix.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.tanh.html#scipy.sparse.csr_matrix.tanh',
                              'scipy.sparse.csr_matrix.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.toarray.html#scipy.sparse.csr_matrix.toarray',
                              'scipy.sparse.csr_matrix.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.tobsr.html#scipy.sparse.csr_matrix.tobsr',
                              'scipy.sparse.csr_matrix.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.tocoo.html#scipy.sparse.csr_matrix.tocoo',
                              'scipy.sparse.csr_matrix.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.tocsc.html#scipy.sparse.csr_matrix.tocsc',
                              'scipy.sparse.csr_matrix.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.tocsr.html#scipy.sparse.csr_matrix.tocsr',
                              'scipy.sparse.csr_matrix.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.todense.html#scipy.sparse.csr_matrix.todense',
                              'scipy.sparse.csr_matrix.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.todia.html#scipy.sparse.csr_matrix.todia',
                              'scipy.sparse.csr_matrix.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.todok.html#scipy.sparse.csr_matrix.todok',
                              'scipy.sparse.csr_matrix.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.tolil.html#scipy.sparse.csr_matrix.tolil',
                              'scipy.sparse.csr_matrix.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.trace.html#scipy.sparse.csr_matrix.trace',
                              'scipy.sparse.csr_matrix.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.transpose.html#scipy.sparse.csr_matrix.transpose',
                              'scipy.sparse.csr_matrix.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.trunc.html#scipy.sparse.csr_matrix.trunc',
                              'scipy.sparse.dia_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.html#scipy.sparse.dia_array',
                              'scipy.sparse.dia_array.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.__len__.html#scipy.sparse.dia_array.__len__',
                              'scipy.sparse.dia_array.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.__mul__.html#scipy.sparse.dia_array.__mul__',
                              'scipy.sparse.dia_array.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.arcsin.html#scipy.sparse.dia_array.arcsin',
                              'scipy.sparse.dia_array.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.arcsinh.html#scipy.sparse.dia_array.arcsinh',
                              'scipy.sparse.dia_array.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.arctan.html#scipy.sparse.dia_array.arctan',
                              'scipy.sparse.dia_array.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.arctanh.html#scipy.sparse.dia_array.arctanh',
                              'scipy.sparse.dia_array.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.asformat.html#scipy.sparse.dia_array.asformat',
                              'scipy.sparse.dia_array.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.asfptype.html#scipy.sparse.dia_array.asfptype',
                              'scipy.sparse.dia_array.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.astype.html#scipy.sparse.dia_array.astype',
                              'scipy.sparse.dia_array.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.ceil.html#scipy.sparse.dia_array.ceil',
                              'scipy.sparse.dia_array.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.conj.html#scipy.sparse.dia_array.conj',
                              'scipy.sparse.dia_array.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.conjugate.html#scipy.sparse.dia_array.conjugate',
                              'scipy.sparse.dia_array.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.copy.html#scipy.sparse.dia_array.copy',
                              'scipy.sparse.dia_array.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.count_nonzero.html#scipy.sparse.dia_array.count_nonzero',
                              'scipy.sparse.dia_array.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.deg2rad.html#scipy.sparse.dia_array.deg2rad',
                              'scipy.sparse.dia_array.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.diagonal.html#scipy.sparse.dia_array.diagonal',
                              'scipy.sparse.dia_array.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.dot.html#scipy.sparse.dia_array.dot',
                              'scipy.sparse.dia_array.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.expm1.html#scipy.sparse.dia_array.expm1',
                              'scipy.sparse.dia_array.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.floor.html#scipy.sparse.dia_array.floor',
                              'scipy.sparse.dia_array.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.getH.html#scipy.sparse.dia_array.getH',
                              'scipy.sparse.dia_array.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.get_shape.html#scipy.sparse.dia_array.get_shape',
                              'scipy.sparse.dia_array.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.getcol.html#scipy.sparse.dia_array.getcol',
                              'scipy.sparse.dia_array.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.getformat.html#scipy.sparse.dia_array.getformat',
                              'scipy.sparse.dia_array.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.getmaxprint.html#scipy.sparse.dia_array.getmaxprint',
                              'scipy.sparse.dia_array.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.getnnz.html#scipy.sparse.dia_array.getnnz',
                              'scipy.sparse.dia_array.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.getrow.html#scipy.sparse.dia_array.getrow',
                              'scipy.sparse.dia_array.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.log1p.html#scipy.sparse.dia_array.log1p',
                              'scipy.sparse.dia_array.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.maximum.html#scipy.sparse.dia_array.maximum',
                              'scipy.sparse.dia_array.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.mean.html#scipy.sparse.dia_array.mean',
                              'scipy.sparse.dia_array.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.minimum.html#scipy.sparse.dia_array.minimum',
                              'scipy.sparse.dia_array.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.multiply.html#scipy.sparse.dia_array.multiply',
                              'scipy.sparse.dia_array.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.nonzero.html#scipy.sparse.dia_array.nonzero',
                              'scipy.sparse.dia_array.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.power.html#scipy.sparse.dia_array.power',
                              'scipy.sparse.dia_array.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.rad2deg.html#scipy.sparse.dia_array.rad2deg',
                              'scipy.sparse.dia_array.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.reshape.html#scipy.sparse.dia_array.reshape',
                              'scipy.sparse.dia_array.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.resize.html#scipy.sparse.dia_array.resize',
                              'scipy.sparse.dia_array.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.rint.html#scipy.sparse.dia_array.rint',
                              'scipy.sparse.dia_array.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.set_shape.html#scipy.sparse.dia_array.set_shape',
                              'scipy.sparse.dia_array.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.setdiag.html#scipy.sparse.dia_array.setdiag',
                              'scipy.sparse.dia_array.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.sign.html#scipy.sparse.dia_array.sign',
                              'scipy.sparse.dia_array.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.sin.html#scipy.sparse.dia_array.sin',
                              'scipy.sparse.dia_array.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.sinh.html#scipy.sparse.dia_array.sinh',
                              'scipy.sparse.dia_array.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.sqrt.html#scipy.sparse.dia_array.sqrt',
                              'scipy.sparse.dia_array.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.sum.html#scipy.sparse.dia_array.sum',
                              'scipy.sparse.dia_array.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.tan.html#scipy.sparse.dia_array.tan',
                              'scipy.sparse.dia_array.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.tanh.html#scipy.sparse.dia_array.tanh',
                              'scipy.sparse.dia_array.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.toarray.html#scipy.sparse.dia_array.toarray',
                              'scipy.sparse.dia_array.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.tobsr.html#scipy.sparse.dia_array.tobsr',
                              'scipy.sparse.dia_array.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.tocoo.html#scipy.sparse.dia_array.tocoo',
                              'scipy.sparse.dia_array.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.tocsc.html#scipy.sparse.dia_array.tocsc',
                              'scipy.sparse.dia_array.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.tocsr.html#scipy.sparse.dia_array.tocsr',
                              'scipy.sparse.dia_array.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.todense.html#scipy.sparse.dia_array.todense',
                              'scipy.sparse.dia_array.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.todia.html#scipy.sparse.dia_array.todia',
                              'scipy.sparse.dia_array.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.todok.html#scipy.sparse.dia_array.todok',
                              'scipy.sparse.dia_array.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.tolil.html#scipy.sparse.dia_array.tolil',
                              'scipy.sparse.dia_array.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.trace.html#scipy.sparse.dia_array.trace',
                              'scipy.sparse.dia_array.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.transpose.html#scipy.sparse.dia_array.transpose',
                              'scipy.sparse.dia_array.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.trunc.html#scipy.sparse.dia_array.trunc',
                              'scipy.sparse.dia_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.html#scipy.sparse.dia_matrix',
                              'scipy.sparse.dia_matrix.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.__len__.html#scipy.sparse.dia_matrix.__len__',
                              'scipy.sparse.dia_matrix.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.__mul__.html#scipy.sparse.dia_matrix.__mul__',
                              'scipy.sparse.dia_matrix.arcsin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.arcsin.html#scipy.sparse.dia_matrix.arcsin',
                              'scipy.sparse.dia_matrix.arcsinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.arcsinh.html#scipy.sparse.dia_matrix.arcsinh',
                              'scipy.sparse.dia_matrix.arctan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.arctan.html#scipy.sparse.dia_matrix.arctan',
                              'scipy.sparse.dia_matrix.arctanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.arctanh.html#scipy.sparse.dia_matrix.arctanh',
                              'scipy.sparse.dia_matrix.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.asformat.html#scipy.sparse.dia_matrix.asformat',
                              'scipy.sparse.dia_matrix.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.asfptype.html#scipy.sparse.dia_matrix.asfptype',
                              'scipy.sparse.dia_matrix.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.astype.html#scipy.sparse.dia_matrix.astype',
                              'scipy.sparse.dia_matrix.ceil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.ceil.html#scipy.sparse.dia_matrix.ceil',
                              'scipy.sparse.dia_matrix.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.conj.html#scipy.sparse.dia_matrix.conj',
                              'scipy.sparse.dia_matrix.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.conjugate.html#scipy.sparse.dia_matrix.conjugate',
                              'scipy.sparse.dia_matrix.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.copy.html#scipy.sparse.dia_matrix.copy',
                              'scipy.sparse.dia_matrix.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.count_nonzero.html#scipy.sparse.dia_matrix.count_nonzero',
                              'scipy.sparse.dia_matrix.deg2rad': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.deg2rad.html#scipy.sparse.dia_matrix.deg2rad',
                              'scipy.sparse.dia_matrix.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.diagonal.html#scipy.sparse.dia_matrix.diagonal',
                              'scipy.sparse.dia_matrix.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.dot.html#scipy.sparse.dia_matrix.dot',
                              'scipy.sparse.dia_matrix.expm1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.expm1.html#scipy.sparse.dia_matrix.expm1',
                              'scipy.sparse.dia_matrix.floor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.floor.html#scipy.sparse.dia_matrix.floor',
                              'scipy.sparse.dia_matrix.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.getH.html#scipy.sparse.dia_matrix.getH',
                              'scipy.sparse.dia_matrix.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.get_shape.html#scipy.sparse.dia_matrix.get_shape',
                              'scipy.sparse.dia_matrix.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.getcol.html#scipy.sparse.dia_matrix.getcol',
                              'scipy.sparse.dia_matrix.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.getformat.html#scipy.sparse.dia_matrix.getformat',
                              'scipy.sparse.dia_matrix.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.getmaxprint.html#scipy.sparse.dia_matrix.getmaxprint',
                              'scipy.sparse.dia_matrix.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.getnnz.html#scipy.sparse.dia_matrix.getnnz',
                              'scipy.sparse.dia_matrix.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.getrow.html#scipy.sparse.dia_matrix.getrow',
                              'scipy.sparse.dia_matrix.log1p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.log1p.html#scipy.sparse.dia_matrix.log1p',
                              'scipy.sparse.dia_matrix.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.maximum.html#scipy.sparse.dia_matrix.maximum',
                              'scipy.sparse.dia_matrix.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.mean.html#scipy.sparse.dia_matrix.mean',
                              'scipy.sparse.dia_matrix.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.minimum.html#scipy.sparse.dia_matrix.minimum',
                              'scipy.sparse.dia_matrix.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.multiply.html#scipy.sparse.dia_matrix.multiply',
                              'scipy.sparse.dia_matrix.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.nonzero.html#scipy.sparse.dia_matrix.nonzero',
                              'scipy.sparse.dia_matrix.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.power.html#scipy.sparse.dia_matrix.power',
                              'scipy.sparse.dia_matrix.rad2deg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.rad2deg.html#scipy.sparse.dia_matrix.rad2deg',
                              'scipy.sparse.dia_matrix.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.reshape.html#scipy.sparse.dia_matrix.reshape',
                              'scipy.sparse.dia_matrix.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.resize.html#scipy.sparse.dia_matrix.resize',
                              'scipy.sparse.dia_matrix.rint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.rint.html#scipy.sparse.dia_matrix.rint',
                              'scipy.sparse.dia_matrix.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.set_shape.html#scipy.sparse.dia_matrix.set_shape',
                              'scipy.sparse.dia_matrix.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.setdiag.html#scipy.sparse.dia_matrix.setdiag',
                              'scipy.sparse.dia_matrix.sign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.sign.html#scipy.sparse.dia_matrix.sign',
                              'scipy.sparse.dia_matrix.sin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.sin.html#scipy.sparse.dia_matrix.sin',
                              'scipy.sparse.dia_matrix.sinh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.sinh.html#scipy.sparse.dia_matrix.sinh',
                              'scipy.sparse.dia_matrix.sqrt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.sqrt.html#scipy.sparse.dia_matrix.sqrt',
                              'scipy.sparse.dia_matrix.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.sum.html#scipy.sparse.dia_matrix.sum',
                              'scipy.sparse.dia_matrix.tan': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.tan.html#scipy.sparse.dia_matrix.tan',
                              'scipy.sparse.dia_matrix.tanh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.tanh.html#scipy.sparse.dia_matrix.tanh',
                              'scipy.sparse.dia_matrix.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.toarray.html#scipy.sparse.dia_matrix.toarray',
                              'scipy.sparse.dia_matrix.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.tobsr.html#scipy.sparse.dia_matrix.tobsr',
                              'scipy.sparse.dia_matrix.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.tocoo.html#scipy.sparse.dia_matrix.tocoo',
                              'scipy.sparse.dia_matrix.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.tocsc.html#scipy.sparse.dia_matrix.tocsc',
                              'scipy.sparse.dia_matrix.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.tocsr.html#scipy.sparse.dia_matrix.tocsr',
                              'scipy.sparse.dia_matrix.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.todense.html#scipy.sparse.dia_matrix.todense',
                              'scipy.sparse.dia_matrix.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.todia.html#scipy.sparse.dia_matrix.todia',
                              'scipy.sparse.dia_matrix.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.todok.html#scipy.sparse.dia_matrix.todok',
                              'scipy.sparse.dia_matrix.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.tolil.html#scipy.sparse.dia_matrix.tolil',
                              'scipy.sparse.dia_matrix.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.trace.html#scipy.sparse.dia_matrix.trace',
                              'scipy.sparse.dia_matrix.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.transpose.html#scipy.sparse.dia_matrix.transpose',
                              'scipy.sparse.dia_matrix.trunc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.trunc.html#scipy.sparse.dia_matrix.trunc',
                              'scipy.sparse.diags': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.diags.html#scipy.sparse.diags',
                              'scipy.sparse.dok_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.html#scipy.sparse.dok_array',
                              'scipy.sparse.dok_array.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.__getitem__.html#scipy.sparse.dok_array.__getitem__',
                              'scipy.sparse.dok_array.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.__len__.html#scipy.sparse.dok_array.__len__',
                              'scipy.sparse.dok_array.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.__mul__.html#scipy.sparse.dok_array.__mul__',
                              'scipy.sparse.dok_array.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.asformat.html#scipy.sparse.dok_array.asformat',
                              'scipy.sparse.dok_array.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.asfptype.html#scipy.sparse.dok_array.asfptype',
                              'scipy.sparse.dok_array.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.astype.html#scipy.sparse.dok_array.astype',
                              'scipy.sparse.dok_array.clear': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.clear.html#scipy.sparse.dok_array.clear',
                              'scipy.sparse.dok_array.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.conj.html#scipy.sparse.dok_array.conj',
                              'scipy.sparse.dok_array.conjtransp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.conjtransp.html#scipy.sparse.dok_array.conjtransp',
                              'scipy.sparse.dok_array.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.conjugate.html#scipy.sparse.dok_array.conjugate',
                              'scipy.sparse.dok_array.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.copy.html#scipy.sparse.dok_array.copy',
                              'scipy.sparse.dok_array.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.count_nonzero.html#scipy.sparse.dok_array.count_nonzero',
                              'scipy.sparse.dok_array.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.diagonal.html#scipy.sparse.dok_array.diagonal',
                              'scipy.sparse.dok_array.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.dot.html#scipy.sparse.dok_array.dot',
                              'scipy.sparse.dok_array.fromkeys': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.fromkeys.html#scipy.sparse.dok_array.fromkeys',
                              'scipy.sparse.dok_array.get': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.get.html#scipy.sparse.dok_array.get',
                              'scipy.sparse.dok_array.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.getH.html#scipy.sparse.dok_array.getH',
                              'scipy.sparse.dok_array.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.get_shape.html#scipy.sparse.dok_array.get_shape',
                              'scipy.sparse.dok_array.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.getcol.html#scipy.sparse.dok_array.getcol',
                              'scipy.sparse.dok_array.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.getformat.html#scipy.sparse.dok_array.getformat',
                              'scipy.sparse.dok_array.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.getmaxprint.html#scipy.sparse.dok_array.getmaxprint',
                              'scipy.sparse.dok_array.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.getnnz.html#scipy.sparse.dok_array.getnnz',
                              'scipy.sparse.dok_array.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.getrow.html#scipy.sparse.dok_array.getrow',
                              'scipy.sparse.dok_array.items': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.items.html#scipy.sparse.dok_array.items',
                              'scipy.sparse.dok_array.keys': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.keys.html#scipy.sparse.dok_array.keys',
                              'scipy.sparse.dok_array.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.maximum.html#scipy.sparse.dok_array.maximum',
                              'scipy.sparse.dok_array.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.mean.html#scipy.sparse.dok_array.mean',
                              'scipy.sparse.dok_array.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.minimum.html#scipy.sparse.dok_array.minimum',
                              'scipy.sparse.dok_array.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.multiply.html#scipy.sparse.dok_array.multiply',
                              'scipy.sparse.dok_array.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.nonzero.html#scipy.sparse.dok_array.nonzero',
                              'scipy.sparse.dok_array.pop': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.pop.html#scipy.sparse.dok_array.pop',
                              'scipy.sparse.dok_array.popitem': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.popitem.html#scipy.sparse.dok_array.popitem',
                              'scipy.sparse.dok_array.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.power.html#scipy.sparse.dok_array.power',
                              'scipy.sparse.dok_array.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.reshape.html#scipy.sparse.dok_array.reshape',
                              'scipy.sparse.dok_array.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.resize.html#scipy.sparse.dok_array.resize',
                              'scipy.sparse.dok_array.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.set_shape.html#scipy.sparse.dok_array.set_shape',
                              'scipy.sparse.dok_array.setdefault': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.setdefault.html#scipy.sparse.dok_array.setdefault',
                              'scipy.sparse.dok_array.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.setdiag.html#scipy.sparse.dok_array.setdiag',
                              'scipy.sparse.dok_array.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.sum.html#scipy.sparse.dok_array.sum',
                              'scipy.sparse.dok_array.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.toarray.html#scipy.sparse.dok_array.toarray',
                              'scipy.sparse.dok_array.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.tobsr.html#scipy.sparse.dok_array.tobsr',
                              'scipy.sparse.dok_array.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.tocoo.html#scipy.sparse.dok_array.tocoo',
                              'scipy.sparse.dok_array.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.tocsc.html#scipy.sparse.dok_array.tocsc',
                              'scipy.sparse.dok_array.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.tocsr.html#scipy.sparse.dok_array.tocsr',
                              'scipy.sparse.dok_array.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.todense.html#scipy.sparse.dok_array.todense',
                              'scipy.sparse.dok_array.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.todia.html#scipy.sparse.dok_array.todia',
                              'scipy.sparse.dok_array.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.todok.html#scipy.sparse.dok_array.todok',
                              'scipy.sparse.dok_array.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.tolil.html#scipy.sparse.dok_array.tolil',
                              'scipy.sparse.dok_array.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.trace.html#scipy.sparse.dok_array.trace',
                              'scipy.sparse.dok_array.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.transpose.html#scipy.sparse.dok_array.transpose',
                              'scipy.sparse.dok_array.update': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.update.html#scipy.sparse.dok_array.update',
                              'scipy.sparse.dok_array.values': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.values.html#scipy.sparse.dok_array.values',
                              'scipy.sparse.dok_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.html#scipy.sparse.dok_matrix',
                              'scipy.sparse.dok_matrix.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.__getitem__.html#scipy.sparse.dok_matrix.__getitem__',
                              'scipy.sparse.dok_matrix.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.__len__.html#scipy.sparse.dok_matrix.__len__',
                              'scipy.sparse.dok_matrix.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.__mul__.html#scipy.sparse.dok_matrix.__mul__',
                              'scipy.sparse.dok_matrix.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.asformat.html#scipy.sparse.dok_matrix.asformat',
                              'scipy.sparse.dok_matrix.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.asfptype.html#scipy.sparse.dok_matrix.asfptype',
                              'scipy.sparse.dok_matrix.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.astype.html#scipy.sparse.dok_matrix.astype',
                              'scipy.sparse.dok_matrix.clear': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.clear.html#scipy.sparse.dok_matrix.clear',
                              'scipy.sparse.dok_matrix.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.conj.html#scipy.sparse.dok_matrix.conj',
                              'scipy.sparse.dok_matrix.conjtransp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.conjtransp.html#scipy.sparse.dok_matrix.conjtransp',
                              'scipy.sparse.dok_matrix.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.conjugate.html#scipy.sparse.dok_matrix.conjugate',
                              'scipy.sparse.dok_matrix.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.copy.html#scipy.sparse.dok_matrix.copy',
                              'scipy.sparse.dok_matrix.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.count_nonzero.html#scipy.sparse.dok_matrix.count_nonzero',
                              'scipy.sparse.dok_matrix.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.diagonal.html#scipy.sparse.dok_matrix.diagonal',
                              'scipy.sparse.dok_matrix.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.dot.html#scipy.sparse.dok_matrix.dot',
                              'scipy.sparse.dok_matrix.fromkeys': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.fromkeys.html#scipy.sparse.dok_matrix.fromkeys',
                              'scipy.sparse.dok_matrix.get': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.get.html#scipy.sparse.dok_matrix.get',
                              'scipy.sparse.dok_matrix.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.getH.html#scipy.sparse.dok_matrix.getH',
                              'scipy.sparse.dok_matrix.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.get_shape.html#scipy.sparse.dok_matrix.get_shape',
                              'scipy.sparse.dok_matrix.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.getcol.html#scipy.sparse.dok_matrix.getcol',
                              'scipy.sparse.dok_matrix.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.getformat.html#scipy.sparse.dok_matrix.getformat',
                              'scipy.sparse.dok_matrix.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.getmaxprint.html#scipy.sparse.dok_matrix.getmaxprint',
                              'scipy.sparse.dok_matrix.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.getnnz.html#scipy.sparse.dok_matrix.getnnz',
                              'scipy.sparse.dok_matrix.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.getrow.html#scipy.sparse.dok_matrix.getrow',
                              'scipy.sparse.dok_matrix.items': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.items.html#scipy.sparse.dok_matrix.items',
                              'scipy.sparse.dok_matrix.keys': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.keys.html#scipy.sparse.dok_matrix.keys',
                              'scipy.sparse.dok_matrix.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.maximum.html#scipy.sparse.dok_matrix.maximum',
                              'scipy.sparse.dok_matrix.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.mean.html#scipy.sparse.dok_matrix.mean',
                              'scipy.sparse.dok_matrix.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.minimum.html#scipy.sparse.dok_matrix.minimum',
                              'scipy.sparse.dok_matrix.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.multiply.html#scipy.sparse.dok_matrix.multiply',
                              'scipy.sparse.dok_matrix.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.nonzero.html#scipy.sparse.dok_matrix.nonzero',
                              'scipy.sparse.dok_matrix.pop': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.pop.html#scipy.sparse.dok_matrix.pop',
                              'scipy.sparse.dok_matrix.popitem': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.popitem.html#scipy.sparse.dok_matrix.popitem',
                              'scipy.sparse.dok_matrix.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.power.html#scipy.sparse.dok_matrix.power',
                              'scipy.sparse.dok_matrix.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.reshape.html#scipy.sparse.dok_matrix.reshape',
                              'scipy.sparse.dok_matrix.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.resize.html#scipy.sparse.dok_matrix.resize',
                              'scipy.sparse.dok_matrix.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.set_shape.html#scipy.sparse.dok_matrix.set_shape',
                              'scipy.sparse.dok_matrix.setdefault': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.setdefault.html#scipy.sparse.dok_matrix.setdefault',
                              'scipy.sparse.dok_matrix.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.setdiag.html#scipy.sparse.dok_matrix.setdiag',
                              'scipy.sparse.dok_matrix.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.sum.html#scipy.sparse.dok_matrix.sum',
                              'scipy.sparse.dok_matrix.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.toarray.html#scipy.sparse.dok_matrix.toarray',
                              'scipy.sparse.dok_matrix.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.tobsr.html#scipy.sparse.dok_matrix.tobsr',
                              'scipy.sparse.dok_matrix.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.tocoo.html#scipy.sparse.dok_matrix.tocoo',
                              'scipy.sparse.dok_matrix.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.tocsc.html#scipy.sparse.dok_matrix.tocsc',
                              'scipy.sparse.dok_matrix.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.tocsr.html#scipy.sparse.dok_matrix.tocsr',
                              'scipy.sparse.dok_matrix.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.todense.html#scipy.sparse.dok_matrix.todense',
                              'scipy.sparse.dok_matrix.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.todia.html#scipy.sparse.dok_matrix.todia',
                              'scipy.sparse.dok_matrix.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.todok.html#scipy.sparse.dok_matrix.todok',
                              'scipy.sparse.dok_matrix.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.tolil.html#scipy.sparse.dok_matrix.tolil',
                              'scipy.sparse.dok_matrix.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.trace.html#scipy.sparse.dok_matrix.trace',
                              'scipy.sparse.dok_matrix.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.transpose.html#scipy.sparse.dok_matrix.transpose',
                              'scipy.sparse.dok_matrix.update': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.update.html#scipy.sparse.dok_matrix.update',
                              'scipy.sparse.dok_matrix.values': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.values.html#scipy.sparse.dok_matrix.values',
                              'scipy.sparse.eye': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.eye.html#scipy.sparse.eye',
                              'scipy.sparse.find': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.find.html#scipy.sparse.find',
                              'scipy.sparse.hstack': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.hstack.html#scipy.sparse.hstack',
                              'scipy.sparse.identity': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.identity.html#scipy.sparse.identity',
                              'scipy.sparse.issparse': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.issparse.html#scipy.sparse.issparse',
                              'scipy.sparse.isspmatrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.isspmatrix.html#scipy.sparse.isspmatrix',
                              'scipy.sparse.isspmatrix_bsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.isspmatrix_bsr.html#scipy.sparse.isspmatrix_bsr',
                              'scipy.sparse.isspmatrix_coo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.isspmatrix_coo.html#scipy.sparse.isspmatrix_coo',
                              'scipy.sparse.isspmatrix_csc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.isspmatrix_csc.html#scipy.sparse.isspmatrix_csc',
                              'scipy.sparse.isspmatrix_csr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.isspmatrix_csr.html#scipy.sparse.isspmatrix_csr',
                              'scipy.sparse.isspmatrix_dia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.isspmatrix_dia.html#scipy.sparse.isspmatrix_dia',
                              'scipy.sparse.isspmatrix_dok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.isspmatrix_dok.html#scipy.sparse.isspmatrix_dok',
                              'scipy.sparse.isspmatrix_lil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.isspmatrix_lil.html#scipy.sparse.isspmatrix_lil',
                              'scipy.sparse.kron': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.kron.html#scipy.sparse.kron',
                              'scipy.sparse.kronsum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.kronsum.html#scipy.sparse.kronsum',
                              'scipy.sparse.lil_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.html#scipy.sparse.lil_array',
                              'scipy.sparse.lil_array.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.__getitem__.html#scipy.sparse.lil_array.__getitem__',
                              'scipy.sparse.lil_array.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.__len__.html#scipy.sparse.lil_array.__len__',
                              'scipy.sparse.lil_array.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.__mul__.html#scipy.sparse.lil_array.__mul__',
                              'scipy.sparse.lil_array.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.asformat.html#scipy.sparse.lil_array.asformat',
                              'scipy.sparse.lil_array.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.asfptype.html#scipy.sparse.lil_array.asfptype',
                              'scipy.sparse.lil_array.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.astype.html#scipy.sparse.lil_array.astype',
                              'scipy.sparse.lil_array.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.conj.html#scipy.sparse.lil_array.conj',
                              'scipy.sparse.lil_array.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.conjugate.html#scipy.sparse.lil_array.conjugate',
                              'scipy.sparse.lil_array.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.copy.html#scipy.sparse.lil_array.copy',
                              'scipy.sparse.lil_array.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.count_nonzero.html#scipy.sparse.lil_array.count_nonzero',
                              'scipy.sparse.lil_array.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.diagonal.html#scipy.sparse.lil_array.diagonal',
                              'scipy.sparse.lil_array.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.dot.html#scipy.sparse.lil_array.dot',
                              'scipy.sparse.lil_array.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.getH.html#scipy.sparse.lil_array.getH',
                              'scipy.sparse.lil_array.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.get_shape.html#scipy.sparse.lil_array.get_shape',
                              'scipy.sparse.lil_array.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.getcol.html#scipy.sparse.lil_array.getcol',
                              'scipy.sparse.lil_array.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.getformat.html#scipy.sparse.lil_array.getformat',
                              'scipy.sparse.lil_array.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.getmaxprint.html#scipy.sparse.lil_array.getmaxprint',
                              'scipy.sparse.lil_array.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.getnnz.html#scipy.sparse.lil_array.getnnz',
                              'scipy.sparse.lil_array.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.getrow.html#scipy.sparse.lil_array.getrow',
                              'scipy.sparse.lil_array.getrowview': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.getrowview.html#scipy.sparse.lil_array.getrowview',
                              'scipy.sparse.lil_array.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.maximum.html#scipy.sparse.lil_array.maximum',
                              'scipy.sparse.lil_array.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.mean.html#scipy.sparse.lil_array.mean',
                              'scipy.sparse.lil_array.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.minimum.html#scipy.sparse.lil_array.minimum',
                              'scipy.sparse.lil_array.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.multiply.html#scipy.sparse.lil_array.multiply',
                              'scipy.sparse.lil_array.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.nonzero.html#scipy.sparse.lil_array.nonzero',
                              'scipy.sparse.lil_array.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.power.html#scipy.sparse.lil_array.power',
                              'scipy.sparse.lil_array.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.reshape.html#scipy.sparse.lil_array.reshape',
                              'scipy.sparse.lil_array.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.resize.html#scipy.sparse.lil_array.resize',
                              'scipy.sparse.lil_array.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.set_shape.html#scipy.sparse.lil_array.set_shape',
                              'scipy.sparse.lil_array.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.setdiag.html#scipy.sparse.lil_array.setdiag',
                              'scipy.sparse.lil_array.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.sum.html#scipy.sparse.lil_array.sum',
                              'scipy.sparse.lil_array.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.toarray.html#scipy.sparse.lil_array.toarray',
                              'scipy.sparse.lil_array.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.tobsr.html#scipy.sparse.lil_array.tobsr',
                              'scipy.sparse.lil_array.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.tocoo.html#scipy.sparse.lil_array.tocoo',
                              'scipy.sparse.lil_array.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.tocsc.html#scipy.sparse.lil_array.tocsc',
                              'scipy.sparse.lil_array.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.tocsr.html#scipy.sparse.lil_array.tocsr',
                              'scipy.sparse.lil_array.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.todense.html#scipy.sparse.lil_array.todense',
                              'scipy.sparse.lil_array.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.todia.html#scipy.sparse.lil_array.todia',
                              'scipy.sparse.lil_array.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.todok.html#scipy.sparse.lil_array.todok',
                              'scipy.sparse.lil_array.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.tolil.html#scipy.sparse.lil_array.tolil',
                              'scipy.sparse.lil_array.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.trace.html#scipy.sparse.lil_array.trace',
                              'scipy.sparse.lil_array.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.transpose.html#scipy.sparse.lil_array.transpose',
                              'scipy.sparse.lil_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.html#scipy.sparse.lil_matrix',
                              'scipy.sparse.lil_matrix.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.__getitem__.html#scipy.sparse.lil_matrix.__getitem__',
                              'scipy.sparse.lil_matrix.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.__len__.html#scipy.sparse.lil_matrix.__len__',
                              'scipy.sparse.lil_matrix.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.__mul__.html#scipy.sparse.lil_matrix.__mul__',
                              'scipy.sparse.lil_matrix.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.asformat.html#scipy.sparse.lil_matrix.asformat',
                              'scipy.sparse.lil_matrix.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.asfptype.html#scipy.sparse.lil_matrix.asfptype',
                              'scipy.sparse.lil_matrix.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.astype.html#scipy.sparse.lil_matrix.astype',
                              'scipy.sparse.lil_matrix.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.conj.html#scipy.sparse.lil_matrix.conj',
                              'scipy.sparse.lil_matrix.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.conjugate.html#scipy.sparse.lil_matrix.conjugate',
                              'scipy.sparse.lil_matrix.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.copy.html#scipy.sparse.lil_matrix.copy',
                              'scipy.sparse.lil_matrix.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.count_nonzero.html#scipy.sparse.lil_matrix.count_nonzero',
                              'scipy.sparse.lil_matrix.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.diagonal.html#scipy.sparse.lil_matrix.diagonal',
                              'scipy.sparse.lil_matrix.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.dot.html#scipy.sparse.lil_matrix.dot',
                              'scipy.sparse.lil_matrix.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.getH.html#scipy.sparse.lil_matrix.getH',
                              'scipy.sparse.lil_matrix.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.get_shape.html#scipy.sparse.lil_matrix.get_shape',
                              'scipy.sparse.lil_matrix.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.getcol.html#scipy.sparse.lil_matrix.getcol',
                              'scipy.sparse.lil_matrix.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.getformat.html#scipy.sparse.lil_matrix.getformat',
                              'scipy.sparse.lil_matrix.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.getmaxprint.html#scipy.sparse.lil_matrix.getmaxprint',
                              'scipy.sparse.lil_matrix.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.getnnz.html#scipy.sparse.lil_matrix.getnnz',
                              'scipy.sparse.lil_matrix.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.getrow.html#scipy.sparse.lil_matrix.getrow',
                              'scipy.sparse.lil_matrix.getrowview': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.getrowview.html#scipy.sparse.lil_matrix.getrowview',
                              'scipy.sparse.lil_matrix.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.maximum.html#scipy.sparse.lil_matrix.maximum',
                              'scipy.sparse.lil_matrix.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.mean.html#scipy.sparse.lil_matrix.mean',
                              'scipy.sparse.lil_matrix.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.minimum.html#scipy.sparse.lil_matrix.minimum',
                              'scipy.sparse.lil_matrix.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.multiply.html#scipy.sparse.lil_matrix.multiply',
                              'scipy.sparse.lil_matrix.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.nonzero.html#scipy.sparse.lil_matrix.nonzero',
                              'scipy.sparse.lil_matrix.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.power.html#scipy.sparse.lil_matrix.power',
                              'scipy.sparse.lil_matrix.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.reshape.html#scipy.sparse.lil_matrix.reshape',
                              'scipy.sparse.lil_matrix.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.resize.html#scipy.sparse.lil_matrix.resize',
                              'scipy.sparse.lil_matrix.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.set_shape.html#scipy.sparse.lil_matrix.set_shape',
                              'scipy.sparse.lil_matrix.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.setdiag.html#scipy.sparse.lil_matrix.setdiag',
                              'scipy.sparse.lil_matrix.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.sum.html#scipy.sparse.lil_matrix.sum',
                              'scipy.sparse.lil_matrix.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.toarray.html#scipy.sparse.lil_matrix.toarray',
                              'scipy.sparse.lil_matrix.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.tobsr.html#scipy.sparse.lil_matrix.tobsr',
                              'scipy.sparse.lil_matrix.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.tocoo.html#scipy.sparse.lil_matrix.tocoo',
                              'scipy.sparse.lil_matrix.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.tocsc.html#scipy.sparse.lil_matrix.tocsc',
                              'scipy.sparse.lil_matrix.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.tocsr.html#scipy.sparse.lil_matrix.tocsr',
                              'scipy.sparse.lil_matrix.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.todense.html#scipy.sparse.lil_matrix.todense',
                              'scipy.sparse.lil_matrix.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.todia.html#scipy.sparse.lil_matrix.todia',
                              'scipy.sparse.lil_matrix.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.todok.html#scipy.sparse.lil_matrix.todok',
                              'scipy.sparse.lil_matrix.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.tolil.html#scipy.sparse.lil_matrix.tolil',
                              'scipy.sparse.lil_matrix.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.trace.html#scipy.sparse.lil_matrix.trace',
                              'scipy.sparse.lil_matrix.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.transpose.html#scipy.sparse.lil_matrix.transpose',
                              'scipy.sparse.linalg': 'https://docs.scipy.org/doc/scipy/reference/reference/sparse.linalg.html#module-scipy.sparse.linalg',
                              'scipy.sparse.load_npz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.load_npz.html#scipy.sparse.load_npz',
                              'scipy.sparse.rand': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.rand.html#scipy.sparse.rand',
                              'scipy.sparse.random': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.random.html#scipy.sparse.random',
                              'scipy.sparse.save_npz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.save_npz.html#scipy.sparse.save_npz',
                              'scipy.sparse.spdiags': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spdiags.html#scipy.sparse.spdiags',
                              'scipy.sparse.spmatrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.html#scipy.sparse.spmatrix',
                              'scipy.sparse.spmatrix.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.__len__.html#scipy.sparse.spmatrix.__len__',
                              'scipy.sparse.spmatrix.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.__mul__.html#scipy.sparse.spmatrix.__mul__',
                              'scipy.sparse.spmatrix.asformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.asformat.html#scipy.sparse.spmatrix.asformat',
                              'scipy.sparse.spmatrix.asfptype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.asfptype.html#scipy.sparse.spmatrix.asfptype',
                              'scipy.sparse.spmatrix.astype': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.astype.html#scipy.sparse.spmatrix.astype',
                              'scipy.sparse.spmatrix.conj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.conj.html#scipy.sparse.spmatrix.conj',
                              'scipy.sparse.spmatrix.conjugate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.conjugate.html#scipy.sparse.spmatrix.conjugate',
                              'scipy.sparse.spmatrix.copy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.copy.html#scipy.sparse.spmatrix.copy',
                              'scipy.sparse.spmatrix.count_nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.count_nonzero.html#scipy.sparse.spmatrix.count_nonzero',
                              'scipy.sparse.spmatrix.diagonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.diagonal.html#scipy.sparse.spmatrix.diagonal',
                              'scipy.sparse.spmatrix.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.dot.html#scipy.sparse.spmatrix.dot',
                              'scipy.sparse.spmatrix.getH': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.getH.html#scipy.sparse.spmatrix.getH',
                              'scipy.sparse.spmatrix.get_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.get_shape.html#scipy.sparse.spmatrix.get_shape',
                              'scipy.sparse.spmatrix.getcol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.getcol.html#scipy.sparse.spmatrix.getcol',
                              'scipy.sparse.spmatrix.getformat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.getformat.html#scipy.sparse.spmatrix.getformat',
                              'scipy.sparse.spmatrix.getmaxprint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.getmaxprint.html#scipy.sparse.spmatrix.getmaxprint',
                              'scipy.sparse.spmatrix.getnnz': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.getnnz.html#scipy.sparse.spmatrix.getnnz',
                              'scipy.sparse.spmatrix.getrow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.getrow.html#scipy.sparse.spmatrix.getrow',
                              'scipy.sparse.spmatrix.maximum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.maximum.html#scipy.sparse.spmatrix.maximum',
                              'scipy.sparse.spmatrix.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.mean.html#scipy.sparse.spmatrix.mean',
                              'scipy.sparse.spmatrix.minimum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.minimum.html#scipy.sparse.spmatrix.minimum',
                              'scipy.sparse.spmatrix.multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.multiply.html#scipy.sparse.spmatrix.multiply',
                              'scipy.sparse.spmatrix.nonzero': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.nonzero.html#scipy.sparse.spmatrix.nonzero',
                              'scipy.sparse.spmatrix.power': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.power.html#scipy.sparse.spmatrix.power',
                              'scipy.sparse.spmatrix.reshape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.reshape.html#scipy.sparse.spmatrix.reshape',
                              'scipy.sparse.spmatrix.resize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.resize.html#scipy.sparse.spmatrix.resize',
                              'scipy.sparse.spmatrix.set_shape': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.set_shape.html#scipy.sparse.spmatrix.set_shape',
                              'scipy.sparse.spmatrix.setdiag': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.setdiag.html#scipy.sparse.spmatrix.setdiag',
                              'scipy.sparse.spmatrix.sum': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.sum.html#scipy.sparse.spmatrix.sum',
                              'scipy.sparse.spmatrix.toarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.toarray.html#scipy.sparse.spmatrix.toarray',
                              'scipy.sparse.spmatrix.tobsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.tobsr.html#scipy.sparse.spmatrix.tobsr',
                              'scipy.sparse.spmatrix.tocoo': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.tocoo.html#scipy.sparse.spmatrix.tocoo',
                              'scipy.sparse.spmatrix.tocsc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.tocsc.html#scipy.sparse.spmatrix.tocsc',
                              'scipy.sparse.spmatrix.tocsr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.tocsr.html#scipy.sparse.spmatrix.tocsr',
                              'scipy.sparse.spmatrix.todense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.todense.html#scipy.sparse.spmatrix.todense',
                              'scipy.sparse.spmatrix.todia': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.todia.html#scipy.sparse.spmatrix.todia',
                              'scipy.sparse.spmatrix.todok': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.todok.html#scipy.sparse.spmatrix.todok',
                              'scipy.sparse.spmatrix.tolil': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.tolil.html#scipy.sparse.spmatrix.tolil',
                              'scipy.sparse.spmatrix.trace': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.trace.html#scipy.sparse.spmatrix.trace',
                              'scipy.sparse.spmatrix.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.transpose.html#scipy.sparse.spmatrix.transpose',
                              'scipy.sparse.tril': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.tril.html#scipy.sparse.tril',
                              'scipy.sparse.triu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.triu.html#scipy.sparse.triu',
                              'scipy.sparse.vstack': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.vstack.html#scipy.sparse.vstack'},
            'scipy.sparse._arrays': { 'scipy.sparse._arrays.bsr_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_array.html#scipy.sparse.bsr_array',
                                      'scipy.sparse._arrays.coo_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_array.html#scipy.sparse.coo_array',
                                      'scipy.sparse._arrays.csc_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_array.html#scipy.sparse.csc_array',
                                      'scipy.sparse._arrays.csr_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_array.html#scipy.sparse.csr_array',
                                      'scipy.sparse._arrays.dia_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_array.html#scipy.sparse.dia_array',
                                      'scipy.sparse._arrays.dok_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_array.html#scipy.sparse.dok_array',
                                      'scipy.sparse._arrays.lil_array': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_array.html#scipy.sparse.lil_array'},
            'scipy.sparse._base': { 'scipy.sparse._base.spmatrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.spmatrix.html#scipy.sparse.spmatrix'},
            'scipy.sparse._bsr': { 'scipy.sparse._bsr.bsr_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.bsr_matrix.html#scipy.sparse.bsr_matrix'},
            'scipy.sparse._coo': { 'scipy.sparse._coo.coo_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.coo_matrix.html#scipy.sparse.coo_matrix'},
            'scipy.sparse._csc': { 'scipy.sparse._csc.csc_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csc_matrix.html#scipy.sparse.csc_matrix'},
            'scipy.sparse._csr': { 'scipy.sparse._csr.csr_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csr_matrix.html#scipy.sparse.csr_matrix'},
            'scipy.sparse._dia': { 'scipy.sparse._dia.dia_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dia_matrix.html#scipy.sparse.dia_matrix'},
            'scipy.sparse._dok': { 'scipy.sparse._dok.dok_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.dok_matrix.html#scipy.sparse.dok_matrix'},
            'scipy.sparse._lil': { 'scipy.sparse._lil.lil_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.lil_matrix.html#scipy.sparse.lil_matrix'},
            'scipy.sparse.csgraph': { 'scipy.sparse.csgraph.NegativeCycleError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.NegativeCycleError.html#scipy.sparse.csgraph.NegativeCycleError.with_traceback',
                                      'scipy.sparse.csgraph.bellman_ford': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.bellman_ford.html#scipy.sparse.csgraph.bellman_ford',
                                      'scipy.sparse.csgraph.breadth_first_order': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.breadth_first_order.html#scipy.sparse.csgraph.breadth_first_order',
                                      'scipy.sparse.csgraph.breadth_first_tree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.breadth_first_tree.html#scipy.sparse.csgraph.breadth_first_tree',
                                      'scipy.sparse.csgraph.connected_components': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.connected_components.html#scipy.sparse.csgraph.connected_components',
                                      'scipy.sparse.csgraph.construct_dist_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.construct_dist_matrix.html#scipy.sparse.csgraph.construct_dist_matrix',
                                      'scipy.sparse.csgraph.csgraph_from_dense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.csgraph_from_dense.html#scipy.sparse.csgraph.csgraph_from_dense',
                                      'scipy.sparse.csgraph.csgraph_from_masked': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.csgraph_from_masked.html#scipy.sparse.csgraph.csgraph_from_masked',
                                      'scipy.sparse.csgraph.csgraph_masked_from_dense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.csgraph_masked_from_dense.html#scipy.sparse.csgraph.csgraph_masked_from_dense',
                                      'scipy.sparse.csgraph.csgraph_to_dense': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.csgraph_to_dense.html#scipy.sparse.csgraph.csgraph_to_dense',
                                      'scipy.sparse.csgraph.csgraph_to_masked': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.csgraph_to_masked.html#scipy.sparse.csgraph.csgraph_to_masked',
                                      'scipy.sparse.csgraph.depth_first_order': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.depth_first_order.html#scipy.sparse.csgraph.depth_first_order',
                                      'scipy.sparse.csgraph.depth_first_tree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.depth_first_tree.html#scipy.sparse.csgraph.depth_first_tree',
                                      'scipy.sparse.csgraph.dijkstra': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.dijkstra.html#scipy.sparse.csgraph.dijkstra',
                                      'scipy.sparse.csgraph.floyd_warshall': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.floyd_warshall.html#scipy.sparse.csgraph.floyd_warshall',
                                      'scipy.sparse.csgraph.johnson': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.johnson.html#scipy.sparse.csgraph.johnson',
                                      'scipy.sparse.csgraph.laplacian': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.laplacian.html#scipy.sparse.csgraph.laplacian',
                                      'scipy.sparse.csgraph.maximum_bipartite_matching': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.maximum_bipartite_matching.html#scipy.sparse.csgraph.maximum_bipartite_matching',
                                      'scipy.sparse.csgraph.maximum_flow': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.maximum_flow.html#scipy.sparse.csgraph.maximum_flow',
                                      'scipy.sparse.csgraph.min_weight_full_bipartite_matching': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.min_weight_full_bipartite_matching.html#scipy.sparse.csgraph.min_weight_full_bipartite_matching',
                                      'scipy.sparse.csgraph.minimum_spanning_tree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.minimum_spanning_tree.html#scipy.sparse.csgraph.minimum_spanning_tree',
                                      'scipy.sparse.csgraph.reconstruct_path': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.reconstruct_path.html#scipy.sparse.csgraph.reconstruct_path',
                                      'scipy.sparse.csgraph.reverse_cuthill_mckee': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.reverse_cuthill_mckee.html#scipy.sparse.csgraph.reverse_cuthill_mckee',
                                      'scipy.sparse.csgraph.shortest_path': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.shortest_path.html#scipy.sparse.csgraph.shortest_path',
                                      'scipy.sparse.csgraph.structural_rank': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.csgraph.structural_rank.html#scipy.sparse.csgraph.structural_rank'},
            'scipy.sparse.linalg': { 'scipy.sparse.linalg.ArpackError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.ArpackError.html#scipy.sparse.linalg.ArpackError.with_traceback',
                                     'scipy.sparse.linalg.ArpackNoConvergence.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.ArpackNoConvergence.html#scipy.sparse.linalg.ArpackNoConvergence.with_traceback',
                                     'scipy.sparse.linalg.LinearOperator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.html#scipy.sparse.linalg.LinearOperator',
                                     'scipy.sparse.linalg.LinearOperator.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.__call__.html#scipy.sparse.linalg.LinearOperator.__call__',
                                     'scipy.sparse.linalg.LinearOperator.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.__mul__.html#scipy.sparse.linalg.LinearOperator.__mul__',
                                     'scipy.sparse.linalg.LinearOperator.adjoint': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.adjoint.html#scipy.sparse.linalg.LinearOperator.adjoint',
                                     'scipy.sparse.linalg.LinearOperator.dot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.dot.html#scipy.sparse.linalg.LinearOperator.dot',
                                     'scipy.sparse.linalg.LinearOperator.matmat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.matmat.html#scipy.sparse.linalg.LinearOperator.matmat',
                                     'scipy.sparse.linalg.LinearOperator.matvec': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.matvec.html#scipy.sparse.linalg.LinearOperator.matvec',
                                     'scipy.sparse.linalg.LinearOperator.rmatmat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.rmatmat.html#scipy.sparse.linalg.LinearOperator.rmatmat',
                                     'scipy.sparse.linalg.LinearOperator.rmatvec': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.rmatvec.html#scipy.sparse.linalg.LinearOperator.rmatvec',
                                     'scipy.sparse.linalg.LinearOperator.transpose': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.transpose.html#scipy.sparse.linalg.LinearOperator.transpose',
                                     'scipy.sparse.linalg.MatrixRankWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.MatrixRankWarning.html#scipy.sparse.linalg.MatrixRankWarning.with_traceback',
                                     'scipy.sparse.linalg.SuperLU': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.SuperLU.html#scipy.sparse.linalg.SuperLU',
                                     'scipy.sparse.linalg.SuperLU.solve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.SuperLU.solve.html#scipy.sparse.linalg.SuperLU.solve',
                                     'scipy.sparse.linalg.aslinearoperator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.aslinearoperator.html#scipy.sparse.linalg.aslinearoperator',
                                     'scipy.sparse.linalg.bicg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.bicg.html#scipy.sparse.linalg.bicg',
                                     'scipy.sparse.linalg.bicgstab': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.bicgstab.html#scipy.sparse.linalg.bicgstab',
                                     'scipy.sparse.linalg.cg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.cg.html#scipy.sparse.linalg.cg',
                                     'scipy.sparse.linalg.cgs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.cgs.html#scipy.sparse.linalg.cgs',
                                     'scipy.sparse.linalg.eigs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.eigs.html#scipy.sparse.linalg.eigs',
                                     'scipy.sparse.linalg.eigsh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.eigsh.html#scipy.sparse.linalg.eigsh',
                                     'scipy.sparse.linalg.expm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.expm.html#scipy.sparse.linalg.expm',
                                     'scipy.sparse.linalg.expm_multiply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.expm_multiply.html#scipy.sparse.linalg.expm_multiply',
                                     'scipy.sparse.linalg.factorized': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.factorized.html#scipy.sparse.linalg.factorized',
                                     'scipy.sparse.linalg.gcrotmk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.gcrotmk.html#scipy.sparse.linalg.gcrotmk',
                                     'scipy.sparse.linalg.gmres': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.gmres.html#scipy.sparse.linalg.gmres',
                                     'scipy.sparse.linalg.inv': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.inv.html#scipy.sparse.linalg.inv',
                                     'scipy.sparse.linalg.lgmres': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.lgmres.html#scipy.sparse.linalg.lgmres',
                                     'scipy.sparse.linalg.lobpcg': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.lobpcg.html#scipy.sparse.linalg.lobpcg',
                                     'scipy.sparse.linalg.lsmr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.lsmr.html#scipy.sparse.linalg.lsmr',
                                     'scipy.sparse.linalg.lsqr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.lsqr.html#scipy.sparse.linalg.lsqr',
                                     'scipy.sparse.linalg.minres': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.minres.html#scipy.sparse.linalg.minres',
                                     'scipy.sparse.linalg.norm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.norm.html#scipy.sparse.linalg.norm',
                                     'scipy.sparse.linalg.onenormest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.onenormest.html#scipy.sparse.linalg.onenormest',
                                     'scipy.sparse.linalg.qmr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.qmr.html#scipy.sparse.linalg.qmr',
                                     'scipy.sparse.linalg.spilu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.spilu.html#scipy.sparse.linalg.spilu',
                                     'scipy.sparse.linalg.splu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.splu.html#scipy.sparse.linalg.splu',
                                     'scipy.sparse.linalg.spsolve': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.spsolve.html#scipy.sparse.linalg.spsolve',
                                     'scipy.sparse.linalg.spsolve_triangular': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.spsolve_triangular.html#scipy.sparse.linalg.spsolve_triangular',
                                     'scipy.sparse.linalg.svds': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.svds.html#scipy.sparse.linalg.svds',
                                     'scipy.sparse.linalg.tfqmr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.tfqmr.html#scipy.sparse.linalg.tfqmr',
                                     'scipy.sparse.linalg.use_solver': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.use_solver.html#scipy.sparse.linalg.use_solver'},
            'scipy.sparse.linalg._interface': { 'scipy.sparse.linalg._interface.LinearOperator': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.sparse.linalg.LinearOperator.html#scipy.sparse.linalg.LinearOperator'},
            'scipy.spatial': { 'scipy.spatial.ConvexHull': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.ConvexHull.html#scipy.spatial.ConvexHull',
                               'scipy.spatial.ConvexHull.add_points': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.ConvexHull.add_points.html#scipy.spatial.ConvexHull.add_points',
                               'scipy.spatial.ConvexHull.close': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.ConvexHull.close.html#scipy.spatial.ConvexHull.close',
                               'scipy.spatial.Delaunay': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Delaunay.html#scipy.spatial.Delaunay',
                               'scipy.spatial.Delaunay.add_points': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Delaunay.add_points.html#scipy.spatial.Delaunay.add_points',
                               'scipy.spatial.Delaunay.close': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Delaunay.close.html#scipy.spatial.Delaunay.close',
                               'scipy.spatial.Delaunay.find_simplex': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Delaunay.find_simplex.html#scipy.spatial.Delaunay.find_simplex',
                               'scipy.spatial.Delaunay.lift_points': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Delaunay.lift_points.html#scipy.spatial.Delaunay.lift_points',
                               'scipy.spatial.Delaunay.plane_distance': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Delaunay.plane_distance.html#scipy.spatial.Delaunay.plane_distance',
                               'scipy.spatial.HalfspaceIntersection': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.HalfspaceIntersection.html#scipy.spatial.HalfspaceIntersection',
                               'scipy.spatial.HalfspaceIntersection.add_halfspaces': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.HalfspaceIntersection.add_halfspaces.html#scipy.spatial.HalfspaceIntersection.add_halfspaces',
                               'scipy.spatial.HalfspaceIntersection.close': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.HalfspaceIntersection.close.html#scipy.spatial.HalfspaceIntersection.close',
                               'scipy.spatial.KDTree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.KDTree.html#scipy.spatial.KDTree',
                               'scipy.spatial.KDTree.count_neighbors': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.KDTree.count_neighbors.html#scipy.spatial.KDTree.count_neighbors',
                               'scipy.spatial.KDTree.query': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.KDTree.query.html#scipy.spatial.KDTree.query',
                               'scipy.spatial.KDTree.query_ball_point': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.KDTree.query_ball_point.html#scipy.spatial.KDTree.query_ball_point',
                               'scipy.spatial.KDTree.query_ball_tree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.KDTree.query_ball_tree.html#scipy.spatial.KDTree.query_ball_tree',
                               'scipy.spatial.KDTree.query_pairs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.KDTree.query_pairs.html#scipy.spatial.KDTree.query_pairs',
                               'scipy.spatial.KDTree.sparse_distance_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.KDTree.sparse_distance_matrix.html#scipy.spatial.KDTree.sparse_distance_matrix',
                               'scipy.spatial.QhullError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.QhullError.html#scipy.spatial.QhullError.with_traceback',
                               'scipy.spatial.Rectangle': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Rectangle.html#scipy.spatial.Rectangle',
                               'scipy.spatial.Rectangle.max_distance_point': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Rectangle.max_distance_point.html#scipy.spatial.Rectangle.max_distance_point',
                               'scipy.spatial.Rectangle.max_distance_rectangle': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Rectangle.max_distance_rectangle.html#scipy.spatial.Rectangle.max_distance_rectangle',
                               'scipy.spatial.Rectangle.min_distance_point': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Rectangle.min_distance_point.html#scipy.spatial.Rectangle.min_distance_point',
                               'scipy.spatial.Rectangle.min_distance_rectangle': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Rectangle.min_distance_rectangle.html#scipy.spatial.Rectangle.min_distance_rectangle',
                               'scipy.spatial.Rectangle.split': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Rectangle.split.html#scipy.spatial.Rectangle.split',
                               'scipy.spatial.Rectangle.volume': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Rectangle.volume.html#scipy.spatial.Rectangle.volume',
                               'scipy.spatial.SphericalVoronoi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.SphericalVoronoi.html#scipy.spatial.SphericalVoronoi',
                               'scipy.spatial.SphericalVoronoi.calculate_areas': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.SphericalVoronoi.calculate_areas.html#scipy.spatial.SphericalVoronoi.calculate_areas',
                               'scipy.spatial.SphericalVoronoi.sort_vertices_of_regions': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.SphericalVoronoi.sort_vertices_of_regions.html#scipy.spatial.SphericalVoronoi.sort_vertices_of_regions',
                               'scipy.spatial.Voronoi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Voronoi.html#scipy.spatial.Voronoi',
                               'scipy.spatial.Voronoi.add_points': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Voronoi.add_points.html#scipy.spatial.Voronoi.add_points',
                               'scipy.spatial.Voronoi.close': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Voronoi.close.html#scipy.spatial.Voronoi.close',
                               'scipy.spatial.cKDTree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.cKDTree.html#scipy.spatial.cKDTree',
                               'scipy.spatial.cKDTree.count_neighbors': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.cKDTree.count_neighbors.html#scipy.spatial.cKDTree.count_neighbors',
                               'scipy.spatial.cKDTree.query': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.cKDTree.query.html#scipy.spatial.cKDTree.query',
                               'scipy.spatial.cKDTree.query_ball_point': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.cKDTree.query_ball_point.html#scipy.spatial.cKDTree.query_ball_point',
                               'scipy.spatial.cKDTree.query_ball_tree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.cKDTree.query_ball_tree.html#scipy.spatial.cKDTree.query_ball_tree',
                               'scipy.spatial.cKDTree.query_pairs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.cKDTree.query_pairs.html#scipy.spatial.cKDTree.query_pairs',
                               'scipy.spatial.cKDTree.sparse_distance_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.cKDTree.sparse_distance_matrix.html#scipy.spatial.cKDTree.sparse_distance_matrix',
                               'scipy.spatial.convex_hull_plot_2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.convex_hull_plot_2d.html#scipy.spatial.convex_hull_plot_2d',
                               'scipy.spatial.delaunay_plot_2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.delaunay_plot_2d.html#scipy.spatial.delaunay_plot_2d',
                               'scipy.spatial.distance': 'https://docs.scipy.org/doc/scipy/reference/reference/spatial.distance.html#module-scipy.spatial.distance',
                               'scipy.spatial.distance_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance_matrix.html#scipy.spatial.distance_matrix',
                               'scipy.spatial.geometric_slerp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.geometric_slerp.html#scipy.spatial.geometric_slerp',
                               'scipy.spatial.minkowski_distance': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.minkowski_distance.html#scipy.spatial.minkowski_distance',
                               'scipy.spatial.minkowski_distance_p': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.minkowski_distance_p.html#scipy.spatial.minkowski_distance_p',
                               'scipy.spatial.procrustes': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.procrustes.html#scipy.spatial.procrustes',
                               'scipy.spatial.transform': 'https://docs.scipy.org/doc/scipy/reference/reference/spatial.transform.html#module-scipy.spatial.transform',
                               'scipy.spatial.tsearch': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.tsearch.html#scipy.spatial.tsearch',
                               'scipy.spatial.voronoi_plot_2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.voronoi_plot_2d.html#scipy.spatial.voronoi_plot_2d'},
            'scipy.spatial._ckdtree': { 'scipy.spatial._ckdtree.cKDTree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.cKDTree.html#scipy.spatial.cKDTree'},
            'scipy.spatial._kdtree': { 'scipy.spatial._kdtree.KDTree': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.KDTree.html#scipy.spatial.KDTree',
                                       'scipy.spatial._kdtree.Rectangle': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Rectangle.html#scipy.spatial.Rectangle'},
            'scipy.spatial._qhull': { 'scipy.spatial._qhull.ConvexHull': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.ConvexHull.html#scipy.spatial.ConvexHull',
                                      'scipy.spatial._qhull.Delaunay': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Delaunay.html#scipy.spatial.Delaunay',
                                      'scipy.spatial._qhull.HalfspaceIntersection': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.HalfspaceIntersection.html#scipy.spatial.HalfspaceIntersection',
                                      'scipy.spatial._qhull.Voronoi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.Voronoi.html#scipy.spatial.Voronoi'},
            'scipy.spatial._spherical_voronoi': { 'scipy.spatial._spherical_voronoi.SphericalVoronoi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.SphericalVoronoi.html#scipy.spatial.SphericalVoronoi'},
            'scipy.spatial.distance': { 'scipy.spatial.distance.braycurtis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.braycurtis.html#scipy.spatial.distance.braycurtis',
                                        'scipy.spatial.distance.canberra': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.canberra.html#scipy.spatial.distance.canberra',
                                        'scipy.spatial.distance.cdist': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.cdist.html#scipy.spatial.distance.cdist',
                                        'scipy.spatial.distance.chebyshev': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.chebyshev.html#scipy.spatial.distance.chebyshev',
                                        'scipy.spatial.distance.cityblock': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.cityblock.html#scipy.spatial.distance.cityblock',
                                        'scipy.spatial.distance.correlation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.correlation.html#scipy.spatial.distance.correlation',
                                        'scipy.spatial.distance.cosine': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.cosine.html#scipy.spatial.distance.cosine',
                                        'scipy.spatial.distance.dice': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.dice.html#scipy.spatial.distance.dice',
                                        'scipy.spatial.distance.directed_hausdorff': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.directed_hausdorff.html#scipy.spatial.distance.directed_hausdorff',
                                        'scipy.spatial.distance.euclidean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.euclidean.html#scipy.spatial.distance.euclidean',
                                        'scipy.spatial.distance.hamming': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.hamming.html#scipy.spatial.distance.hamming',
                                        'scipy.spatial.distance.is_valid_dm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.is_valid_dm.html#scipy.spatial.distance.is_valid_dm',
                                        'scipy.spatial.distance.is_valid_y': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.is_valid_y.html#scipy.spatial.distance.is_valid_y',
                                        'scipy.spatial.distance.jaccard': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.jaccard.html#scipy.spatial.distance.jaccard',
                                        'scipy.spatial.distance.jensenshannon': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.jensenshannon.html#scipy.spatial.distance.jensenshannon',
                                        'scipy.spatial.distance.kulczynski1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.kulczynski1.html#scipy.spatial.distance.kulczynski1',
                                        'scipy.spatial.distance.mahalanobis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.mahalanobis.html#scipy.spatial.distance.mahalanobis',
                                        'scipy.spatial.distance.minkowski': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.minkowski.html#scipy.spatial.distance.minkowski',
                                        'scipy.spatial.distance.num_obs_dm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.num_obs_dm.html#scipy.spatial.distance.num_obs_dm',
                                        'scipy.spatial.distance.num_obs_y': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.num_obs_y.html#scipy.spatial.distance.num_obs_y',
                                        'scipy.spatial.distance.pdist': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.pdist.html#scipy.spatial.distance.pdist',
                                        'scipy.spatial.distance.rogerstanimoto': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.rogerstanimoto.html#scipy.spatial.distance.rogerstanimoto',
                                        'scipy.spatial.distance.russellrao': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.russellrao.html#scipy.spatial.distance.russellrao',
                                        'scipy.spatial.distance.seuclidean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.seuclidean.html#scipy.spatial.distance.seuclidean',
                                        'scipy.spatial.distance.sokalmichener': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.sokalmichener.html#scipy.spatial.distance.sokalmichener',
                                        'scipy.spatial.distance.sokalsneath': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.sokalsneath.html#scipy.spatial.distance.sokalsneath',
                                        'scipy.spatial.distance.sqeuclidean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.sqeuclidean.html#scipy.spatial.distance.sqeuclidean',
                                        'scipy.spatial.distance.squareform': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.squareform.html#scipy.spatial.distance.squareform',
                                        'scipy.spatial.distance.yule': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.distance.yule.html#scipy.spatial.distance.yule'},
            'scipy.spatial.transform': { 'scipy.spatial.transform.Rotation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.html#scipy.spatial.transform.Rotation',
                                         'scipy.spatial.transform.Rotation.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.__getitem__.html#scipy.spatial.transform.Rotation.__getitem__',
                                         'scipy.spatial.transform.Rotation.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.__len__.html#scipy.spatial.transform.Rotation.__len__',
                                         'scipy.spatial.transform.Rotation.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.__mul__.html#scipy.spatial.transform.Rotation.__mul__',
                                         'scipy.spatial.transform.Rotation.align_vectors': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.align_vectors.html#scipy.spatial.transform.Rotation.align_vectors',
                                         'scipy.spatial.transform.Rotation.apply': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.apply.html#scipy.spatial.transform.Rotation.apply',
                                         'scipy.spatial.transform.Rotation.as_euler': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.as_euler.html#scipy.spatial.transform.Rotation.as_euler',
                                         'scipy.spatial.transform.Rotation.as_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.as_matrix.html#scipy.spatial.transform.Rotation.as_matrix',
                                         'scipy.spatial.transform.Rotation.as_mrp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.as_mrp.html#scipy.spatial.transform.Rotation.as_mrp',
                                         'scipy.spatial.transform.Rotation.as_quat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.as_quat.html#scipy.spatial.transform.Rotation.as_quat',
                                         'scipy.spatial.transform.Rotation.as_rotvec': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.as_rotvec.html#scipy.spatial.transform.Rotation.as_rotvec',
                                         'scipy.spatial.transform.Rotation.concatenate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.concatenate.html#scipy.spatial.transform.Rotation.concatenate',
                                         'scipy.spatial.transform.Rotation.create_group': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.create_group.html#scipy.spatial.transform.Rotation.create_group',
                                         'scipy.spatial.transform.Rotation.from_euler': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.from_euler.html#scipy.spatial.transform.Rotation.from_euler',
                                         'scipy.spatial.transform.Rotation.from_matrix': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.from_matrix.html#scipy.spatial.transform.Rotation.from_matrix',
                                         'scipy.spatial.transform.Rotation.from_mrp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.from_mrp.html#scipy.spatial.transform.Rotation.from_mrp',
                                         'scipy.spatial.transform.Rotation.from_quat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.from_quat.html#scipy.spatial.transform.Rotation.from_quat',
                                         'scipy.spatial.transform.Rotation.from_rotvec': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.from_rotvec.html#scipy.spatial.transform.Rotation.from_rotvec',
                                         'scipy.spatial.transform.Rotation.identity': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.identity.html#scipy.spatial.transform.Rotation.identity',
                                         'scipy.spatial.transform.Rotation.inv': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.inv.html#scipy.spatial.transform.Rotation.inv',
                                         'scipy.spatial.transform.Rotation.magnitude': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.magnitude.html#scipy.spatial.transform.Rotation.magnitude',
                                         'scipy.spatial.transform.Rotation.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.mean.html#scipy.spatial.transform.Rotation.mean',
                                         'scipy.spatial.transform.Rotation.random': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.random.html#scipy.spatial.transform.Rotation.random',
                                         'scipy.spatial.transform.Rotation.reduce': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.reduce.html#scipy.spatial.transform.Rotation.reduce',
                                         'scipy.spatial.transform.RotationSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.RotationSpline.html#scipy.spatial.transform.RotationSpline',
                                         'scipy.spatial.transform.RotationSpline.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.RotationSpline.__call__.html#scipy.spatial.transform.RotationSpline.__call__',
                                         'scipy.spatial.transform.Slerp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Slerp.html#scipy.spatial.transform.Slerp',
                                         'scipy.spatial.transform.Slerp.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Slerp.__call__.html#scipy.spatial.transform.Slerp.__call__'},
            'scipy.spatial.transform._rotation': { 'scipy.spatial.transform._rotation.Rotation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Rotation.html#scipy.spatial.transform.Rotation',
                                                   'scipy.spatial.transform._rotation.Slerp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.Slerp.html#scipy.spatial.transform.Slerp'},
            'scipy.spatial.transform._rotation_spline': { 'scipy.spatial.transform._rotation_spline.RotationSpline': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.spatial.transform.RotationSpline.html#scipy.spatial.transform.RotationSpline'},
            'scipy.special': { 'scipy.special.SpecialFunctionError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.SpecialFunctionError.html#scipy.special.SpecialFunctionError.with_traceback',
                               'scipy.special.SpecialFunctionWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.SpecialFunctionWarning.html#scipy.special.SpecialFunctionWarning.with_traceback',
                               'scipy.special.ai_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.ai_zeros.html#scipy.special.ai_zeros',
                               'scipy.special.assoc_laguerre': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.assoc_laguerre.html#scipy.special.assoc_laguerre',
                               'scipy.special.bei_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.bei_zeros.html#scipy.special.bei_zeros',
                               'scipy.special.beip_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.beip_zeros.html#scipy.special.beip_zeros',
                               'scipy.special.ber_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.ber_zeros.html#scipy.special.ber_zeros',
                               'scipy.special.bernoulli': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.bernoulli.html#scipy.special.bernoulli',
                               'scipy.special.berp_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.berp_zeros.html#scipy.special.berp_zeros',
                               'scipy.special.bi_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.bi_zeros.html#scipy.special.bi_zeros',
                               'scipy.special.chebyc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.chebyc.html#scipy.special.chebyc',
                               'scipy.special.chebys': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.chebys.html#scipy.special.chebys',
                               'scipy.special.chebyt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.chebyt.html#scipy.special.chebyt',
                               'scipy.special.chebyu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.chebyu.html#scipy.special.chebyu',
                               'scipy.special.clpmn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.clpmn.html#scipy.special.clpmn',
                               'scipy.special.comb': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.comb.html#scipy.special.comb',
                               'scipy.special.cython_special': 'https://docs.scipy.org/doc/scipy/reference/reference/special.cython_special.html#module-scipy.special.cython_special',
                               'scipy.special.diric': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.diric.html#scipy.special.diric',
                               'scipy.special.ellip_harm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.ellip_harm.html#scipy.special.ellip_harm',
                               'scipy.special.ellip_harm_2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.ellip_harm_2.html#scipy.special.ellip_harm_2',
                               'scipy.special.ellip_normal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.ellip_normal.html#scipy.special.ellip_normal',
                               'scipy.special.erf_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.erf_zeros.html#scipy.special.erf_zeros',
                               'scipy.special.errstate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.errstate.html#scipy.special.errstate',
                               'scipy.special.euler': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.euler.html#scipy.special.euler',
                               'scipy.special.factorial': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.factorial.html#scipy.special.factorial',
                               'scipy.special.factorial2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.factorial2.html#scipy.special.factorial2',
                               'scipy.special.factorialk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.factorialk.html#scipy.special.factorialk',
                               'scipy.special.fresnel_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.fresnel_zeros.html#scipy.special.fresnel_zeros',
                               'scipy.special.fresnelc_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.fresnelc_zeros.html#scipy.special.fresnelc_zeros',
                               'scipy.special.fresnels_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.fresnels_zeros.html#scipy.special.fresnels_zeros',
                               'scipy.special.gegenbauer': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.gegenbauer.html#scipy.special.gegenbauer',
                               'scipy.special.genlaguerre': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.genlaguerre.html#scipy.special.genlaguerre',
                               'scipy.special.geterr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.geterr.html#scipy.special.geterr',
                               'scipy.special.h1vp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.h1vp.html#scipy.special.h1vp',
                               'scipy.special.h2vp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.h2vp.html#scipy.special.h2vp',
                               'scipy.special.hermite': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.hermite.html#scipy.special.hermite',
                               'scipy.special.hermitenorm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.hermitenorm.html#scipy.special.hermitenorm',
                               'scipy.special.ivp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.ivp.html#scipy.special.ivp',
                               'scipy.special.jacobi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.jacobi.html#scipy.special.jacobi',
                               'scipy.special.jn_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.jn_zeros.html#scipy.special.jn_zeros',
                               'scipy.special.jnjnp_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.jnjnp_zeros.html#scipy.special.jnjnp_zeros',
                               'scipy.special.jnp_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.jnp_zeros.html#scipy.special.jnp_zeros',
                               'scipy.special.jnyn_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.jnyn_zeros.html#scipy.special.jnyn_zeros',
                               'scipy.special.jvp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.jvp.html#scipy.special.jvp',
                               'scipy.special.kei_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.kei_zeros.html#scipy.special.kei_zeros',
                               'scipy.special.keip_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.keip_zeros.html#scipy.special.keip_zeros',
                               'scipy.special.kelvin_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.kelvin_zeros.html#scipy.special.kelvin_zeros',
                               'scipy.special.ker_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.ker_zeros.html#scipy.special.ker_zeros',
                               'scipy.special.kerp_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.kerp_zeros.html#scipy.special.kerp_zeros',
                               'scipy.special.kvp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.kvp.html#scipy.special.kvp',
                               'scipy.special.laguerre': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.laguerre.html#scipy.special.laguerre',
                               'scipy.special.lambertw': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.lambertw.html#scipy.special.lambertw',
                               'scipy.special.legendre': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.legendre.html#scipy.special.legendre',
                               'scipy.special.lmbda': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.lmbda.html#scipy.special.lmbda',
                               'scipy.special.log_softmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.log_softmax.html#scipy.special.log_softmax',
                               'scipy.special.logsumexp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.logsumexp.html#scipy.special.logsumexp',
                               'scipy.special.lpmn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.lpmn.html#scipy.special.lpmn',
                               'scipy.special.lpn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.lpn.html#scipy.special.lpn',
                               'scipy.special.lqmn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.lqmn.html#scipy.special.lqmn',
                               'scipy.special.lqn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.lqn.html#scipy.special.lqn',
                               'scipy.special.mathieu_even_coef': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.mathieu_even_coef.html#scipy.special.mathieu_even_coef',
                               'scipy.special.mathieu_odd_coef': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.mathieu_odd_coef.html#scipy.special.mathieu_odd_coef',
                               'scipy.special.multigammaln': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.multigammaln.html#scipy.special.multigammaln',
                               'scipy.special.obl_cv_seq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.obl_cv_seq.html#scipy.special.obl_cv_seq',
                               'scipy.special.pbdn_seq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.pbdn_seq.html#scipy.special.pbdn_seq',
                               'scipy.special.pbdv_seq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.pbdv_seq.html#scipy.special.pbdv_seq',
                               'scipy.special.pbvv_seq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.pbvv_seq.html#scipy.special.pbvv_seq',
                               'scipy.special.perm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.perm.html#scipy.special.perm',
                               'scipy.special.polygamma': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.polygamma.html#scipy.special.polygamma',
                               'scipy.special.pro_cv_seq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.pro_cv_seq.html#scipy.special.pro_cv_seq',
                               'scipy.special.riccati_jn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.riccati_jn.html#scipy.special.riccati_jn',
                               'scipy.special.riccati_yn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.riccati_yn.html#scipy.special.riccati_yn',
                               'scipy.special.roots_chebyc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_chebyc.html#scipy.special.roots_chebyc',
                               'scipy.special.roots_chebys': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_chebys.html#scipy.special.roots_chebys',
                               'scipy.special.roots_chebyt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_chebyt.html#scipy.special.roots_chebyt',
                               'scipy.special.roots_chebyu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_chebyu.html#scipy.special.roots_chebyu',
                               'scipy.special.roots_gegenbauer': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_gegenbauer.html#scipy.special.roots_gegenbauer',
                               'scipy.special.roots_genlaguerre': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_genlaguerre.html#scipy.special.roots_genlaguerre',
                               'scipy.special.roots_hermite': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_hermite.html#scipy.special.roots_hermite',
                               'scipy.special.roots_hermitenorm': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_hermitenorm.html#scipy.special.roots_hermitenorm',
                               'scipy.special.roots_jacobi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_jacobi.html#scipy.special.roots_jacobi',
                               'scipy.special.roots_laguerre': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_laguerre.html#scipy.special.roots_laguerre',
                               'scipy.special.roots_legendre': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_legendre.html#scipy.special.roots_legendre',
                               'scipy.special.roots_sh_chebyt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_sh_chebyt.html#scipy.special.roots_sh_chebyt',
                               'scipy.special.roots_sh_chebyu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_sh_chebyu.html#scipy.special.roots_sh_chebyu',
                               'scipy.special.roots_sh_jacobi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_sh_jacobi.html#scipy.special.roots_sh_jacobi',
                               'scipy.special.roots_sh_legendre': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.roots_sh_legendre.html#scipy.special.roots_sh_legendre',
                               'scipy.special.seterr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.seterr.html#scipy.special.seterr',
                               'scipy.special.sh_chebyt': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.sh_chebyt.html#scipy.special.sh_chebyt',
                               'scipy.special.sh_chebyu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.sh_chebyu.html#scipy.special.sh_chebyu',
                               'scipy.special.sh_jacobi': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.sh_jacobi.html#scipy.special.sh_jacobi',
                               'scipy.special.sh_legendre': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.sh_legendre.html#scipy.special.sh_legendre',
                               'scipy.special.sinc': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.sinc.html#scipy.special.sinc',
                               'scipy.special.softmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.softmax.html#scipy.special.softmax',
                               'scipy.special.spherical_in': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.spherical_in.html#scipy.special.spherical_in',
                               'scipy.special.spherical_jn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.spherical_jn.html#scipy.special.spherical_jn',
                               'scipy.special.spherical_kn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.spherical_kn.html#scipy.special.spherical_kn',
                               'scipy.special.spherical_yn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.spherical_yn.html#scipy.special.spherical_yn',
                               'scipy.special.y0_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.y0_zeros.html#scipy.special.y0_zeros',
                               'scipy.special.y1_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.y1_zeros.html#scipy.special.y1_zeros',
                               'scipy.special.y1p_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.y1p_zeros.html#scipy.special.y1p_zeros',
                               'scipy.special.yn_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.yn_zeros.html#scipy.special.yn_zeros',
                               'scipy.special.ynp_zeros': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.ynp_zeros.html#scipy.special.ynp_zeros',
                               'scipy.special.yvp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.yvp.html#scipy.special.yvp',
                               'scipy.special.zeta': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.zeta.html#scipy.special.zeta'},
            'scipy.special._ufuncs': { 'scipy.special._ufuncs.errstate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.special.errstate.html#scipy.special.errstate'},
            'scipy.stats': { 'scipy.stats.ConstantInputWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ConstantInputWarning.html#scipy.stats.ConstantInputWarning.with_traceback',
                             'scipy.stats.DegenerateDataWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.DegenerateDataWarning.html#scipy.stats.DegenerateDataWarning.with_traceback',
                             'scipy.stats.FitError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.FitError.html#scipy.stats.FitError.with_traceback',
                             'scipy.stats.NearConstantInputWarning.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.NearConstantInputWarning.html#scipy.stats.NearConstantInputWarning.with_traceback',
                             'scipy.stats._result_classes': 'https://docs.scipy.org/doc/scipy/reference/reference/stats._result_classes.html#module-scipy.stats._result_classes',
                             'scipy.stats.alexandergovern': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.alexandergovern.html#scipy.stats.alexandergovern',
                             'scipy.stats.anderson': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.anderson.html#scipy.stats.anderson',
                             'scipy.stats.anderson_ksamp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.anderson_ksamp.html#scipy.stats.anderson_ksamp',
                             'scipy.stats.ansari': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ansari.html#scipy.stats.ansari',
                             'scipy.stats.barnard_exact': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.barnard_exact.html#scipy.stats.barnard_exact',
                             'scipy.stats.bartlett': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.bartlett.html#scipy.stats.bartlett',
                             'scipy.stats.bayes_mvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.bayes_mvs.html#scipy.stats.bayes_mvs',
                             'scipy.stats.binned_statistic': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.binned_statistic.html#scipy.stats.binned_statistic',
                             'scipy.stats.binned_statistic_2d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.binned_statistic_2d.html#scipy.stats.binned_statistic_2d',
                             'scipy.stats.binned_statistic_dd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.binned_statistic_dd.html#scipy.stats.binned_statistic_dd',
                             'scipy.stats.binom_test': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.binom_test.html#scipy.stats.binom_test',
                             'scipy.stats.binomtest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.binomtest.html#scipy.stats.binomtest',
                             'scipy.stats.bootstrap': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.bootstrap.html#scipy.stats.bootstrap',
                             'scipy.stats.boschloo_exact': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.boschloo_exact.html#scipy.stats.boschloo_exact',
                             'scipy.stats.boxcox': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.boxcox.html#scipy.stats.boxcox',
                             'scipy.stats.boxcox_llf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.boxcox_llf.html#scipy.stats.boxcox_llf',
                             'scipy.stats.boxcox_normmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.boxcox_normmax.html#scipy.stats.boxcox_normmax',
                             'scipy.stats.boxcox_normplot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.boxcox_normplot.html#scipy.stats.boxcox_normplot',
                             'scipy.stats.brunnermunzel': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.brunnermunzel.html#scipy.stats.brunnermunzel',
                             'scipy.stats.chi2_contingency': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.chi2_contingency.html#scipy.stats.chi2_contingency',
                             'scipy.stats.chisquare': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.chisquare.html#scipy.stats.chisquare',
                             'scipy.stats.circmean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.circmean.html#scipy.stats.circmean',
                             'scipy.stats.circstd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.circstd.html#scipy.stats.circstd',
                             'scipy.stats.circvar': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.circvar.html#scipy.stats.circvar',
                             'scipy.stats.combine_pvalues': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.combine_pvalues.html#scipy.stats.combine_pvalues',
                             'scipy.stats.contingency': 'https://docs.scipy.org/doc/scipy/reference/reference/stats.contingency.html#module-scipy.stats.contingency',
                             'scipy.stats.cramervonmises': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.cramervonmises.html#scipy.stats.cramervonmises',
                             'scipy.stats.cramervonmises_2samp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.cramervonmises_2samp.html#scipy.stats.cramervonmises_2samp',
                             'scipy.stats.cumfreq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.cumfreq.html#scipy.stats.cumfreq',
                             'scipy.stats.describe': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.describe.html#scipy.stats.describe',
                             'scipy.stats.differential_entropy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.differential_entropy.html#scipy.stats.differential_entropy',
                             'scipy.stats.energy_distance': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.energy_distance.html#scipy.stats.energy_distance',
                             'scipy.stats.entropy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.entropy.html#scipy.stats.entropy',
                             'scipy.stats.epps_singleton_2samp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.epps_singleton_2samp.html#scipy.stats.epps_singleton_2samp',
                             'scipy.stats.f_oneway': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.f_oneway.html#scipy.stats.f_oneway',
                             'scipy.stats.find_repeats': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.find_repeats.html#scipy.stats.find_repeats',
                             'scipy.stats.fisher_exact': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.fisher_exact.html#scipy.stats.fisher_exact',
                             'scipy.stats.fit': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.fit.html#scipy.stats.fit',
                             'scipy.stats.fligner': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.fligner.html#scipy.stats.fligner',
                             'scipy.stats.friedmanchisquare': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.friedmanchisquare.html#scipy.stats.friedmanchisquare',
                             'scipy.stats.gaussian_kde': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.html#scipy.stats.gaussian_kde',
                             'scipy.stats.gaussian_kde.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.__call__.html#scipy.stats.gaussian_kde.__call__',
                             'scipy.stats.gaussian_kde.covariance_factor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.covariance_factor.html#scipy.stats.gaussian_kde.covariance_factor',
                             'scipy.stats.gaussian_kde.evaluate': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.evaluate.html#scipy.stats.gaussian_kde.evaluate',
                             'scipy.stats.gaussian_kde.integrate_box': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.integrate_box.html#scipy.stats.gaussian_kde.integrate_box',
                             'scipy.stats.gaussian_kde.integrate_box_1d': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.integrate_box_1d.html#scipy.stats.gaussian_kde.integrate_box_1d',
                             'scipy.stats.gaussian_kde.integrate_gaussian': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.integrate_gaussian.html#scipy.stats.gaussian_kde.integrate_gaussian',
                             'scipy.stats.gaussian_kde.integrate_kde': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.integrate_kde.html#scipy.stats.gaussian_kde.integrate_kde',
                             'scipy.stats.gaussian_kde.logpdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.logpdf.html#scipy.stats.gaussian_kde.logpdf',
                             'scipy.stats.gaussian_kde.pdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.pdf.html#scipy.stats.gaussian_kde.pdf',
                             'scipy.stats.gaussian_kde.resample': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.resample.html#scipy.stats.gaussian_kde.resample',
                             'scipy.stats.gaussian_kde.scotts_factor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.scotts_factor.html#scipy.stats.gaussian_kde.scotts_factor',
                             'scipy.stats.gaussian_kde.set_bandwidth': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.set_bandwidth.html#scipy.stats.gaussian_kde.set_bandwidth',
                             'scipy.stats.gaussian_kde.silverman_factor': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.silverman_factor.html#scipy.stats.gaussian_kde.silverman_factor',
                             'scipy.stats.gmean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gmean.html#scipy.stats.gmean',
                             'scipy.stats.gstd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gstd.html#scipy.stats.gstd',
                             'scipy.stats.gzscore': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gzscore.html#scipy.stats.gzscore',
                             'scipy.stats.hmean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.hmean.html#scipy.stats.hmean',
                             'scipy.stats.iqr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.iqr.html#scipy.stats.iqr',
                             'scipy.stats.jarque_bera': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.jarque_bera.html#scipy.stats.jarque_bera',
                             'scipy.stats.kendalltau': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.kendalltau.html#scipy.stats.kendalltau',
                             'scipy.stats.kruskal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.kruskal.html#scipy.stats.kruskal',
                             'scipy.stats.ks_1samp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ks_1samp.html#scipy.stats.ks_1samp',
                             'scipy.stats.ks_2samp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ks_2samp.html#scipy.stats.ks_2samp',
                             'scipy.stats.kstat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.kstat.html#scipy.stats.kstat',
                             'scipy.stats.kstatvar': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.kstatvar.html#scipy.stats.kstatvar',
                             'scipy.stats.kstest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.kstest.html#scipy.stats.kstest',
                             'scipy.stats.kurtosis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.kurtosis.html#scipy.stats.kurtosis',
                             'scipy.stats.kurtosistest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.kurtosistest.html#scipy.stats.kurtosistest',
                             'scipy.stats.levene': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.levene.html#scipy.stats.levene',
                             'scipy.stats.linregress': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.linregress.html#scipy.stats.linregress',
                             'scipy.stats.mannwhitneyu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mannwhitneyu.html#scipy.stats.mannwhitneyu',
                             'scipy.stats.median_abs_deviation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.median_abs_deviation.html#scipy.stats.median_abs_deviation',
                             'scipy.stats.median_test': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.median_test.html#scipy.stats.median_test',
                             'scipy.stats.mode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mode.html#scipy.stats.mode',
                             'scipy.stats.moment': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.moment.html#scipy.stats.moment',
                             'scipy.stats.monte_carlo_test': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.monte_carlo_test.html#scipy.stats.monte_carlo_test',
                             'scipy.stats.mood': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mood.html#scipy.stats.mood',
                             'scipy.stats.mstats': 'https://docs.scipy.org/doc/scipy/reference/reference/stats.mstats.html#module-scipy.stats.mstats',
                             'scipy.stats.multiscale_graphcorr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.multiscale_graphcorr.html#scipy.stats.multiscale_graphcorr',
                             'scipy.stats.mvsdist': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mvsdist.html#scipy.stats.mvsdist',
                             'scipy.stats.normaltest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.normaltest.html#scipy.stats.normaltest',
                             'scipy.stats.obrientransform': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.obrientransform.html#scipy.stats.obrientransform',
                             'scipy.stats.page_trend_test': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.page_trend_test.html#scipy.stats.page_trend_test',
                             'scipy.stats.pearsonr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.pearsonr.html#scipy.stats.pearsonr',
                             'scipy.stats.percentileofscore': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.percentileofscore.html#scipy.stats.percentileofscore',
                             'scipy.stats.permutation_test': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.permutation_test.html#scipy.stats.permutation_test',
                             'scipy.stats.pmean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.pmean.html#scipy.stats.pmean',
                             'scipy.stats.pointbiserialr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.pointbiserialr.html#scipy.stats.pointbiserialr',
                             'scipy.stats.power_divergence': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.power_divergence.html#scipy.stats.power_divergence',
                             'scipy.stats.ppcc_max': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ppcc_max.html#scipy.stats.ppcc_max',
                             'scipy.stats.ppcc_plot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ppcc_plot.html#scipy.stats.ppcc_plot',
                             'scipy.stats.probplot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.probplot.html#scipy.stats.probplot',
                             'scipy.stats.qmc': 'https://docs.scipy.org/doc/scipy/reference/reference/stats.qmc.html#module-scipy.stats.qmc',
                             'scipy.stats.rankdata': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rankdata.html#scipy.stats.rankdata',
                             'scipy.stats.ranksums': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ranksums.html#scipy.stats.ranksums',
                             'scipy.stats.relfreq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.relfreq.html#scipy.stats.relfreq',
                             'scipy.stats.rv_continuous': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.html#scipy.stats.rv_continuous',
                             'scipy.stats.rv_continuous.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.__call__.html#scipy.stats.rv_continuous.__call__',
                             'scipy.stats.rv_continuous.cdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.cdf.html#scipy.stats.rv_continuous.cdf',
                             'scipy.stats.rv_continuous.entropy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.entropy.html#scipy.stats.rv_continuous.entropy',
                             'scipy.stats.rv_continuous.expect': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.expect.html#scipy.stats.rv_continuous.expect',
                             'scipy.stats.rv_continuous.fit': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.fit.html#scipy.stats.rv_continuous.fit',
                             'scipy.stats.rv_continuous.fit_loc_scale': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.fit_loc_scale.html#scipy.stats.rv_continuous.fit_loc_scale',
                             'scipy.stats.rv_continuous.freeze': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.freeze.html#scipy.stats.rv_continuous.freeze',
                             'scipy.stats.rv_continuous.interval': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.interval.html#scipy.stats.rv_continuous.interval',
                             'scipy.stats.rv_continuous.isf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.isf.html#scipy.stats.rv_continuous.isf',
                             'scipy.stats.rv_continuous.logcdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.logcdf.html#scipy.stats.rv_continuous.logcdf',
                             'scipy.stats.rv_continuous.logpdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.logpdf.html#scipy.stats.rv_continuous.logpdf',
                             'scipy.stats.rv_continuous.logsf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.logsf.html#scipy.stats.rv_continuous.logsf',
                             'scipy.stats.rv_continuous.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.mean.html#scipy.stats.rv_continuous.mean',
                             'scipy.stats.rv_continuous.median': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.median.html#scipy.stats.rv_continuous.median',
                             'scipy.stats.rv_continuous.moment': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.moment.html#scipy.stats.rv_continuous.moment',
                             'scipy.stats.rv_continuous.nnlf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.nnlf.html#scipy.stats.rv_continuous.nnlf',
                             'scipy.stats.rv_continuous.pdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.pdf.html#scipy.stats.rv_continuous.pdf',
                             'scipy.stats.rv_continuous.ppf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.ppf.html#scipy.stats.rv_continuous.ppf',
                             'scipy.stats.rv_continuous.rvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.rvs.html#scipy.stats.rv_continuous.rvs',
                             'scipy.stats.rv_continuous.sf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.sf.html#scipy.stats.rv_continuous.sf',
                             'scipy.stats.rv_continuous.stats': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.stats.html#scipy.stats.rv_continuous.stats',
                             'scipy.stats.rv_continuous.std': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.std.html#scipy.stats.rv_continuous.std',
                             'scipy.stats.rv_continuous.support': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.support.html#scipy.stats.rv_continuous.support',
                             'scipy.stats.rv_continuous.var': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.var.html#scipy.stats.rv_continuous.var',
                             'scipy.stats.rv_discrete': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.html#scipy.stats.rv_discrete',
                             'scipy.stats.rv_discrete.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.__call__.html#scipy.stats.rv_discrete.__call__',
                             'scipy.stats.rv_discrete.cdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.cdf.html#scipy.stats.rv_discrete.cdf',
                             'scipy.stats.rv_discrete.entropy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.entropy.html#scipy.stats.rv_discrete.entropy',
                             'scipy.stats.rv_discrete.expect': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.expect.html#scipy.stats.rv_discrete.expect',
                             'scipy.stats.rv_discrete.freeze': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.freeze.html#scipy.stats.rv_discrete.freeze',
                             'scipy.stats.rv_discrete.interval': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.interval.html#scipy.stats.rv_discrete.interval',
                             'scipy.stats.rv_discrete.isf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.isf.html#scipy.stats.rv_discrete.isf',
                             'scipy.stats.rv_discrete.logcdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.logcdf.html#scipy.stats.rv_discrete.logcdf',
                             'scipy.stats.rv_discrete.logpmf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.logpmf.html#scipy.stats.rv_discrete.logpmf',
                             'scipy.stats.rv_discrete.logsf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.logsf.html#scipy.stats.rv_discrete.logsf',
                             'scipy.stats.rv_discrete.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.mean.html#scipy.stats.rv_discrete.mean',
                             'scipy.stats.rv_discrete.median': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.median.html#scipy.stats.rv_discrete.median',
                             'scipy.stats.rv_discrete.moment': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.moment.html#scipy.stats.rv_discrete.moment',
                             'scipy.stats.rv_discrete.nnlf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.nnlf.html#scipy.stats.rv_discrete.nnlf',
                             'scipy.stats.rv_discrete.pmf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.pmf.html#scipy.stats.rv_discrete.pmf',
                             'scipy.stats.rv_discrete.ppf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.ppf.html#scipy.stats.rv_discrete.ppf',
                             'scipy.stats.rv_discrete.rvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.rvs.html#scipy.stats.rv_discrete.rvs',
                             'scipy.stats.rv_discrete.sf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.sf.html#scipy.stats.rv_discrete.sf',
                             'scipy.stats.rv_discrete.stats': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.stats.html#scipy.stats.rv_discrete.stats',
                             'scipy.stats.rv_discrete.std': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.std.html#scipy.stats.rv_discrete.std',
                             'scipy.stats.rv_discrete.support': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.support.html#scipy.stats.rv_discrete.support',
                             'scipy.stats.rv_discrete.var': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.var.html#scipy.stats.rv_discrete.var',
                             'scipy.stats.rv_histogram': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.html#scipy.stats.rv_histogram',
                             'scipy.stats.rv_histogram.__call__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.__call__.html#scipy.stats.rv_histogram.__call__',
                             'scipy.stats.rv_histogram.cdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.cdf.html#scipy.stats.rv_histogram.cdf',
                             'scipy.stats.rv_histogram.entropy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.entropy.html#scipy.stats.rv_histogram.entropy',
                             'scipy.stats.rv_histogram.expect': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.expect.html#scipy.stats.rv_histogram.expect',
                             'scipy.stats.rv_histogram.fit': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.fit.html#scipy.stats.rv_histogram.fit',
                             'scipy.stats.rv_histogram.fit_loc_scale': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.fit_loc_scale.html#scipy.stats.rv_histogram.fit_loc_scale',
                             'scipy.stats.rv_histogram.freeze': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.freeze.html#scipy.stats.rv_histogram.freeze',
                             'scipy.stats.rv_histogram.interval': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.interval.html#scipy.stats.rv_histogram.interval',
                             'scipy.stats.rv_histogram.isf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.isf.html#scipy.stats.rv_histogram.isf',
                             'scipy.stats.rv_histogram.logcdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.logcdf.html#scipy.stats.rv_histogram.logcdf',
                             'scipy.stats.rv_histogram.logpdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.logpdf.html#scipy.stats.rv_histogram.logpdf',
                             'scipy.stats.rv_histogram.logsf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.logsf.html#scipy.stats.rv_histogram.logsf',
                             'scipy.stats.rv_histogram.mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.mean.html#scipy.stats.rv_histogram.mean',
                             'scipy.stats.rv_histogram.median': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.median.html#scipy.stats.rv_histogram.median',
                             'scipy.stats.rv_histogram.moment': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.moment.html#scipy.stats.rv_histogram.moment',
                             'scipy.stats.rv_histogram.nnlf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.nnlf.html#scipy.stats.rv_histogram.nnlf',
                             'scipy.stats.rv_histogram.pdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.pdf.html#scipy.stats.rv_histogram.pdf',
                             'scipy.stats.rv_histogram.ppf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.ppf.html#scipy.stats.rv_histogram.ppf',
                             'scipy.stats.rv_histogram.rvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.rvs.html#scipy.stats.rv_histogram.rvs',
                             'scipy.stats.rv_histogram.sf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.sf.html#scipy.stats.rv_histogram.sf',
                             'scipy.stats.rv_histogram.stats': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.stats.html#scipy.stats.rv_histogram.stats',
                             'scipy.stats.rv_histogram.std': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.std.html#scipy.stats.rv_histogram.std',
                             'scipy.stats.rv_histogram.support': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.support.html#scipy.stats.rv_histogram.support',
                             'scipy.stats.rv_histogram.var': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.var.html#scipy.stats.rv_histogram.var',
                             'scipy.stats.rvs_ratio_uniforms': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rvs_ratio_uniforms.html#scipy.stats.rvs_ratio_uniforms',
                             'scipy.stats.sampling': 'https://docs.scipy.org/doc/scipy/reference/reference/stats.sampling.html#module-scipy.stats.sampling',
                             'scipy.stats.scoreatpercentile': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.scoreatpercentile.html#scipy.stats.scoreatpercentile',
                             'scipy.stats.sem': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sem.html#scipy.stats.sem',
                             'scipy.stats.shapiro': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.shapiro.html#scipy.stats.shapiro',
                             'scipy.stats.siegelslopes': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.siegelslopes.html#scipy.stats.siegelslopes',
                             'scipy.stats.sigmaclip': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sigmaclip.html#scipy.stats.sigmaclip',
                             'scipy.stats.skew': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.skew.html#scipy.stats.skew',
                             'scipy.stats.skewtest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.skewtest.html#scipy.stats.skewtest',
                             'scipy.stats.somersd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.somersd.html#scipy.stats.somersd',
                             'scipy.stats.spearmanr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.spearmanr.html#scipy.stats.spearmanr',
                             'scipy.stats.theilslopes': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.theilslopes.html#scipy.stats.theilslopes',
                             'scipy.stats.tiecorrect': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.tiecorrect.html#scipy.stats.tiecorrect',
                             'scipy.stats.tmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.tmax.html#scipy.stats.tmax',
                             'scipy.stats.tmean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.tmean.html#scipy.stats.tmean',
                             'scipy.stats.tmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.tmin.html#scipy.stats.tmin',
                             'scipy.stats.trim1': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.trim1.html#scipy.stats.trim1',
                             'scipy.stats.trim_mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.trim_mean.html#scipy.stats.trim_mean',
                             'scipy.stats.trimboth': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.trimboth.html#scipy.stats.trimboth',
                             'scipy.stats.tsem': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.tsem.html#scipy.stats.tsem',
                             'scipy.stats.tstd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.tstd.html#scipy.stats.tstd',
                             'scipy.stats.ttest_1samp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ttest_1samp.html#scipy.stats.ttest_1samp',
                             'scipy.stats.ttest_ind': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ttest_ind.html#scipy.stats.ttest_ind',
                             'scipy.stats.ttest_ind_from_stats': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ttest_ind_from_stats.html#scipy.stats.ttest_ind_from_stats',
                             'scipy.stats.ttest_rel': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.ttest_rel.html#scipy.stats.ttest_rel',
                             'scipy.stats.tukey_hsd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.tukey_hsd.html#scipy.stats.tukey_hsd',
                             'scipy.stats.tvar': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.tvar.html#scipy.stats.tvar',
                             'scipy.stats.variation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.variation.html#scipy.stats.variation',
                             'scipy.stats.wasserstein_distance': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.wasserstein_distance.html#scipy.stats.wasserstein_distance',
                             'scipy.stats.weightedtau': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.weightedtau.html#scipy.stats.weightedtau',
                             'scipy.stats.wilcoxon': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.wilcoxon.html#scipy.stats.wilcoxon',
                             'scipy.stats.yeojohnson': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.yeojohnson.html#scipy.stats.yeojohnson',
                             'scipy.stats.yeojohnson_llf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.yeojohnson_llf.html#scipy.stats.yeojohnson_llf',
                             'scipy.stats.yeojohnson_normmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.yeojohnson_normmax.html#scipy.stats.yeojohnson_normmax',
                             'scipy.stats.yeojohnson_normplot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.yeojohnson_normplot.html#scipy.stats.yeojohnson_normplot',
                             'scipy.stats.zmap': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.zmap.html#scipy.stats.zmap',
                             'scipy.stats.zscore': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.zscore.html#scipy.stats.zscore'},
            'scipy.stats._binomtest': { 'scipy.stats._binomtest.BinomTestResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.BinomTestResult.html#scipy.stats._result_classes.BinomTestResult'},
            'scipy.stats._continuous_distns': { 'scipy.stats._continuous_distns.rv_histogram': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_histogram.html#scipy.stats.rv_histogram'},
            'scipy.stats._distn_infrastructure': { 'scipy.stats._distn_infrastructure.rv_continuous': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_continuous.html#scipy.stats.rv_continuous',
                                                   'scipy.stats._distn_infrastructure.rv_discrete': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.rv_discrete.html#scipy.stats.rv_discrete'},
            'scipy.stats._fit': { 'scipy.stats._fit.FitResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.FitResult.html#scipy.stats._result_classes.FitResult'},
            'scipy.stats._hypotests': { 'scipy.stats._hypotests.TukeyHSDResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.TukeyHSDResult.html#scipy.stats._result_classes.TukeyHSDResult'},
            'scipy.stats._kde': { 'scipy.stats._kde.gaussian_kde': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.gaussian_kde.html#scipy.stats.gaussian_kde'},
            'scipy.stats._qmc': { 'scipy.stats._qmc.Halton': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Halton.html#scipy.stats.qmc.Halton',
                                  'scipy.stats._qmc.LatinHypercube': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.LatinHypercube.html#scipy.stats.qmc.LatinHypercube',
                                  'scipy.stats._qmc.MultinomialQMC': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.MultinomialQMC.html#scipy.stats.qmc.MultinomialQMC',
                                  'scipy.stats._qmc.MultivariateNormalQMC': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.MultivariateNormalQMC.html#scipy.stats.qmc.MultivariateNormalQMC',
                                  'scipy.stats._qmc.PoissonDisk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.PoissonDisk.html#scipy.stats.qmc.PoissonDisk',
                                  'scipy.stats._qmc.QMCEngine': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.QMCEngine.html#scipy.stats.qmc.QMCEngine',
                                  'scipy.stats._qmc.Sobol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Sobol.html#scipy.stats.qmc.Sobol'},
            'scipy.stats._relative_risk': { 'scipy.stats._relative_risk.RelativeRiskResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.RelativeRiskResult.html#scipy.stats._result_classes.RelativeRiskResult'},
            'scipy.stats._result_classes': { 'scipy.stats._result_classes.BinomTestResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.BinomTestResult.html#scipy.stats._result_classes.BinomTestResult',
                                             'scipy.stats._result_classes.BinomTestResult.proportion_ci': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.BinomTestResult.proportion_ci.html#scipy.stats._result_classes.BinomTestResult.proportion_ci',
                                             'scipy.stats._result_classes.FitResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.FitResult.html#scipy.stats._result_classes.FitResult',
                                             'scipy.stats._result_classes.FitResult.nllf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.FitResult.nllf.html#scipy.stats._result_classes.FitResult.nllf',
                                             'scipy.stats._result_classes.FitResult.plot': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.FitResult.plot.html#scipy.stats._result_classes.FitResult.plot',
                                             'scipy.stats._result_classes.PearsonRResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.PearsonRResult.html#scipy.stats._result_classes.PearsonRResult',
                                             'scipy.stats._result_classes.PearsonRResult.__getitem__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.PearsonRResult.__getitem__.html#scipy.stats._result_classes.PearsonRResult.__getitem__',
                                             'scipy.stats._result_classes.PearsonRResult.__len__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.PearsonRResult.__len__.html#scipy.stats._result_classes.PearsonRResult.__len__',
                                             'scipy.stats._result_classes.PearsonRResult.__mul__': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.PearsonRResult.__mul__.html#scipy.stats._result_classes.PearsonRResult.__mul__',
                                             'scipy.stats._result_classes.PearsonRResult.confidence_interval': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.PearsonRResult.confidence_interval.html#scipy.stats._result_classes.PearsonRResult.confidence_interval',
                                             'scipy.stats._result_classes.PearsonRResult.count': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.PearsonRResult.count.html#scipy.stats._result_classes.PearsonRResult.count',
                                             'scipy.stats._result_classes.PearsonRResult.index': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.PearsonRResult.index.html#scipy.stats._result_classes.PearsonRResult.index',
                                             'scipy.stats._result_classes.RelativeRiskResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.RelativeRiskResult.html#scipy.stats._result_classes.RelativeRiskResult',
                                             'scipy.stats._result_classes.RelativeRiskResult.confidence_interval': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.RelativeRiskResult.confidence_interval.html#scipy.stats._result_classes.RelativeRiskResult.confidence_interval',
                                             'scipy.stats._result_classes.TukeyHSDResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.TukeyHSDResult.html#scipy.stats._result_classes.TukeyHSDResult',
                                             'scipy.stats._result_classes.TukeyHSDResult.confidence_interval': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.TukeyHSDResult.confidence_interval.html#scipy.stats._result_classes.TukeyHSDResult.confidence_interval'},
            'scipy.stats._stats_py': { 'scipy.stats._stats_py.PearsonRResult': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats._result_classes.PearsonRResult.html#scipy.stats._result_classes.PearsonRResult'},
            'scipy.stats.contingency': { 'scipy.stats.contingency.association': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.contingency.association.html#scipy.stats.contingency.association',
                                         'scipy.stats.contingency.chi2_contingency': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.contingency.chi2_contingency.html#scipy.stats.contingency.chi2_contingency',
                                         'scipy.stats.contingency.crosstab': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.contingency.crosstab.html#scipy.stats.contingency.crosstab',
                                         'scipy.stats.contingency.expected_freq': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.contingency.expected_freq.html#scipy.stats.contingency.expected_freq',
                                         'scipy.stats.contingency.margins': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.contingency.margins.html#scipy.stats.contingency.margins',
                                         'scipy.stats.contingency.relative_risk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.contingency.relative_risk.html#scipy.stats.contingency.relative_risk'},
            'scipy.stats.mstats': { 'scipy.stats.mstats.argstoarray': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.argstoarray.html#scipy.stats.mstats.argstoarray',
                                    'scipy.stats.mstats.brunnermunzel': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.brunnermunzel.html#scipy.stats.mstats.brunnermunzel',
                                    'scipy.stats.mstats.chisquare': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.chisquare.html#scipy.stats.mstats.chisquare',
                                    'scipy.stats.mstats.compare_medians_ms': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.compare_medians_ms.html#scipy.stats.mstats.compare_medians_ms',
                                    'scipy.stats.mstats.count_tied_groups': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.count_tied_groups.html#scipy.stats.mstats.count_tied_groups',
                                    'scipy.stats.mstats.describe': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.describe.html#scipy.stats.mstats.describe',
                                    'scipy.stats.mstats.f_oneway': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.f_oneway.html#scipy.stats.mstats.f_oneway',
                                    'scipy.stats.mstats.find_repeats': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.find_repeats.html#scipy.stats.mstats.find_repeats',
                                    'scipy.stats.mstats.friedmanchisquare': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.friedmanchisquare.html#scipy.stats.mstats.friedmanchisquare',
                                    'scipy.stats.mstats.gmean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.gmean.html#scipy.stats.mstats.gmean',
                                    'scipy.stats.mstats.hdmedian': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.hdmedian.html#scipy.stats.mstats.hdmedian',
                                    'scipy.stats.mstats.hdquantiles': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.hdquantiles.html#scipy.stats.mstats.hdquantiles',
                                    'scipy.stats.mstats.hdquantiles_sd': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.hdquantiles_sd.html#scipy.stats.mstats.hdquantiles_sd',
                                    'scipy.stats.mstats.hmean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.hmean.html#scipy.stats.mstats.hmean',
                                    'scipy.stats.mstats.idealfourths': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.idealfourths.html#scipy.stats.mstats.idealfourths',
                                    'scipy.stats.mstats.kendalltau': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.kendalltau.html#scipy.stats.mstats.kendalltau',
                                    'scipy.stats.mstats.kendalltau_seasonal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.kendalltau_seasonal.html#scipy.stats.mstats.kendalltau_seasonal',
                                    'scipy.stats.mstats.kruskal': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.kruskal.html#scipy.stats.mstats.kruskal',
                                    'scipy.stats.mstats.kruskalwallis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.kruskalwallis.html#scipy.stats.mstats.kruskalwallis',
                                    'scipy.stats.mstats.ks_1samp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.ks_1samp.html#scipy.stats.mstats.ks_1samp',
                                    'scipy.stats.mstats.ks_2samp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.ks_2samp.html#scipy.stats.mstats.ks_2samp',
                                    'scipy.stats.mstats.ks_twosamp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.ks_twosamp.html#scipy.stats.mstats.ks_twosamp',
                                    'scipy.stats.mstats.kstest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.kstest.html#scipy.stats.mstats.kstest',
                                    'scipy.stats.mstats.kurtosis': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.kurtosis.html#scipy.stats.mstats.kurtosis',
                                    'scipy.stats.mstats.kurtosistest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.kurtosistest.html#scipy.stats.mstats.kurtosistest',
                                    'scipy.stats.mstats.linregress': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.linregress.html#scipy.stats.mstats.linregress',
                                    'scipy.stats.mstats.mannwhitneyu': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.mannwhitneyu.html#scipy.stats.mstats.mannwhitneyu',
                                    'scipy.stats.mstats.median_cihs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.median_cihs.html#scipy.stats.mstats.median_cihs',
                                    'scipy.stats.mstats.meppf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.meppf.html#scipy.stats.mstats.meppf',
                                    'scipy.stats.mstats.mjci': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.mjci.html#scipy.stats.mstats.mjci',
                                    'scipy.stats.mstats.mode': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.mode.html#scipy.stats.mstats.mode',
                                    'scipy.stats.mstats.moment': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.moment.html#scipy.stats.mstats.moment',
                                    'scipy.stats.mstats.mquantiles': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.mquantiles.html#scipy.stats.mstats.mquantiles',
                                    'scipy.stats.mstats.mquantiles_cimj': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.mquantiles_cimj.html#scipy.stats.mstats.mquantiles_cimj',
                                    'scipy.stats.mstats.msign': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.msign.html#scipy.stats.mstats.msign',
                                    'scipy.stats.mstats.normaltest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.normaltest.html#scipy.stats.mstats.normaltest',
                                    'scipy.stats.mstats.obrientransform': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.obrientransform.html#scipy.stats.mstats.obrientransform',
                                    'scipy.stats.mstats.pearsonr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.pearsonr.html#scipy.stats.mstats.pearsonr',
                                    'scipy.stats.mstats.plotting_positions': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.plotting_positions.html#scipy.stats.mstats.plotting_positions',
                                    'scipy.stats.mstats.pointbiserialr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.pointbiserialr.html#scipy.stats.mstats.pointbiserialr',
                                    'scipy.stats.mstats.rankdata': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.rankdata.html#scipy.stats.mstats.rankdata',
                                    'scipy.stats.mstats.rsh': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.rsh.html#scipy.stats.mstats.rsh',
                                    'scipy.stats.mstats.scoreatpercentile': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.scoreatpercentile.html#scipy.stats.mstats.scoreatpercentile',
                                    'scipy.stats.mstats.sem': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.sem.html#scipy.stats.mstats.sem',
                                    'scipy.stats.mstats.sen_seasonal_slopes': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.sen_seasonal_slopes.html#scipy.stats.mstats.sen_seasonal_slopes',
                                    'scipy.stats.mstats.siegelslopes': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.siegelslopes.html#scipy.stats.mstats.siegelslopes',
                                    'scipy.stats.mstats.skew': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.skew.html#scipy.stats.mstats.skew',
                                    'scipy.stats.mstats.skewtest': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.skewtest.html#scipy.stats.mstats.skewtest',
                                    'scipy.stats.mstats.spearmanr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.spearmanr.html#scipy.stats.mstats.spearmanr',
                                    'scipy.stats.mstats.theilslopes': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.theilslopes.html#scipy.stats.mstats.theilslopes',
                                    'scipy.stats.mstats.tmax': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.tmax.html#scipy.stats.mstats.tmax',
                                    'scipy.stats.mstats.tmean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.tmean.html#scipy.stats.mstats.tmean',
                                    'scipy.stats.mstats.tmin': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.tmin.html#scipy.stats.mstats.tmin',
                                    'scipy.stats.mstats.trim': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trim.html#scipy.stats.mstats.trim',
                                    'scipy.stats.mstats.trima': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trima.html#scipy.stats.mstats.trima',
                                    'scipy.stats.mstats.trimboth': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trimboth.html#scipy.stats.mstats.trimboth',
                                    'scipy.stats.mstats.trimmed_mean': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trimmed_mean.html#scipy.stats.mstats.trimmed_mean',
                                    'scipy.stats.mstats.trimmed_mean_ci': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trimmed_mean_ci.html#scipy.stats.mstats.trimmed_mean_ci',
                                    'scipy.stats.mstats.trimmed_std': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trimmed_std.html#scipy.stats.mstats.trimmed_std',
                                    'scipy.stats.mstats.trimmed_stde': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trimmed_stde.html#scipy.stats.mstats.trimmed_stde',
                                    'scipy.stats.mstats.trimmed_var': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trimmed_var.html#scipy.stats.mstats.trimmed_var',
                                    'scipy.stats.mstats.trimr': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trimr.html#scipy.stats.mstats.trimr',
                                    'scipy.stats.mstats.trimtail': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.trimtail.html#scipy.stats.mstats.trimtail',
                                    'scipy.stats.mstats.tsem': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.tsem.html#scipy.stats.mstats.tsem',
                                    'scipy.stats.mstats.ttest_1samp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.ttest_1samp.html#scipy.stats.mstats.ttest_1samp',
                                    'scipy.stats.mstats.ttest_ind': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.ttest_ind.html#scipy.stats.mstats.ttest_ind',
                                    'scipy.stats.mstats.ttest_onesamp': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.ttest_onesamp.html#scipy.stats.mstats.ttest_onesamp',
                                    'scipy.stats.mstats.ttest_rel': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.ttest_rel.html#scipy.stats.mstats.ttest_rel',
                                    'scipy.stats.mstats.tvar': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.tvar.html#scipy.stats.mstats.tvar',
                                    'scipy.stats.mstats.variation': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.variation.html#scipy.stats.mstats.variation',
                                    'scipy.stats.mstats.winsorize': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.winsorize.html#scipy.stats.mstats.winsorize',
                                    'scipy.stats.mstats.zmap': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.zmap.html#scipy.stats.mstats.zmap',
                                    'scipy.stats.mstats.zscore': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.mstats.zscore.html#scipy.stats.mstats.zscore'},
            'scipy.stats.qmc': { 'scipy.stats.qmc.Halton': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Halton.html#scipy.stats.qmc.Halton',
                                 'scipy.stats.qmc.Halton.fast_forward': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Halton.fast_forward.html#scipy.stats.qmc.Halton.fast_forward',
                                 'scipy.stats.qmc.Halton.integers': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Halton.integers.html#scipy.stats.qmc.Halton.integers',
                                 'scipy.stats.qmc.Halton.random': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Halton.random.html#scipy.stats.qmc.Halton.random',
                                 'scipy.stats.qmc.Halton.reset': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Halton.reset.html#scipy.stats.qmc.Halton.reset',
                                 'scipy.stats.qmc.LatinHypercube': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.LatinHypercube.html#scipy.stats.qmc.LatinHypercube',
                                 'scipy.stats.qmc.LatinHypercube.fast_forward': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.LatinHypercube.fast_forward.html#scipy.stats.qmc.LatinHypercube.fast_forward',
                                 'scipy.stats.qmc.LatinHypercube.integers': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.LatinHypercube.integers.html#scipy.stats.qmc.LatinHypercube.integers',
                                 'scipy.stats.qmc.LatinHypercube.random': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.LatinHypercube.random.html#scipy.stats.qmc.LatinHypercube.random',
                                 'scipy.stats.qmc.LatinHypercube.reset': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.LatinHypercube.reset.html#scipy.stats.qmc.LatinHypercube.reset',
                                 'scipy.stats.qmc.MultinomialQMC': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.MultinomialQMC.html#scipy.stats.qmc.MultinomialQMC',
                                 'scipy.stats.qmc.MultinomialQMC.random': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.MultinomialQMC.random.html#scipy.stats.qmc.MultinomialQMC.random',
                                 'scipy.stats.qmc.MultivariateNormalQMC': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.MultivariateNormalQMC.html#scipy.stats.qmc.MultivariateNormalQMC',
                                 'scipy.stats.qmc.MultivariateNormalQMC.random': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.MultivariateNormalQMC.random.html#scipy.stats.qmc.MultivariateNormalQMC.random',
                                 'scipy.stats.qmc.PoissonDisk': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.PoissonDisk.html#scipy.stats.qmc.PoissonDisk',
                                 'scipy.stats.qmc.PoissonDisk.fast_forward': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.PoissonDisk.fast_forward.html#scipy.stats.qmc.PoissonDisk.fast_forward',
                                 'scipy.stats.qmc.PoissonDisk.fill_space': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.PoissonDisk.fill_space.html#scipy.stats.qmc.PoissonDisk.fill_space',
                                 'scipy.stats.qmc.PoissonDisk.integers': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.PoissonDisk.integers.html#scipy.stats.qmc.PoissonDisk.integers',
                                 'scipy.stats.qmc.PoissonDisk.random': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.PoissonDisk.random.html#scipy.stats.qmc.PoissonDisk.random',
                                 'scipy.stats.qmc.PoissonDisk.reset': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.PoissonDisk.reset.html#scipy.stats.qmc.PoissonDisk.reset',
                                 'scipy.stats.qmc.QMCEngine': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.QMCEngine.html#scipy.stats.qmc.QMCEngine',
                                 'scipy.stats.qmc.QMCEngine.fast_forward': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.QMCEngine.fast_forward.html#scipy.stats.qmc.QMCEngine.fast_forward',
                                 'scipy.stats.qmc.QMCEngine.integers': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.QMCEngine.integers.html#scipy.stats.qmc.QMCEngine.integers',
                                 'scipy.stats.qmc.QMCEngine.random': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.QMCEngine.random.html#scipy.stats.qmc.QMCEngine.random',
                                 'scipy.stats.qmc.QMCEngine.reset': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.QMCEngine.reset.html#scipy.stats.qmc.QMCEngine.reset',
                                 'scipy.stats.qmc.Sobol': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Sobol.html#scipy.stats.qmc.Sobol',
                                 'scipy.stats.qmc.Sobol.fast_forward': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Sobol.fast_forward.html#scipy.stats.qmc.Sobol.fast_forward',
                                 'scipy.stats.qmc.Sobol.integers': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Sobol.integers.html#scipy.stats.qmc.Sobol.integers',
                                 'scipy.stats.qmc.Sobol.random': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Sobol.random.html#scipy.stats.qmc.Sobol.random',
                                 'scipy.stats.qmc.Sobol.random_base2': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Sobol.random_base2.html#scipy.stats.qmc.Sobol.random_base2',
                                 'scipy.stats.qmc.Sobol.reset': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.Sobol.reset.html#scipy.stats.qmc.Sobol.reset',
                                 'scipy.stats.qmc.discrepancy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.discrepancy.html#scipy.stats.qmc.discrepancy',
                                 'scipy.stats.qmc.scale': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.scale.html#scipy.stats.qmc.scale',
                                 'scipy.stats.qmc.update_discrepancy': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.qmc.update_discrepancy.html#scipy.stats.qmc.update_discrepancy'},
            'scipy.stats.sampling': { 'scipy.stats.sampling.DiscreteAliasUrn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.DiscreteAliasUrn.html#scipy.stats.sampling.DiscreteAliasUrn',
                                      'scipy.stats.sampling.DiscreteAliasUrn.rvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.DiscreteAliasUrn.rvs.html#scipy.stats.sampling.DiscreteAliasUrn.rvs',
                                      'scipy.stats.sampling.DiscreteAliasUrn.set_random_state': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.DiscreteAliasUrn.set_random_state.html#scipy.stats.sampling.DiscreteAliasUrn.set_random_state',
                                      'scipy.stats.sampling.DiscreteGuideTable': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.DiscreteGuideTable.html#scipy.stats.sampling.DiscreteGuideTable',
                                      'scipy.stats.sampling.DiscreteGuideTable.ppf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.DiscreteGuideTable.ppf.html#scipy.stats.sampling.DiscreteGuideTable.ppf',
                                      'scipy.stats.sampling.DiscreteGuideTable.rvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.DiscreteGuideTable.rvs.html#scipy.stats.sampling.DiscreteGuideTable.rvs',
                                      'scipy.stats.sampling.DiscreteGuideTable.set_random_state': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.DiscreteGuideTable.set_random_state.html#scipy.stats.sampling.DiscreteGuideTable.set_random_state',
                                      'scipy.stats.sampling.NumericalInverseHermite': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInverseHermite.html#scipy.stats.sampling.NumericalInverseHermite',
                                      'scipy.stats.sampling.NumericalInverseHermite.ppf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInverseHermite.ppf.html#scipy.stats.sampling.NumericalInverseHermite.ppf',
                                      'scipy.stats.sampling.NumericalInverseHermite.qrvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInverseHermite.qrvs.html#scipy.stats.sampling.NumericalInverseHermite.qrvs',
                                      'scipy.stats.sampling.NumericalInverseHermite.rvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInverseHermite.rvs.html#scipy.stats.sampling.NumericalInverseHermite.rvs',
                                      'scipy.stats.sampling.NumericalInverseHermite.set_random_state': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInverseHermite.set_random_state.html#scipy.stats.sampling.NumericalInverseHermite.set_random_state',
                                      'scipy.stats.sampling.NumericalInverseHermite.u_error': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInverseHermite.u_error.html#scipy.stats.sampling.NumericalInverseHermite.u_error',
                                      'scipy.stats.sampling.NumericalInversePolynomial': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInversePolynomial.html#scipy.stats.sampling.NumericalInversePolynomial',
                                      'scipy.stats.sampling.NumericalInversePolynomial.cdf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInversePolynomial.cdf.html#scipy.stats.sampling.NumericalInversePolynomial.cdf',
                                      'scipy.stats.sampling.NumericalInversePolynomial.ppf': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInversePolynomial.ppf.html#scipy.stats.sampling.NumericalInversePolynomial.ppf',
                                      'scipy.stats.sampling.NumericalInversePolynomial.qrvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInversePolynomial.qrvs.html#scipy.stats.sampling.NumericalInversePolynomial.qrvs',
                                      'scipy.stats.sampling.NumericalInversePolynomial.rvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInversePolynomial.rvs.html#scipy.stats.sampling.NumericalInversePolynomial.rvs',
                                      'scipy.stats.sampling.NumericalInversePolynomial.set_random_state': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInversePolynomial.set_random_state.html#scipy.stats.sampling.NumericalInversePolynomial.set_random_state',
                                      'scipy.stats.sampling.NumericalInversePolynomial.u_error': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInversePolynomial.u_error.html#scipy.stats.sampling.NumericalInversePolynomial.u_error',
                                      'scipy.stats.sampling.SimpleRatioUniforms': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.SimpleRatioUniforms.html#scipy.stats.sampling.SimpleRatioUniforms',
                                      'scipy.stats.sampling.SimpleRatioUniforms.rvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.SimpleRatioUniforms.rvs.html#scipy.stats.sampling.SimpleRatioUniforms.rvs',
                                      'scipy.stats.sampling.SimpleRatioUniforms.set_random_state': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.SimpleRatioUniforms.set_random_state.html#scipy.stats.sampling.SimpleRatioUniforms.set_random_state',
                                      'scipy.stats.sampling.TransformedDensityRejection': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.TransformedDensityRejection.html#scipy.stats.sampling.TransformedDensityRejection',
                                      'scipy.stats.sampling.TransformedDensityRejection.ppf_hat': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.TransformedDensityRejection.ppf_hat.html#scipy.stats.sampling.TransformedDensityRejection.ppf_hat',
                                      'scipy.stats.sampling.TransformedDensityRejection.rvs': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.TransformedDensityRejection.rvs.html#scipy.stats.sampling.TransformedDensityRejection.rvs',
                                      'scipy.stats.sampling.TransformedDensityRejection.set_random_state': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.TransformedDensityRejection.set_random_state.html#scipy.stats.sampling.TransformedDensityRejection.set_random_state',
                                      'scipy.stats.sampling.UNURANError.with_traceback': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.UNURANError.html#scipy.stats.sampling.UNURANError.with_traceback'},
            'scipy.stats.unuran_wrapper': { 'scipy.stats.unuran_wrapper.DiscreteAliasUrn': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.DiscreteAliasUrn.html#scipy.stats.sampling.DiscreteAliasUrn',
                                            'scipy.stats.unuran_wrapper.DiscreteGuideTable': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.DiscreteGuideTable.html#scipy.stats.sampling.DiscreteGuideTable',
                                            'scipy.stats.unuran_wrapper.NumericalInverseHermite': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInverseHermite.html#scipy.stats.sampling.NumericalInverseHermite',
                                            'scipy.stats.unuran_wrapper.NumericalInversePolynomial': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.NumericalInversePolynomial.html#scipy.stats.sampling.NumericalInversePolynomial',
                                            'scipy.stats.unuran_wrapper.SimpleRatioUniforms': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.SimpleRatioUniforms.html#scipy.stats.sampling.SimpleRatioUniforms',
                                            'scipy.stats.unuran_wrapper.TransformedDensityRejection': 'https://docs.scipy.org/doc/scipy/reference/reference/generated/scipy.stats.sampling.TransformedDensityRejection.html#scipy.stats.sampling.TransformedDensityRejection'}}}
